// megaupload captcha-handler

skipscreen.megaupload = function() {

    function Block() {
	this.keys = [];
	this.items = [];
    }

    Block.prototype.add = function(value) {
	var key = value.toSource();
	var pos = this.search(key);
	if (this.keys[pos] != key)
	{
            this.keys.splice(pos, 0, key);
            this.items.splice(pos, 0, value);
	}
    }

    Block.prototype.contains = function(value) {
	var key = value.toSource();
	var pos = this.search(key);
	return this.keys[pos] === key;
    }

    Block.prototype.search = function(key) {
	var low = 0;
	var high = this.keys.length;
	while (low < high)
	{
            mid = low + Math.floor((high - low) / 2);
            if (this.keys[mid] < key)
		low = mid + 1;
            else
		high = mid;
	}

	return low;
    }

    function GIF() {
	this.bytes = 0;
	this.code_dict = [];
	this.current_byte = 0;
	this.height = 0;
	this.gct = []
	this.pixels = []
	this.min_code_size = 0
	this.remaining = [0, 0]
	this.width = 0;
    }

    GIF.prototype.from_array = function(data) {
	this.width = data[6] + data[7] * 0x100;
	this.height = data[8] + data[9] * 0x100;

	var gct_size = Math.pow(2, (data[10] & 7) + 1);

	for (var i = 0; i < gct_size; i++)
            this.gct.push([data[13+i*3], data[13+i*3+1], data[13+i*3+2]]);

	this.min_code_size = data[127];
	var code_size = this.min_code_size + 1;

	this.init_code_dict();

	this.current_byte = 128;
	var code = null;
	var previous = null;
	var next_code = Math.pow(2, this.min_code_size) + 2;
	while (1)
	{
            if (!this.bytes)
            {
		var byte_ = data[this.current_byte];
		if (byte_ == 0)
                    break;
		this.bytes = byte_;
		this.current_byte++;
            }
            else
            {
		code = this.get_code(data, code_size);
		if (code < this.code_dict.length)
		{
                    if (this.code_dict[code] == 'clear')
                    {
			this.init_code_dict();
			code_size = this.min_code_size + 1;
			next_code =  Math.pow(2, this.min_code_size) + 2;
			previous = null;
			continue;
                    }
                    if (this.code_dict[code] == 'end')
			break;
                    if (previous == null)
                    {
			this.pixels = this.pixels.concat(this.code_dict[code]);
			previous = code;
			continue;
                    }
		}

		if (code < this.code_dict.length)
                    this.code_dict[next_code] =
                    this.code_dict[previous].concat(this.code_dict[code][0]);
		else
                    this.code_dict[next_code] =
                    this.code_dict[previous].concat(this.code_dict[previous][0]);

		this.pixels = this.pixels.concat(this.code_dict[code]);

		previous = code;
		next_code++;
		if (next_code >= Math.pow(2, code_size) && code_size < 12)
                    code_size++;
            }
	}
    }

    GIF.prototype.get_code = function(data, code_size) {
	if (this.remaining[0] >= code_size)
	{
            var mask = Math.pow(2, code_size) - 1;
            var code = this.remaining[1] & mask;
            this.remaining[0] -= code_size;
            this.remaining[1] >>= code_size;
	}
	else
	{
            var read_bits = 0;
            var code = 0;
            while (read_bits < code_size)
            {
		var byte_ = data[this.current_byte];
		this.current_byte++;
		this.bytes--;

		var read_in = Math.min(8, code_size - read_bits);
		var read_new = Math.max(0, read_in - this.remaining[0]);
		var new_mask = Math.pow(2, read_new) - 1;
		var rem_mask = Math.pow(2, read_in - read_new) - 1;

		code |= (((byte_ & new_mask) << this.remaining[0]) |
			 (this.remaining[1] & rem_mask)) << read_bits;

		this.remaining = [this.remaining[0] - (read_in - read_new),
				  this.remaining[1] >> (read_in - read_new)];

		this.remaining = [this.remaining[0] + (8 - read_new),
				  this.remaining[1] | (byte_ >> read_new << this.remaining[0])];

		read_bits += read_in;
            }
	}

	return code;
    }

    GIF.prototype.get_pixel = function(x, y)  {
	if (0 <= x && x < this.width && 0 <= y && y < this.height)
            return this.gct[this.pixels[x+y*this.width]];
	else
            return null;
    }

    GIF.prototype.init_code_dict = function() {
	var code_dict = [];

	for (var i = 0; i < this.gct.length; i++)
            code_dict[i] = [i];

	code_dict[Math.pow(2, this.min_code_size)] = 'clear';
	code_dict[Math.pow(2, this.min_code_size)+1] = 'end';

	this.code_dict = code_dict;
    }

    GIF.prototype.to_canvas = function() {
	var canvas = unsafeWindow.document.createElement('canvas');
	canvas.width = this.width;
	canvas.height = this.height;

	var image = canvas.getContext('2d').getImageData(0, 0, canvas.width, canvas.height);
	image.coord_to_index = coord_to_index;
	image.set_pixel = set_pixel;
	image.get_pixel = get_pixel;

	for (var x = 0; x < this.width; x++)
            for (var y = 0; y < this.height; y++)
		image.set_pixel(x, y, this.get_pixel(x, y)[0]);

	canvas.getContext('2d').putImageData(image, 0, 0);

	return canvas;
    }


    function NeuralNet() {
	this.h_layer = [];
	this.o_layer = [];
    }

    NeuralNet.prototype.create_layer = function(weights) {
	var layer = [];

	for (var i = 0; i < weights.length; i++)
	{
            var neuron = new Neuron;
            neuron.threshold = weights[i][0];
            neuron.weights = weights[i][1];

            layer.push(neuron);
	}

	return layer;
    }

    NeuralNet.prototype.feed = function(inputs) {
	var h_outputs = [];

	for (var i = 0; i < this.h_layer.length; i++)
	{
            this.h_layer[i].feed(inputs);
            h_outputs.push(this.h_layer[i].output());
	}

	for (var i = 0; i < this.o_layer.length; i++)
	{
            this.o_layer[i].feed(h_outputs);
	}
    }

    NeuralNet.prototype.output = function() {
	var output = [];

	for (var i = 0; i < this.o_layer.length; i++)
	{
            output.push(this.o_layer[i].output());
	}

	return output;
    }

    NeuralNet.prototype.test = function(inputs) {
	this.feed(inputs);
	return this.output();
    }

    function Neuron() {
	this.activation = 0;
	this.bias = -1;
	this.threshold = 0;
	this.weights = [];
    }

    Neuron.prototype.feed = function(inputs) {
	this.activation = 0;
	for (var i = 0; i < inputs.length; i++)
	{
            this.activation += inputs[i] * this.weights[i];
	}
	this.activation += this.bias*this.threshold;
    }

    Neuron.prototype.output = function() {
	return 1/(1+Math.exp(-this.activation));
    }

    function coord_to_index(x, y) {
	return x*4+y*4*this.width;
    }

    function set_pixel(x, y, colour) {
	this.data[this.coord_to_index(x, y)] = colour;
	this.data[this.coord_to_index(x, y)+1] = colour;
	this.data[this.coord_to_index(x, y)+2] = colour;
	this.data[this.coord_to_index(x, y)+3] = 255;
    }

    function get_pixel(x, y, colour) {
	return this.data[this.coord_to_index(x, y)];
    }

    function check_receptors(image) {
	receptors = [];
	for (var x = 0; x < 33; x += 3)
            for (var y = 0; y < 30; y += 2)
		if (image.get_pixel(x, y) >= 128)
                    receptors.push(1);
        else
            receptors.push(0);

	return receptors;
    }

    function crop_canvas(canvas, start_point) {
	var image = canvas.getContext('2d').getImageData(0, 0, canvas.width, canvas.height);
	image.coord_to_index = coord_to_index;
	image.set_pixel = set_pixel;
	image.get_pixel = get_pixel;

	var char_pos = null;
	for (var interval = 25; interval > 1; interval = Math.floor(interval / 2))
	{
            for (var x = start_point[0]; x < start_point[0] + 50; x += interval)
            {
		for (var y = start_point[1]; y < start_point[1] + 50; y++)
		{
                    if (image.get_pixel(x, y) == 255)
			char_pos = [x, y];
		}
            }
            if (char_pos != null)
		break;
	}

	for (var dir = -1; dir <= 2; dir += 2)
            for (var x = char_pos[0]; 0 <= x && x < image.width; x += dir)
        {
            var white_pixels = 0;
            for (var y = Math.max(0, char_pos[1]-50);
                 y < Math.min(image.height, char_pos[1]+50); y += 4)
                if (image.get_pixel(x, y) >= 128)
                    white_pixels++;

            if (!white_pixels)
                for (var y = Math.max(0, char_pos[1]-50);
                     y < Math.min(image.height, char_pos[1]+50); y++)
                    if (image.get_pixel(x, y) >= 128)
                        white_pixels++;

            if (!white_pixels)
                if (dir == -1)
            {
                var im_left = x + 1;
                break;
            }
            else
            {
                var im_right = x - 1;
                break;
            }
        }

	for (var dir = -1; dir <= 2; dir += 2)
            for (var y = char_pos[1]; 0 <= y && y < image.height; y += dir)
        {
            var white_pixels = 0;
            for (var x = Math.max(0, char_pos[0]-50);
                 x < Math.min(image.width, char_pos[0]+50); x += 4)
                if (image.get_pixel(x, y) >= 128)
                    white_pixels++;

            if (!white_pixels)
                for (var x = Math.max(0, char_pos[0]-50);
                     x < Math.min(image.width, char_pos[0]+50); x++)
                    if (image.get_pixel(x, y) >= 128)
                        white_pixels++;

            if (!white_pixels)
                if (dir == -1)
            {
                var im_top = y + 1;
                break;
            }
            else
            {
                var im_bottom = y - 1;
                break;
            }
        }

	width = im_right-im_left;
	height = im_bottom-im_top;

	var cropped_canvas = unsafeWindow.document.createElement('canvas');
	cropped_canvas.width = 100;
	cropped_canvas.height = 100;
	cropped_canvas.getContext('2d').drawImage(canvas, im_left, im_top, width, height,
						  0, 0, width, height);

	return cropped_canvas;
    }

    function decode(captcha) {
	var canvas = captcha.to_canvas();
	var image = canvas.getContext('2d').getImageData(0, 0, canvas.width, canvas.height);

	var blocks = get_blocks(image);
	var black_blocks = blocks[0];
	var white_blocks = blocks[1];

	var large_black = get_large_blocks(black_blocks, 4);
	var large_white = get_large_blocks(white_blocks, 3);

	var small_black = [];
	for (var i = 0; i < black_blocks.length; i++)
	{
            var in_large = false;
            for (var j = 0; j < large_black.length; j++)
		if (large_black[j].contains(black_blocks[i].items[0]))
                    in_large = true;
            if (!in_large)
		small_black.push(black_blocks[i]);
	}

	var small_white = [];
	for (var i = 0; i < white_blocks.length; i++)
	{
            var in_large = false;
            for (var j = 0; j < large_white.length; j++)
		if (large_white[j].contains(white_blocks[i].items[0]))
                    in_large = true;
            if (!in_large)
		small_white.push(white_blocks[i]);
	}

	try
	{
            chars = get_chars(image, large_black, large_white, small_black, small_white);
	}
	catch (e)
	{
            return false;
	}

	net = create_net();
	code = '';
	for (var i = 0; i < chars.length; i++)
	{
            receptors = check_receptors(chars[i]);
            code += guess_letter(net, receptors, i == 3);
	}

	return code;
    }

    function get_blocks(image) {
	function sort_block(pixel1, pixel2)
	{
            return pixel1[0] - pixel2[0];
	}

	function min_size_count(blocks, min_size)
	{
            var count = 0;
            for (var i = 0; i < blocks.length; i++)
		if (blocks[i].items.length > min_size)
                    count++;
            return count;
	}

	var canvas = unsafeWindow.document.createElement('canvas');
	canvas.width = image.width + 2;
	canvas.height = image.height + 2;
	canvas.getContext('2d').fillStyle = 'rgb(255,255,255)';
	canvas.getContext('2d').fillRect (0, 0, canvas.width, canvas.height);
	canvas.getContext('2d').putImageData(image, 1, 1);

	image = canvas.getContext('2d').getImageData(0, 0, canvas.width, canvas.height);
	image.coord_to_index = coord_to_index;
	image.set_pixel = set_pixel;
	image.get_pixel = get_pixel;

	found = new Block();
	bg = get_colour_block(image, 0, 0);

	for (var i = 0; i < bg.items.length; i++)
            found.add(bg.items[i]);

	black_blocks = [];
	white_blocks = [];
	for (var x = 0; x < image.width; x++)
            for (var y = 0; y < image.height; y++)
        {
            var colour = image.get_pixel(x, y);
            var block = null;

            if (found.contains([x, y]))
                continue;

            if (colour == 0)
            {
                block = get_colour_block(image, x, y);
                block.items.sort(sort_block);
                if (block.items.length >= 5)
                    black_blocks.push(block);
            }
            if (colour == 255)
            {
                block = get_colour_block(image, x, y);
                block.items.sort(sort_block);
                if (block.items.length >= 5)
                    white_blocks.push(block);
            }

            if (block != null)
                for (var i = 0; i < block.items.length; i++)
                    found.add(block.items[i]);
        }

	while (min_size_count(black_blocks, 10) < 4)
	{
            var wide = 0;
            for (var i = 0; i < black_blocks.length; i++)
		if (black_blocks[i].items.length > black_blocks[wide].items.length)
                    wide = i;

            var blocks = split_block(black_blocks[wide]);
            black_blocks.splice(wide, 1);
            black_blocks.splice(wide, 0, blocks[1]);
            black_blocks.splice(wide, 0, blocks[0]);
	}

	return [black_blocks, white_blocks];
    }

    function get_chars(image, large_black, large_white, small_black, small_white) {
	chars = [];

	for (var i = 0; i < large_black.length; i++)
	{
            var canvas = unsafeWindow.document.createElement('canvas');
            canvas.width = image.width;
            canvas.height = image.height;
            canvas.getContext('2d').fillRect(0, 0, canvas.width, canvas.height);

            var image = canvas.getContext('2d').getImageData(0, 0, canvas.width, canvas.height);
            image.coord_to_index = coord_to_index;
            image.set_pixel = set_pixel;
            image.get_pixel = get_pixel;

            for (var j = 0; j < large_black[i].items.length; j++)
		image.set_pixel(large_black[i].items[j][0], large_black[i].items[j][1], 255);

            for (var j = 0; j < small_white.length; j++)
            {
		if (i > 0)
                    if (small_white[j].items[0][0] <
			large_black[i-1].items[large_black[i-1].items.length-1][0] &&
			small_white[j].items[small_white[j].items.length-1][0] >
			large_black[i].items[0][0])

			for (var k = 0; k < small_white[j].items.length; k++)
                            image.set_pixel(small_white[j].items[k][0],
                                            small_white[j].items[k][1], 255);

		if (i < large_black.length - 1)
                    if (small_white[j].items[0][0] <
			large_black[i].items[large_black[i].items.length-1][0] &&
			small_white[j].items[small_white[j].items.length-1][0] >
			large_black[i+1].items[0][0])

			for (var k = 0; k < small_white[j].items.length; k++)
                            image.set_pixel(small_white[j].items[k][0],
                                            small_white[j].items[k][1], 255);
            }

            for (var j = 0; j < small_black.length; j++)
            {
		if (small_black[j].items.length < 30)
                    continue;

		var common_columns = 0;
		for (var k = 0; k < small_black[j].items.length; k++)
                    if (large_black[i].items[0][0] <= small_black[j].items[k][0] &&
			small_black[j].items[k][0] <=
			large_black[i].items[large_black[i].items.length-1][0])

			common_columns++;

		if (common_columns < 10)
                    continue;

		if (i > 0)
		{
                    var common_previous = 0;
                    for (var k = 0; k < small_black[j].items.length; k++)
			if (large_black[i-1].items[0][0] <= small_black[j].items[k][0] &&
                            small_black[j].items[k][0] <=
                            large_black[i-1].items[large_black[i-1].items.length-1][0])

                            common_previous++;

                    if (common_columns < common_previous)
			continue;
		}

		if (i < large_black.length - 1)
		{
                    var common_next = 0;
                    for (var k = 0; k < small_black[j].items.length; k++)
			if (large_black[i+1].items[0][0] <= small_black[j].items[k][0] &&
                            small_black[j].items[k][0] <=
                            large_black[i+1].items[large_black[i+1].items.length-1][0])

                            common_next++;

                    if (common_columns < common_next)
			continue;
		}

		for (var k = 0; k < small_black[j].items.length; k++)
                    image.set_pixel(small_black[j].items[k][0],
                                    small_black[j].items[k][1], 255);
            }

            /*if (i > 0)
            if (large_black[i].items[0][0] -
                large_white[i-1].items[large_white[i-1].items.length-1][0] <= 5)

                for (var j = 0; j < large_white[i-1].items.length; j++)
                    image.set_pixel(large_white[i-1].items[j][0],
                                    large_white[i-1].items[j][1], 255);

        if (i < large_black.length - 1)
            if (large_white[i].items[0][0] -
                large_black[i].items[large_black[i].items.length-1][0] <= 5)
                for (var j = 0; j < large_white[i].items.length; j++)
                    image.set_pixel(large_white[i].items[j][0],
                                    large_white[i].items[j][1], 255);*/


            canvas.getContext('2d').putImageData(image, 0, 0);

            var canvas2 = unsafeWindow.document.createElement('canvas');
            canvas2.width = 200;
            canvas2.height = 200;
            canvas2.getContext('2d').fillRect(0, 0, canvas2.width, canvas2.height);

            if (i % 2)
		canvas2.getContext('2d').rotate(0.08726646);
            else
		canvas2.getContext('2d').rotate(6.19591884);

            canvas2.getContext('2d').drawImage(canvas, 50, 75);

            var start_points = [[50, 65], [50, 70], [85, 55], [90, 80]];
            canvas = crop_canvas(canvas2, start_points[i]);

            image = canvas.getContext('2d').getImageData(0, 0, canvas.width, canvas.height);
            image.coord_to_index = coord_to_index;
            image.set_pixel = set_pixel;
            image.get_pixel = get_pixel;

            chars.push(image);
	}

	return chars;
    }

    function get_colour_block(image, x, y) {
	function within(x, y)
	{
            return 0 <= x && x < image.width && 0 <= y && y < image.height;
	}

	var colour = image.get_pixel(x, y);
	var edge = [[x, y]];
	var block = new Block();
	block.add([x, y]);

	while (edge.length > 0)
	{
            var newedge = [];
            for (var i = 0; i < edge.length; i++)
            {
		var x = edge[i][0];
		var y = edge[i][1];
		var adjacent = [[x+1, y], [x-1, y], [x, y+1], [x, y-1]];
		for (var j = 0; j < adjacent.length; j++)
		{
                    var s = adjacent[j][0];
                    var t = adjacent[j][1];

                    if (within(s, t) && !block.contains([s, t]) && image.get_pixel(s, t) == colour)
                    {
			block.add([s, t]);
			newedge.push([s, t]);
                    }
		}
            }
            edge = newedge;
	}
	return block;
    }

    function get_large_blocks(blocks, count) {
	function sort_set(set1, set2)
	{
            return set1.items[0][0] - set2.items[0][0];
	}

	var large = [];
	for (var i = 0; i < blocks.length; i++)
	{
            if (large.length < count)
		large.push(blocks[i]);
            else
            {
		var greatest_diff = [0, null];
		for (var j = 0; j < large.length; j++)
		{
                    var diff = blocks[i].items.length - large[j].items.length;
                    if (diff > 0 && (diff > greatest_diff[0] || greatest_diff[1] == null))
			greatest_diff = [diff, j];
		}

		if (greatest_diff[1] != null)
                    large[greatest_diff[1]] = blocks[i];
            }
	}

	return large.sort(sort_set);
    }

    function guess_letter(net, receptors, digit) {
	var output_map = ['1', '2', '3', '4', '5',
            '6', '7', '8', '9', 'a',
            'b', 'c', 'd', 'e', 'f',
            'g', 'h', 'k', 'm', 'n',
            'p', 'q', 'r', 's', 't',
            'u', 'v', 'w', 'x', 'y',
            'z'];

	var output = net.test(receptors);

	var highest = 0;
	for (var i = 0; i < output.length; i++)
	{
            if (output[i] > output[highest] && ((!digit && i >= 9) ||
						(digit && i < 9)))
		highest = i;
	}

	if (!digit && highest == 0)
            highest = 9;

	return output_map[highest]
    }

    function split_block(block) {
	histogram = [];

	var start = block.items[0][0] + 5;
	var end = block.items[block.items.length-1][0] - 5;

	for (var i = 0; i < block.items.length; i++)
            if (start <= block.items[i][0] && block.items[i][0] <= end)
        {
            if (histogram[block.items[i][0]] == undefined)
                histogram[block.items[i][0]] = 0;

            histogram[block.items[i][0]]++;
        }

	var low = start;
	for (var i = 0; i < histogram.length; i++)
            if (histogram[i] != undefined && histogram[i] < histogram[low])
		low = i;

	left = new Block();
	right = new Block();

	for (var i = 0; i < block.items.length; i++)
	{
            if (block.items[i][0] <= low)
		left.add(block.items[i]);
            if (block.items[i][0] >= low)
		right.add(block.items[i]);
	}

	return [left, right];
    }

    function load_image(data) {
	var gif = new GIF();
	gif.from_array(data_array(data));

	var form = document.getElementById('captchaform');
	var textbox = document.getElementById('captchafield');

	textbox.style.fontWeight = 'normal';
	textbox.style.fontSize = '7pt';
	textbox.value = 'working...';

	textbox.value = decode(gif);

	form.submit();
    }

    function data_array(data) {

	var data_array = [];

	for (var i = 0; i < data.length; i++)
            data_array.push(data[i].charCodeAt(0) & 0xff);

	return data_array;
    }

    function start()  {

	var xpath = "//div[@id='downloadlink']/a";
	var urlLink = getFirstResult(xpath, document);

	if (urlLink) {

            var wait = 0;
            var counter = $id("countdown");
            if (counter && counter.innerHTML) {
		wait = parseInt(counter.innerHTML,10);
		wait = (isNaN(wait) ? 0 : wait);
            }
            try {
		var endFunction = function () {
                    new share().show();
                    location.href = urlLink.href;
		};

		if (wait > 0) {
                    genericWaiter(wait, twoLD, endFunction);
                    return;
		} else {
                    // no wait needed!
                    endFunction();
		}
            } catch(e) { errorHandler(e, twoLD);}
	}


	// have we maxed out???
	// //div[4]/center/font/text()
	// Your IP address 71.57.235.60 has just downloaded 345435 bytes. Please wait 7 minutes, then try your download again.
	var already = document.location.search;
	if (already == "?c=premium&l=1") {
	    var inform = getFirstResult("//div[4]/center/font");

	    //set a timer
	    // go back in history....

	    inform.innerHTML += "<p>MegaUpload is making you wait; "
		+ "<span style='color: green'>But leave this window open, and SkipScreen will"
		+ " download your file automatically when it's available.</p>"
		+ "<p>(in other words, you're free to go)</p>"
		+ "<p id='remaining'>Preparing to skip</p>";

	    var seconds = TOOLS.minutesToSeconds(2);

	    var waiter = setInterval( function() {
		--seconds;
		var msg = TOOLS.formatSeconds(seconds) + " remaining to wait";
		document.title = "{SS} " + msg;
		$id("remaining").innerHTML = msg;

		if (seconds <= 0) {
		    clearInterval(waiter);
		    $id("remaining").innerHTML = "If your download doesn't start, please try again.";
		    unsafeWindow.history.go(-2);
		}

	    } , TOOLS.ONE_SECOND ) ;

	    return;

	}



	if (window.location.href.match('\\?d='))
	{
	    var captcha = $id("captchaform"); // document.getElementById('captchaform')
	    if (captcha) {
		var image = captcha.parentNode.getElementsByTagName('img')[0];

		GM_xmlhttpRequest({method: 'GET',
				   url: image.src,
				   overrideMimeType: 'text/plain; charset=x-user-defined',
				   onload: function(response) { load_image(response.responseText); }
				  });
	    }
	}
    }

    start(); // start MU processing

};


skipscreen.megaupload.create_net = function() {
	//pre-calculated weights
	var h_weights = [[0.77147127757444922, [-0.42600496276709426, 0.28429531740208641, -0.035814287496662128, -0.55078872245288091, -0.74385507315234367, -0.28009741133696231, -0.44084718613931467, -0.42425160544268653, -0.37664922950953605, 0.26562226332146316, 0.038291525814433604, -0.82493266767538209, -0.72883179428492217, 0.5784242294757056, 0.0038283047274942916, -0.074447918400339513, 0.78969514584390021, 0.85325743412218857, -0.048194486727984306, -0.89044565367884809, 0.67200747305210828, 1.0267318957795655, 0.88859356121484023, 0.94713218465935645, 1.091344490781647, 0.47681236607650251, -0.4368491875326892, 0.36233853877812711, -0.37211113662603379, 0.83590671256989024, 0.23304104898986827, 0.50381793230910188, 0.51599371420069851, 0.6259197581469681, 0.075767029435181113, -0.60758522315326591, -0.62486204361829356, 0.19242069602524717, -0.096585276564459949, -0.7517610887051609, 0.75382181224443956, -1.1738139178968903, 0.0031997411605333495, -0.71416885669313812, -0.04722441841604641, -0.75869123586125375, 0.15241268884778569, 0.68582676461268466, -0.070525893160479275, -0.86158589302405453, 0.67483357162994084, 0.053300469889485044, -0.65509862013883335, -0.050872263677536007, -0.28206194711578308, -0.28661491660930083, -1.0449356843051156, -1.0060829542650029, 0.63256090916325691, 0.71846097823567545, -0.045695235135695213, -0.45470222100458557, 0.20963394742633998, 0.62901536885680165, -1.1798237378255509, -0.26928875976143762, -0.028075526849956262, 0.93088463179378633, -0.1497856088321948, 0.059395612517939567, 0.2400555430652857, -0.20846535129443858, -0.8366926924042668, -0.16103622140837498, -0.79779030402584117, 0.81599815180635149, 0.64534663281843707, -0.29251601480095962, -0.26668066773880128, -0.47648440284247323, 0.15462269898002634, 0.62600114137019724, 0.38861679896731643, -0.70628870133254573, 0.20424361722183568, -0.56294138911922753, -0.13999422098253825, 0.12989851655350923, 0.50111197508469829, -0.3801343764713323, 0.66994868491877713, -0.3342905965210311, 0.30032457982923444, -0.66916284832441242, 0.43887769186939735, 0.47630324263614543, 0.062685759668564822, 0.22422622196863426, -0.05596626278188669, 0.75424868239582021, 0.99686007613834593, 0.66227906755625354, 0.54190580301495461, -0.12406755646388895, -0.50205709876501747, 0.70787365293012661, 0.8039871030148199, -0.12838497088662107, -0.0010475489623066291, 0.29242142028177759, -0.75762592654848704, 1.0487196287312286, -0.65916336124871611, 0.69593527235864039, -0.70915391377516035, 0.2524393294897615, 0.72858916359040959, 0.49709497115230877, 0.37346426931487803, -0.27044946199830927, 0.48721769048258573, -0.19476540331433359, 0.95812973232207865, -0.1070736094554086, 0.85528414928883811, 0.7005270250811414, -0.50764426712515354, 0.55293456473022207, -0.41033897222123755, 0.79113378101106102, -0.54191056812543448, 0.67849250041921294, -0.97628978215807272, 0.042239161608192216, -0.84036926666981082, 0.22670295104837518, -0.81925765692570163, 0.89451988085762835, 0.38896621539816995, 0.45516740808832018, -0.78111419160980622, 0.16171983657995886, 0.010709748656962172, -0.32596912065497508, 0.84354671249056423, -0.20375425694993901, -0.39077142135748927, -0.1069828506966137, 0.99034120591639563, -0.4749038775441965, -0.69179832326868307, -1.0165938459963881, 0.10392426644455058, -1.0026733262351815, -0.89556115569619987, 0.45882189141837287, 0.34248138002108236, -0.91507806175180328, 0.53076237835205653, -0.74524366749746229, -0.86166956189707644, 0.66195113394593785, -0.95588159849934096, -0.53187108639297831, 0.046875693976365262]],
	    [0.76980543136233281, [0.18125432486382498, -0.85903776253734188, 0.35214090260811176, 0.10498172509150895, -0.95425720086844368, -0.15694094669815883, 0.49883379562683483, -0.011706985030670101, -0.50921704022777359, -0.35682424932474738, 0.37948507875086807, -0.57911601040525473, -0.016362811855606511, -0.85090740019575062, -0.019314744221713198, -0.53260657678779144, 0.010487089575215314, -0.15550653416467358, 0.077422030222331156, 0.53789656647651263, 0.12588856804896575, 0.21927246143498727, 0.71558271686127772, 0.46935115224963359, 0.28405147703572536, -0.53103562367620272, 0.3340138825974428, -0.65934934759414909, 0.12919177887044897, 0.15006382674752627, -0.30033480150840042, -0.58104506501613906, -1.2013187722858143, -0.21409354688130428, 0.26125772185593993, 0.047962395898773783, -0.32989221443733929, 0.77428507383278877, -0.9720435307058215, -0.47809334416288274, 0.092930627962827556, -0.66108934964161692, -0.87183749094148866, -0.12735485366900606, -0.44034464164975184, 0.69935500896405822, -0.61543519296522453, -0.84950915401751081, -0.2243416071059377, -0.22595541902456204, 0.54935023114819481, 0.97500115882935801, 0.46157158395448739, 0.10330245486761717, -0.51829741134286567, -0.58276911067557835, -0.35824729547450035, -0.5183568383829753, -0.076524864447494637, 0.39143093026661324, 0.3616525072667815, -0.49523692408629316, -0.27194039587926605, 0.27013863531627086, -0.52513267836768751, 0.028798878814495818, 0.57168273617440879, -0.77606821158569395, -0.22563956331168009, 0.061459077014155185, 0.0060019281109378779, -0.068263819448332708, -0.12943286772472115, -0.12478995976521547, 0.98436333070270465, 0.53205973881407165, -0.097478249698729175, -0.25588628112171585, -0.97885471468635832, -0.16194934951550594, 0.41965674589490459, 0.23273735258750036, 0.34894012701608113, -0.93238809561674096, -0.0058846819394086742, 0.47371464061606833, -0.84773689787128792, 0.59798126413353547, 0.36222433073024846, 0.42897320129986949, -0.99504058658729899, 0.05787565529377374, -0.27702547890468143, -0.40302160260496939, 0.56255913908499133, 0.068143049413262199, -0.38165210859287091, -0.39476674590167204, 0.13369598321176782, -0.30815342870815399, 0.63797950558426453, 0.27118221785227881, 0.9180896648763377, 0.63200511830880612, -0.91960267219460612, 0.43593242399410947, 0.2251351534974228, -0.24481465382484793, 0.20471613867536018, 0.3615941795295794, -0.22024048489504194, -0.40044251350416149, 0.41626891135919031, -0.94035504553341243, -0.97514925457788615, -0.92557562351872569, -0.13100248170076448, 0.34663006299708543, -0.079217877395436356, -0.66475020122868012, -0.31365662612307765, 0.31516682067414653, 0.80894970790844323, 0.49408723651898273, 1.015251953160405, 0.92029862107715121, 0.76841268818915387, -0.69907614556407427, -0.53147156144855223, 0.59843677451132449, 0.65073972465265784, -0.65211547284942195, -0.12680096870329829, 0.10724998221510378, -0.25329158003611413, -0.31778585850932484, -0.13738744758134278, -0.19170381720244536, 0.17473293964304581, 0.92922397923730971, 0.64435466233108607, 0.33577368331680268, 0.86511069707623633, -0.063074550817132771, 0.17142744146485911, 0.15505893449120506, -0.14117715810335829, -0.37940001831010955, 0.51697279301175669, 0.012174927280703685, 0.71174628508378057, -0.59428836544465213, 0.14365128356967974, -0.74639638832540656, 0.033761523588515002, -0.50711858398920096, -0.45161768175981926, 0.67114739035659454, 0.70017669662535043, 0.53248939270254292, -0.55047620505572858, -0.15134994575854344, -0.4392637425923589, 0.91112078210905523, 0.27221270540946141]],
	    [-0.093047593347123828, [0.2047918677174933, 1.0927922235824208, -0.50356564824861383, 0.63944827377279556, 0.56352351535214473, -0.074961192845920649, 0.10285672171952262, -0.88540021284542347, 0.45490195387725413, -0.41083500003062778, 0.46520474726896688, 0.5795057264774931, 0.76996531374181165, 0.0070161873802456753, 0.79449675558028354, -0.34436274170093689, -0.53585215358585447, -0.35087533618905986, 0.12855146874078605, 0.58134435654447503, 1.0152750968983213, -0.45826941975367158, 0.086754123681013831, 0.12739170625732102, -0.21007533390048513, -0.45263139057057483, -0.21372506168398789, 0.05208230804635211, 0.87322225383444596, 0.54040865883807854, -0.41077150222081221, 0.05657444079775812, -0.23633447763173315, 1.0542828501034232, 0.76060064654687198, 0.99625580929097479, -0.52675858692093269, -0.45605019275503561, 0.87891072307433138, 0.4948104800458083, 0.80229790809512236, -0.69070329375801098, -0.047461880538010537, 0.69068708177134597, -0.5879379428837157, 0.29620402119153116, -0.19237908073904905, -0.81416467455182151, 0.35760542227386749, -0.16581489867201074, 0.25986579251023745, -0.093803331967315509, -0.62320592834295563, 0.79248051247943874, 0.96588699405964107, -0.15475685656717078, 0.40946837975349992, 0.11273271171010647, 0.48729229020215542, 0.64089963045130016, 0.97433512069129402, -0.33967549891189147, -0.82770144660407796, 0.48500038575358878, -0.90977899221961323, -0.094485907114847875, 0.84974270644313488, -0.80735818321351627, 0.19880161543630581, 0.77571124088633869, 0.52656688763162218, 0.98175480688643479, 0.044903404367690698, -0.37504852627344248, 0.49178061102470738, 0.32273965830846368, 0.78324137136085548, -0.44371932246119505, -0.70390364624921675, -0.17009881515238906, -0.8875916202772971, 0.024299312515455824, -0.023292850468653519, -0.93470961973786515, -0.26204361948905308, -0.49670175867595073, 0.70509353922771834, 0.25055812751630241, 0.075606587200745923, -0.095455249217886173, -0.3491360705268346, -0.36837948504351775, -0.027796106829479715, 0.35912949986253662, 0.068468152183093711, 0.17403351933627553, 0.86185766764612926, -0.082454321779899781, 1.0420488923789419, 0.47124169775125202, 0.79967110295428279, -0.049282853963228887, 0.046464730108933025, 0.34748375993853137, -0.8465440756563315, 0.79187503082842403, -0.60043045448390753, 0.5525602377435247, -0.13905209859321815, -0.02900791391766, 0.3732125777165427, 0.42171308978359195, -0.75446885038288425, 0.76625412434421791, 0.0087220137578173564, 0.33673503709450098, -0.027310025298102027, -0.38423873462354313, 0.00070089899572322266, 0.075420509413785614, 0.49617937000135592, 0.89268399802481546, -0.8552024904043164, -0.48236639823068966, -0.44317768471763569, 0.74185647222390205, -0.67652752168171959, -0.61710935481603335, -0.77256569998069091, -0.22589983657151147, 0.012854534916887959, 0.72974538535339284, -0.84017996577343912, 0.86470638154538271, 0.95573810338262843, -0.6264863076023085, 0.3541263374719209, 0.7178094450963447, 0.84332586291448919, 0.42208972187137173, -0.031318427624286334, -0.4493896054504839, -0.27631966854810919, 0.93222388999119266, -0.21172491421763856, -0.12578008259960374, 0.7226016864210858, -0.46067476146150466, 0.29040432145815903, -0.22258139743130623, 0.9020681469904499, -0.36094698664654701, 0.84611005199048495, -0.62702852411106758, 0.17951958233842552, 0.93831052068103205, 0.73713913161138245, -0.26620725459293015, -0.87153358271230541, 0.44664964114272876, 0.053260130246930659, -0.43149226378792149, -0.13763148211338216, -0.75468890958729928, -0.01177960251683241]],
	    [0.35174797545275283, [-0.29109564430826318, 0.3478122427302196, -0.1234032601996749, -0.25644359835809855, -0.18446556663561189, 0.48890102832009524, -0.30696571901485348, 0.30772785748889953, 0.14923357352237163, 0.97809462055144569, 0.55498827493835889, 0.071569849924833645, -0.72573075968283374, -0.15071978513859796, -0.5881703049313618, -1.1537780190993652, -0.15254111695196973, -0.66016537997470726, -0.62911026701765538, -1.1223342012299187, -1.0018101867970874, -0.08450394400861401, -0.72869403782170783, -0.063129132094779966, 1.1152569356146131, 1.0746861417088032, 0.47249560913855904, -0.30966664424880647, -0.957710135519657, 0.030462625882179406, -0.1849080629461228, 0.72258018893365905, -0.44458556598823035, -0.82732906999106459, -0.049427631209602148, -0.9877339273265725, -0.44909834808830451, 0.62323724639988076, 0.0069044991992823299, -0.32489278754654244, 0.30697129616969104, -0.38634606455000536, 0.33633000714263639, -0.9791171995849276, 0.60607581898635687, 1.0055559590781418, 0.90874382423493816, -0.73908347984782086, 0.78313754843905814, 0.27954344433855116, 0.10482724686033391, 0.25289085348234963, 0.48195895923733462, -0.90027295352094661, 0.26770075144918426, -0.09401200441118103, -0.556624724863927, -0.046808530828549758, 0.992871702742671, -0.69931607065781543, -0.69619308937350055, -1.163610965204241, 0.47845498852575091, 1.4757585404403071, 0.11549068455628743, 0.02372048669853382, 0.58556082461408676, 0.25732587712385296, 0.40127631892293236, 0.90905157444719198, 1.1748087855218228, 1.1048137307045038, 0.19299217088164436, -0.93771505872890115, -0.89022412013393182, 0.91833492771825165, -0.49860371899753553, -0.41922966879252482, -0.60450606201038937, 0.45581137360064594, 0.19732601916055861, 0.61886561975498344, -0.49263922084729445, -0.61276992476604275, -0.12402688619611138, -0.14519913016046293, -0.61495779451861732, -0.52757628701035264, -0.81195203921885528, 0.45588103800386359, 0.17106664670061855, -0.20641613614673773, -0.25394457271810578, -0.39107353506647385, -0.8463230439902053, 0.12000503229915431, 0.1486674414685594, -0.7807499707799177, 0.56925475946867687, 0.36296445000496952, -1.1223599059203908, -0.45929259685130963, -0.38460835789743153, -0.57621335694075893, 0.24705935842234705, 0.72486044011910411, 0.20546158817131768, 0.32031713921057103, -0.73089715265652422, -0.825395701385499, -0.52444111645771907, 0.020626502312278649, 0.89751154579322578, 0.89865711751086697, 0.38067540038510267, 0.046004882328892757, -0.40297294357000757, -0.11337225669611099, -0.58319861122433314, 0.094285819992345116, -0.30897862234592405, -0.76305377038776023, -0.3450111077800006, -0.60352585756903177, 0.19419209391346215, 0.006447986446205394, -0.17304667038410176, -0.46012330406235957, -0.04930424538440363, -0.45531666045414571, 0.93896553416464423, 0.92484993101831303, -0.63417324905190942, 0.45603825525370856, 0.11369445742772748, -0.022518845823545817, 0.26558509061386865, 0.16787518465282103, -0.081476655900191972, 0.02712323000536547, -0.53812733718255468, 0.37284270720667928, -1.0364215004146469, 0.0022062909075030099, -0.57418623886383968, 0.80799685155962286, 0.47421824438159377, -0.4312789185882866, 0.79164599912130995, 0.78241464220829871, 0.35011260963376523, -0.25057553508171798, 0.9064852583320564, 0.48923289468588294, -0.46832613040816018, -0.30977530581189078, -0.96563343164665971, 0.94589177593804141, 0.94316515604684481, 0.44323263579749939, -0.98175803466116274, 0.88162797524216363, 0.45920502297586552, -0.85867540149090948, -0.23495351659910324]],
	    [-0.44658524299105046, [-0.32781691223382897, 0.46833800367733547, -0.30235342432334661, 0.053177035885110663, 0.38706129961123997, -0.16587360440065002, 0.22370218627775196, -0.66959260959321065, 0.24994388163069992, 0.40158133209435187, 0.43769284079585258, -0.83689148008189929, 0.74042690582821391, -0.85037115579655786, 0.24727562876516473, 0.0098559622787029212, -0.28734955219520708, 0.71951034534830749, 0.59263053881544969, -1.0803841148997115, -0.46435303792106369, -0.44997977424578606, -0.80467533333272756, 0.80226768848644381, -0.622223968827187, -0.40013006945959279, -0.86004226042002874, -0.61676757765255408, 0.65554575335862242, 0.80524663296533516, -0.53876875211322806, 0.84005259809369648, 0.75710717111169412, -0.30567685668055689, 0.85400471756412122, -0.65064855045084646, 0.045789395269866466, -0.1152441882397741, -0.1176812364123722, -0.059926912788367537, 0.25792840663394745, 0.58356370033561145, 0.5398136334348691, 0.067816698167481981, 0.8482250379600178, -0.47810183942522211, 0.68148772722644768, 0.19341428871586469, -0.16740016294548851, 1.0931680206873671, -0.49428433539607441, -0.1205586293060788, -1.0482678591303285, 0.1126913703822823, -0.32521827267129377, 0.78308235307744123, 0.26211963329228766, 0.52511089953968937, -0.79359716829657889, -0.37680080274323413, 0.77423342336989487, -0.51416629249409784, -0.22540037114416489, -1.2825918277026298, -1.1995398630075931, -0.17176489341012885, -0.26752471118443566, -1.312118389977067, 0.30985861587292157, 0.29728637964365201, -1.1020604311494309, 0.59418521649858325, -0.36310089216113051, 0.95060501761442762, 0.14456150150868097, 0.12532339943890794, -0.57732632496748426, 0.35567512530374795, -0.29065303698334688, -0.75942176067150369, 0.72690431927911359, -0.82343877403953525, 0.323088264040716, 1.1291624420622346, 0.89846423093589667, 0.73048246190521371, 0.20755547195061624, 0.075923154763910289, 0.84441712126901491, -0.81681587237940168, -0.72514013612689243, -0.24332856690982313, -0.22274009757633098, -0.032738621307565718, 0.60250519818188908, 0.29641981793961553, -0.80017285974936592, 0.87679354420735867, 0.07736532671029582, 0.045258358359147655, 0.29451897374573988, 0.542075765736166, 0.76622599315478912, 0.084683814003935889, -0.36697719097677373, -0.59371882051810443, 0.47659312079088534, -0.20743316006601484, 0.23027056815301644, -0.70138902711493711, 0.18317711195636832, 0.42659136770358619, 0.5477190997672996, 0.79792635858448846, 0.9466273756916308, -0.015343698716386136, -0.20486757406880571, -0.39972689901426023, 0.16751717921554107, 0.56405876710789327, -0.71632768702885119, 0.1613843791284669, -0.77885889758914906, -0.52669838895920917, 0.82418703143612027, 0.20563756578619466, 0.080712272224280054, -0.13411815640718969, -0.88148029104263603, -0.46425795265971553, 0.55873726701557846, -0.68763172642893577, -0.86939256100466178, 0.27155564204081484, -0.39771302544312093, 0.076357477285204853, -0.39505350625233587, 0.73837476837115001, -0.35904264022992061, 0.59564654517451432, 0.5963415394000976, -0.52529226823766839, 0.8557982992891906, -0.27351900136233404, -0.1191744784886216, 0.90332230538627667, 0.75948982538499343, -0.29872471845602194, 0.56263801616712017, 0.41099318413599062, 0.31145248939581405, 0.54751096987280623, 0.33817350629842874, -0.070760795668829354, -0.039292517367178363, 0.26637815484829408, 0.41585980291446051, -0.1990984413464553, 0.50714744091212927, 0.47315586977571256, -0.27843194425420004, 0.55170292008807564, -0.89172506985981315, 0.36904885309605096, 0.04277487795867807]],
	    [0.02824428218972869, [-0.75821808563664594, 0.18773413937855307, -0.60761129325935848, -0.64182236367293666, -0.90088038424436856, -0.33460956875412895, -0.66905252912367397, 0.095692724593119768, 0.13416756905707844, -0.23512986196712496, 0.030862618167928721, -0.94339725399658947, -0.85237364315727004, -0.78482304245592083, 0.42461111303395405, -0.063708030931279871, -0.6079227582979897, -0.60800943891388382, -0.28847567128554852, 0.44513079063659022, -0.21027423425596131, 0.072212317268434439, 0.27021674169841947, -0.0025223956733523133, -0.40950016064419531, -0.7293132370444273, -0.31034768951290759, 0.46228760036004496, 1.018503763181051, 0.266287330722774, 0.12404684355313828, 0.23056540654554536, 0.19630375929111574, 0.65582375034241003, -0.70320309073717302, -0.24839121500140496, -0.71432054314596538, 0.3573573205554314, -0.028962231861232656, -0.69528009408300029, -0.54544521211514274, -0.4224761909983144, -0.53722787254646309, 0.37125684340753912, 0.14455472755023924, -0.73260653055030023, 0.61412121935287223, 0.65067620341119459, 1.1664664451423044, 0.032533571061268703, -0.2748824309793782, 0.3971368799030115, 0.38016273876666423, 0.049333463292522563, 0.84404051640712452, 0.98039427281880542, 0.0010577321976048583, -0.65663886884968647, 0.51662290464513705, 0.14977334201425552, -0.32869957564618296, 0.81129933998383585, -0.5433513317803178, -0.32245034191670147, -0.49898878477245467, -0.48955014985403489, 0.82763433336083481, -0.90712338861773489, -0.7424923718558718, -0.67612268146827093, 0.70858964287160542, -0.41920409046411544, -0.61988627964929399, -0.48973968932894352, 0.13186761408825043, 0.12356796887576811, -0.64102513496244962, -0.71635248794324669, -0.25771126516525489, 0.77120923768781857, 0.84312730428217508, 0.58640952368896671, 0.8307855648089344, 0.38987764425048649, -0.66280641163417586, 0.050297328272938341, 0.27136623601759369, -0.72765859365600583, 0.86335011642454096, 0.88526525843499715, 0.70452165990858462, -1.0006413545206831, -0.76892406390926471, -0.85318197296396181, -0.29969482610894621, 0.69858411762992478, 0.80569894014304777, -0.10433337848985273, -0.50730810540418547, -0.43055134059392042, -0.27085261993737458, -1.0238436827702266, 0.0035061849665413225, -0.19317649975921622, -0.75068835623607566, -0.83660447439807673, -0.65026329509175973, 0.63273216465618964, 0.81657316436146654, 0.48346745997405904, 1.038516895572416, -0.053846511904555354, -0.62079597138666953, 0.33740618846484721, 0.10204366004025232, 0.86297864369877564, 0.99544280698897447, 0.62146066719074078, -0.0025779300432051395, -0.59360776159536865, 0.10680729994280448, 0.46170496730492555, 0.22267938394997031, 0.038285974099443204, 0.59438888137064982, 0.786896123969266, -0.043374523610387059, -0.20551221143954121, -0.59754625029744735, -0.33580901752712716, 0.53643616208478739, 0.98185946005011526, 0.72984348427939538, 0.23875129653130073, -0.62588505258186777, 0.36912828443785289, 0.75026521234559018, 0.91481651771623673, -0.11051304956153044, 0.61519408016123744, 0.44516268111415863, 0.40494826308026122, 1.0504140551257561, -0.23608969363606461, -0.48498162413405438, -0.71230715037712411, 0.96213335406486811, -0.076843755711673997, -0.28306447484245656, -0.6225234369549959, 0.31923170212656127, -0.49911157862424382, 0.43886985733345385, 0.76608886109765606, -0.46121081867872354, -0.37370362401779078, -0.21161021882983372, 0.7447198118756061, -0.39757804835927318, 0.98539091168253945, 0.19754026013949155, -0.97400822593881986, -0.5274497037531598, 0.90245329733691482, -0.66652721242311852]],
	    [-0.33713704681087431, [-0.56603663136269566, 0.029656107530632622, 0.79129313294398063, -0.08444669814517354, -0.69691152097923104, -0.18708632040916945, -0.29989691912569377, -0.98776148079079618, 0.48358002061287014, -0.40429389309549468, -0.86205072878969158, -0.26658045906741268, 0.54193170832646531, -0.55645073612896123, -0.26517172699686986, 0.7439924036169604, 0.32684029128893038, 1.0323807039528987, 0.43262128741835959, 0.14655133322737465, -0.79565130306407872, -0.71200915311508062, -1.2014647429815686, 0.62006997026279853, -0.48070387495269307, 0.09991164430786352, 0.031552857367018634, 0.33378732578590786, -0.53209342268456084, 0.85314208850316109, 0.013333618302142318, 0.33289452079062254, 0.38529228928777159, 0.039137792023942249, -0.81899829250209799, -0.49998539738447895, -0.41581965521599662, 0.13692555122684658, -0.41977648574913451, 0.22117191870355488, -0.58060171449170106, 0.025336476118066362, -1.2307041674933803, -0.75783784113100117, 0.67480786102384882, 1.0285263871744457, -0.38723685809330244, 0.74348225296150439, 0.27394343968717788, -0.68441375134044524, -0.18966812608454139, -0.82938934734432301, -0.64986743304416794, 0.13085480272864908, -0.98673143601764746, -0.49709107449597162, -0.081361872509217947, -0.60943887979765865, -0.80107834861926319, 0.19070499134547303, 1.0283757834928644, 0.54295249953005886, 0.42568651540838448, -0.10885384644673077, -0.6244574244950849, 0.094562093557396851, 1.1517370017957484, 0.90661272956271866, 0.25995334970619605, 0.72515709861700184, -0.32046920042957311, -0.68328121058844882, -0.27984287636549959, 0.76447316039014979, -0.2562198554157129, 0.8552565850396423, -0.23173297093628653, 1.0519357111698573, 0.20197372233730751, -0.1000821530168461, -0.062141305826010539, 0.029547081545627026, 0.64850429716922886, 0.11540830900927722, 0.38059525101564851, 0.56973872897165556, 0.98434737974910436, 0.025999621578989596, 0.19719660684335985, -0.60082849632204205, 0.97669137922244809, 0.72677775522404764, 0.71574918678816368, -0.55620333687251555, 0.6178675589950432, -0.15290000156090955, 0.1396064872904893, -0.55946748020524095, 0.20533155653757912, -0.84137202248311094, -0.54630245497941354, 0.17332981663661276, -0.58222305476709446, -0.6726056368848462, -0.27809039430362975, -0.23312191532122983, -0.5509005134517263, 0.17252532919515462, 0.76368391381265377, -1.0399422219359531, 0.1462209349420944, -1.0173982150202558, -0.89245823472679831, -1.1027337452673529, -1.0186210905515682, 0.25720743052608902, 0.86695153491017674, -0.67701984522189829, 0.72083424812412988, 0.53058051945462226, -0.24896149429549227, -0.70389090504320151, 0.95985553199244267, -0.2581067339055611, -0.2295193281653076, -0.40039238260417265, 0.062710686872259461, -0.10247748465502463, 0.50684580093790499, 0.38813372937569757, -0.6894288470928559, 0.011795339213356995, 0.11624145318796324, 0.077670508313711084, -0.76973244882631864, 0.083680728481479824, 0.53647296226225993, 0.32755507111014281, -0.092606223991271955, 0.32328580274825802, 0.1764504323730326, 0.20223691814934902, -0.82084260392473385, 0.83484689653239474, -0.51064738835567847, 0.41690192728154646, 0.033614560874732156, -0.5653798154412113, -0.86403201984880851, 0.94066907591916626, 0.5150036124987617, -0.4079279723060899, -0.49970579979833546, 0.84765335015195409, -0.47871458083428159, 0.078557206919426428, 0.19191231512118551, 0.86996931833410818, 0.0078300074610821203, -0.79581760439159566, -0.64772487647286625, -0.63236452149204148, 0.97133162109899684, -0.88880812090988037, -0.90654937650305389]],
	    [-0.42234011030834095, [-0.014707742881614942, -0.31076105358226014, -0.64385617607566847, -0.30265934177244469, 0.60540194943616743, -0.13142386182652277, -0.2856305094989347, -0.066062908800832501, 0.19701178931778479, 0.46859372815707662, 0.90809184229590623, 0.34629086409656501, 0.21947734226074003, 0.40483200939650721, -0.050086349766075511, -0.40759832539588586, -0.22577040143751412, -0.1406773822639649, 0.99465786383578736, -0.21415487451111623, 0.6634543458565465, 0.69500288120727838, 0.58556855044604661, 0.2540030259638193, 0.35919299953756884, -0.28432590659256124, -0.15444958575565984, -0.77166565089150185, 0.56080795634069869, -0.2330418696919323, 0.50766269837826239, 0.35693887099647692, -0.49605964128037355, -0.62213410332891417, 0.38502365636699193, 0.49610546252773685, 0.67338374790206601, 0.50242228228480046, -0.16487379000592955, -0.23162432984003165, 0.85138337335668213, 0.61602366096864258, -0.63853844272898752, 0.98106831979494236, -0.74674636720603149, -0.30981998791478016, -0.43663160096239467, -0.38074939813817626, 0.33140001146483544, 0.60827685656971309, -0.92059426131818356, -0.030151470146847697, 1.103752622256241, 0.41972132408617902, 0.074615819868481509, -0.86014244671697937, -0.37637782097939737, 0.39362701756063556, 0.81034894730506735, 0.96313469917707861, 0.052362997944345784, 0.6782860792914942, -0.78172897047340584, -0.39400515174230588, -0.065501125361468349, 0.080300533811363803, -0.72919739771673675, 0.031704700219835076, -0.62959458242644872, -1.0496099213762555, 0.39886499488068355, -0.59704997262732307, -0.32812161770223258, -0.024826433105673347, 0.12235386287521344, -0.17982889203240091, 0.15088400304443375, -1.0836973662070131, -0.93063930958752183, -0.16760514709419955, -0.46763588668874617, -0.72934636922209739, -0.26912533330768329, -0.23711122627071812, 0.86226467877823254, -0.66565233410791103, 0.85269045567607415, 0.074046329495417604, 0.91587556441811602, -0.035699284091069705, -0.69673035449086751, -0.41968556918112793, -0.69195880832387968, 0.2199493699584798, -0.23008156187837381, -0.055749515586609004, -0.47167239723628346, -0.42497125959973153, -0.76072497796929017, 0.39736869991179036, -1.0314502890823103, -0.30780028980590274, -0.85782819343626915, 0.86843249641211351, 0.17561709418461377, 0.29692539016460939, 0.16105794995291137, 0.22563781952258075, 0.55033034695877769, 0.53478863720301317, 0.94811535402768654, -0.7206878992404453, 0.44612942362844493, -0.11534541327692004, 0.45220386828666198, -0.84348246645127056, -0.66243784323506694, -0.73145585758860432, 0.98261286906768264, 0.51296231220174071, -0.53113185572965282, -0.90559576204030712, -0.67361767550752849, 0.28045775221761626, -0.35862191653551234, 0.4195132258422527, -0.30840009889266079, 0.21029557965261172, 0.32234410695773841, 0.87018420917380379, 0.0088966678872482857, 0.36244782941860398, 0.067340434421531342, -0.10819796327832977, -0.00043286024130566618, 0.72495282765120495, 0.32886540456865643, 0.48617576331644613, 0.46828532233729103, -0.11103465454667964, 0.9943253691192866, 0.17713612440750337, 0.03908997543162377, 0.090421409517254775, 0.2262703832211648, 0.35071542695897884, 0.20291589049300482, 0.41575036032337032, -0.26523769525489294, -0.2258013485622159, -1.0132147438861603, 0.48237198186725433, 0.7481225890845411, 0.82571513716445311, -1.0389940465803205, 0.26574615580133004, -0.80322658926149904, -0.56365006225914038, -0.41174606138459074, 0.64823710956357572, 0.072517927053074249, -0.68661131962711131, 0.81697362649733996, 0.35307394877631793, 0.89708636044385792]],
	    [0.65796227474115832, [0.59188492600951148, 0.45855384848405861, 0.26675681459474976, 0.50609676051186991, 0.88741843625938732, 0.6326093440432452, -0.13997109828848642, -0.72563867984098807, -0.66446459836461713, 0.44629278330521671, -0.86067648666172936, 0.89930397809233098, -0.35971229758077511, -0.22817941402476394, 0.49275372577952292, -0.38173591286599151, 0.61084109649626916, 0.15603710817855485, -0.29583713638978848, -0.045592561620584261, 0.094784365898817571, 0.61576019030532891, -0.65191861001888685, -0.61757860686353994, 0.55779017133342557, -0.49161541207247372, -0.15041433118406311, 0.78454263169901584, 0.035348943274087816, -0.35746798232100208, 0.56725119183922146, 0.83956937879994664, 0.38968857420564612, 0.29076457220829977, 0.95961636846113618, 0.81829777472567888, -0.19128674326936423, -0.31592650519897136, -0.40636050101775623, -0.21172415087163607, 0.25150585155027255, -0.28719880594116709, 1.0380661994364784, 0.62372651858995631, -0.99738831719325494, 0.29490279767122962, 0.56604096569826978, 0.39548588123195449, 0.1723122101444409, 0.25130793156788411, 0.44009559370177204, 0.63053746544957356, -0.34759659835508638, 0.007795290802642481, 0.73308445722412974, -1.0756459022369367, -1.0353111203411125, 0.61505437108636918, -0.43160905398712457, 0.14750401507090727, -0.15295877590578227, -0.13402002177633224, -0.054154441398742856, -0.46348429767947597, 0.78204692926689034, 0.35059040508273798, 1.0647699660676502, 0.053613602206457098, -0.016087644138605597, 0.24701115129640869, -0.59360752672071715, -0.63912025828199237, -0.65988866081384034, 0.75887938881650363, -0.29647092308983503, -0.44940439816614791, -1.1410190733241399, 0.48863060706375239, -0.38746496943216169, 0.74538578020169788, -0.13784613555680095, -0.92626261107549779, 0.081118903981318824, -0.077570538565630884, -0.3403760573164934, 0.90212647958298453, -0.49947764748658552, 0.29035474911236941, -0.108679955833184, -0.037973708289678276, 0.26185694994274011, 0.49140625903196383, 0.30916900884712817, -0.013090556162331733, 0.043471403564988596, 0.40996578104422271, 0.38817728784050698, 0.426668242784223, -0.76428405122634624, -0.18075362639506273, -0.51799781847750015, 0.46635994823052473, 0.14749390833459317, 0.93536270418253942, -0.25511417173550877, -0.84811734022407426, 0.036699012228659886, 0.61167278369134903, 1.0120921915420604, 0.42503687220302944, -0.14494726758339974, -0.84001847100228844, 0.68443758655103137, -0.40210613547786084, -0.95309222905551949, -0.4561417109185385, -0.65645995541727364, -0.12855231880235116, -0.45975588814639934, 0.70275073317369019, 0.97771351992854183, 0.56117372133968479, 0.69813614053405704, -0.32334016767996815, 0.81311830499464, -0.80628900125064484, -0.40302558440247249, -0.53829247223494414, 0.97072161707083682, -0.61832216474447854, 0.66767491256536293, -1.0059132722670685, 0.66501704692993557, -0.24439946820794253, -0.70415347476920465, -0.15290273773375704, -0.68509956750709622, 0.76755599039912759, -0.91060370999406637, 0.15989517456670868, 0.83496219893135237, -1.0921004022098486, 0.01853929565842025, 0.3237062597335022, -0.21990577792322255, -0.96648935176343653, -0.9233034085829197, -0.53963086109141167, 0.70519498517664925, -0.77814372252387254, -0.91357835637929119, 0.065705942392870129, 0.84240922969692844, 0.48569980926388301, -0.76082875448084009, -0.5745024888811211, -0.26410968026610571, -0.83506974699620851, 0.39894720977681414, 0.46074238388654565, -0.11287919204860142, 0.29958919265009087, 0.1585285099792737, -0.29361057057073459, -0.33425779770223829]],
	    [0.29401957646870497, [-0.82645477402977974, -0.51619944988262534, 0.62379366403049152, -0.63185406268584943, -0.45505913409530685, -0.21087605038749527, 0.90009275522519028, -0.15132177154282364, 0.39704799789735962, -0.071656713364047012, 0.37383442136302958, -0.36018323299025484, 0.89517581138907509, -0.05762420820001668, -0.62704660853788474, -0.95378282666870551, -0.89189005377649999, 0.1901943744801409, -0.69488494530779654, 0.39844574691636953, 0.79932338899853117, -0.74764701084826379, -0.75794598843468297, 0.61927582832436467, -0.061343043889626157, 1.2602731487206824, -0.45288323942559872, -0.099795123640404354, -0.20607029636394558, -0.95111655523654348, -0.24443816471425678, 0.29117719528440372, 0.73445918486811412, 0.51088503096762228, -0.42713624757785518, 0.5080391906636007, -1.0034086291155209, -0.23886878890587529, 0.87914834603593439, 0.1383585374182017, 0.32523113122278086, 1.0090052519086719, 0.65459601439447612, -0.35738125940522802, 0.90124842335501487, 0.74065955073088197, -0.3505223964111151, 0.43082208508570918, -0.77985156076032847, -0.83332117075931211, 0.11360018181563505, -0.11389249420898787, 0.86569180565556725, -0.49260749181297858, -0.19941155672612254, 0.76826562149461608, 0.54746871708080203, -0.74260853027655926, -0.85093906767019922, 0.96807213250478985, 0.039019204226223472, -0.090562000516023325, -0.58111435730023808, -0.46760865132998114, -0.18750084179475335, 0.46963226059231122, 0.28350878153163167, 0.22941272692685472, -0.26249548388392868, 0.61938643984759634, 0.35990120810589749, -0.26016404966114631, 0.91117733508730292, 0.096724728166171337, -0.044789893729395125, 0.60554097549364005, 0.20169442837302898, 0.1039727569309206, -0.59547748718909155, 0.59976569220881504, 0.74341618014977873, 0.26730047090658265, -0.82407494735768771, 0.47145240375888475, 0.48458862360360333, 0.50284000499012693, 0.60009480285622607, 0.63844917157583825, -0.32740130215159063, 0.40246764343225605, -0.21242265737505045, 0.94210669988132867, -0.8183845883040648, -0.43186304990068292, -0.52957194119657558, 0.33949143828404404, -0.024210640086536648, 0.13114311275718155, -0.1658888011769051, 0.72666578338800847, -0.62224082823790539, 0.06504457432804038, -0.63079987535208215, 0.75836848584064609, -0.39860010083413877, -0.0079025332032179318, -0.36760729639801937, -0.09636531371861326, -0.78631219533910646, 0.46681698086441914, 0.7043356423817978, 0.8386228129852169, -0.12919054101746894, -0.68552206375021596, 0.01325807841205898, 0.92057871024941085, -0.5151960705799894, 0.51280858982814648, 1.0013160537281061, -0.3053186251697102, 0.48942791799373547, -0.18546008810408879, -0.31275935955679318, -0.27442136288497199, 0.45217675288706322, -0.85655758807419935, 0.45916620585216983, 0.56839228508604267, 0.37119520900015196, -0.33599263501474419, 0.41470987008547755, 0.48869699318609505, -0.97243890969893532, 0.4059651148290086, 0.68476030105565966, -0.52929688092291227, 0.83080546282286361, -0.44203903115408827, 0.65079027479446816, -0.39044585303027546, 0.58407268506508614, 1.0284999311144296, 0.31614442424653716, 0.35335951741061628, 0.5364588528530253, 0.5487268057801844, 0.13471832098740552, -0.82818508305861449, 0.98536879021054169, 0.11078194654917239, 0.67762663045244553, 0.98540008790876732, 0.69211819687222764, -0.61132765108588161, -0.041439040796812994, -0.8185137514434333, -0.48221129329136064, -0.34958554220509475, 0.29053858560766244, 0.81892395056450296, -0.061197227026386081, -0.54142235460699761, 0.33003382301698703, 0.80946004721767362, 0.47044774404056144]],
	    [-0.81793439182683736, [-1.0095862214865701, 0.5221552009471474, 0.60265501880387307, 0.80445941495083806, -0.90170430665584023, -0.4866031384823602, 0.48023303258592337, -0.3451645388432647, 0.15656319752563122, 0.32509486724890369, -0.65033349658079642, -0.30542003982953342, 0.99496577782818629, -0.48233232442213025, 0.10914200955946218, 0.5881341326543299, -0.17637115657700211, -0.13755834885267448, -1.2728292187875097, 0.15240864843281082, -0.20385753824457314, 0.055739485878481175, -0.77664137174886527, -0.25183928923593318, 0.55092891906090691, -0.18603302639505923, 0.50330491979370973, -0.34380263867902799, 0.98163245653872233, 0.19526852839957876, 0.12077549833048531, 0.29025189317787564, -0.0054734926919091965, 0.37884737548003783, 0.31889432206646134, 0.33216197601886693, 0.78255957666098852, 0.71728458459644329, 0.021859206274816651, 1.2233040481355006, 0.52080531825573206, -0.29013482315856193, -0.37138453130391863, 0.65610878025809594, 0.60662684175007198, 0.73500478648516032, 0.4963935454182013, -0.41870161011762286, 0.7258994435278544, -0.93231715142421756, -0.048500041209455967, -0.70624583006892339, -0.73531569540883079, 1.2565854301576753, 0.98024792832276275, 0.47518511794643592, -1.3527456752054272, -0.30889605205798887, -0.29476835755028158, -0.089550143463968057, -0.77569272792752997, 0.67414883713668072, 0.80401166040748384, 0.6881022519088057, 0.53584365713658766, 0.8851183276724307, -1.1893963552239826, 0.72397565359232541, 1.0215400426428367, -0.10495517020364419, 0.77144547398956398, -0.28795389532900395, -1.2065408261964106, -0.63603475253192199, -0.49167340624685241, -0.58354887225055663, 0.32150555616049042, -0.45943797777323825, -0.12455041957799269, -0.13196911958877572, 0.60548941343792484, -0.61813667503772585, -0.4740731348135967, 0.51150769812694641, -0.51063108171874283, -0.32437789044017995, -0.89516109684783773, 0.54213145173372224, -0.82248579531581367, 0.55243158556944905, -0.018258831890355574, -0.50948737293423307, -0.7161360946797295, 0.027381683790055473, 0.73181778796963692, -0.71533276651188504, -0.81654456269483155, 0.10303195294856331, 0.46648718296707381, 0.80432337837213719, -1.0675872260381516, 0.32048072146284889, -0.52052449993631478, -0.45857990071377364, 0.78936542642811913, -0.78100826879393381, -0.015565024595325881, -0.92377800182659897, -0.29834759744853623, -0.87214102428895224, 0.064719760070585636, -0.22106733149022506, 0.15997610712193636, -0.51432778497737341, 0.15872464180742257, 0.42999919452566959, -0.66282686353348963, 0.91758714161426669, -0.51608336513452346, -0.56617769095606008, -0.54296504475649476, -0.87350618216140308, -0.56908418709883435, 0.45912821308423635, -0.17874599267057925, 0.6100042091349489, -0.2183389459518163, 0.30545351191596659, 0.6218823622977161, 0.38527080941808028, 0.86916759594218218, 0.41037413083386642, -0.33795913319646459, -0.2721979218070249, -0.9650683830091501, 0.9254456580421625, -0.34737489725847065, 0.73613434092350694, -0.93239010382026144, -0.95945155341963573, 0.8777506969325497, 0.3720289925144396, 0.76281867583006091, -0.014451317214224445, -0.853495838886693, 0.14883461233267103, 0.14498886831559635, -0.19757136882326168, 0.23115718900236984, 0.72494691652225596, 0.31741458425906738, -0.0032419938608731322, -0.27534820253627545, -0.18825997939421102, -0.58300600219579823, 0.69679948346183718, 0.55901980794072914, 0.23878418627635839, -0.90687596069676857, 0.59099509249241589, 0.63344878826966311, 0.070130858950110175, 0.18290717571611093, 0.52768637488206505, -0.41564539146554802]],
	    [0.12812462482383408, [-0.9462034398135496, 0.66522291736031525, -1.003494662121545, 0.19958006723050045, 0.41828806787028855, -0.19832585848525797, -0.649747832915471, -1.0156623862047696, 0.025916508852743686, 0.21125447900161504, -0.90469058328115903, 0.071470357795650599, -0.39006578761369198, 0.47093610700760502, 0.11028512617098141, -0.57976025530458009, -1.0710498537383386, 0.16489237664752993, -0.093404081873499717, 0.53923396902876664, 0.80344641591300825, -0.014152375725809827, -0.80330158473746482, 0.44938976711472506, -0.44360092372206944, -0.22695497775122001, -0.62293384816447439, 0.030379457357437169, -0.4240716449947271, -0.1483808006248386, 0.78108390388621085, 0.14631429368500978, 0.6063556514644356, 0.016604429241851404, 0.36980258704458013, -0.75891977965719637, 0.8341977815140369, 0.54049236644269905, 0.40362389119829617, -0.99038848495777265, -0.97968319965881545, -0.16224493820674571, 0.36607568615728464, -0.14668446600914281, -0.04105742256084266, 0.70391853828632178, 0.61672174193057405, -0.23861757233116032, 0.85898222218508014, 0.5454553108476522, 0.65431228189564661, -0.42828616187881352, 0.32608230967833535, -0.4271480104818558, 0.41797476205096851, 0.86402099248263398, -0.98028081127288036, -0.51843365244501693, -0.8519902524666334, -0.75409590000515903, 0.73265477443849247, 0.2912566061260819, 0.3672404115476563, -1.0354643737151912, 0.3814209785287595, -0.52059044651096875, 1.2141178510978172, 0.30655877866392828, 0.50067793270599981, -0.39363545628419699, 0.28536269297703259, -0.56322518175824465, -0.60128216656666178, 0.34165368662697732, 0.14222643976724636, 0.83492646778477242, -0.11450562306489935, 0.083308032273318025, -0.66549876561775101, 0.26325222935345738, 0.51720209315426502, 0.77279644547528537, 0.95711139716705307, 0.68586924219554124, 0.39664186131980561, 0.70408185263033773, -0.80370417894022961, -0.42460617871483708, -0.61501288752277139, -0.1635379180527643, -0.096509852155939893, -0.02214753941854521, -0.85256651246206483, -0.52354482799099233, -0.9141421634265593, -0.12296328319654015, -0.08625646594637186, 0.42258584437569746, 0.93184857447340819, -0.18980606850888673, 0.011531731926028015, 0.19919909747009695, 0.94667363335578614, -0.041848608932591028, 0.60762011277624517, 0.37646163556954149, -0.77093383403537585, -0.45309734512633043, 0.64080950855351182, -0.69384151095083235, 0.37612641758817028, 0.031851125813435112, 0.16117069293908717, -0.94031688758019671, -0.20726332483776447, 0.54918595202504239, 0.49853657848359856, 0.46578198829333439, -0.9103645072828016, 0.57032435901958711, -0.37660430738519779, -0.13500532408009999, 0.28475074953245039, 0.87098919127503993, -0.33291413524928209, -0.82952781183594715, -0.35349490023514396, -0.33404974960960726, 0.84055994925626942, 0.61075751259961675, 0.35504236398546307, -0.56536028830635243, -0.63148936962250146, 0.33173267519504507, 0.04992041308657709, 0.82564910314932694, 0.20630823486458641, 0.75041360723381889, 0.22220952878972969, 0.07066577236645169, -0.34561138915920042, -0.68860922878234854, -0.17004944941825381, 0.99860799480815132, 0.41507542011442217, -0.33376308524333292, 0.22787781609245808, -0.76534848448299686, 0.85898696779789574, 0.087662510090541712, -0.067312751913001415, 0.063058266805878116, -0.17776368418164032, 0.72240553781046091, -0.27709146771588483, 0.31393467097898964, -0.078002249226356832, 0.14975398254656111, -0.50125821844390617, 0.16781548815739766, 0.66178700392915446, -0.62165399894032425, 0.72067371827603455, 0.27624116215841132, 0.94235457117630328]],
	    [-0.90030298971175793, [0.3742495290581444, 0.74350932964484262, -0.26505805827689066, 0.50315992666199338, -0.53848031324994927, -0.0065924184859059275, 0.062437440472659374, 0.67849521191918516, 0.30181034394994494, 0.56557314950318593, 0.91822163845848614, -0.64913997196840956, -0.23316200675772131, 0.13980223976654016, -0.33675441237845005, -0.23048451459030422, 0.43947900558185116, -0.66777548066250469, 0.74921284542627831, -0.31085128603741286, 0.014871717557110928, -0.79112773891542498, 0.00042222665603808398, -0.26998565139667469, 0.12454041999889236, -0.29807581608025491, 0.12252284325660363, -0.40283079650279413, -0.75626602149379007, 0.40982311795143267, 0.020038601432279986, -0.47981054220190772, 0.65015496407080053, -0.55248056838041859, -0.090121047592203324, -0.21643183283159673, -0.90842783660240001, 1.052349876963858, -0.089615780147858176, 0.21127471877033008, -0.86979274310598098, -0.15856493439286887, -0.21752145721094185, 0.62833727034424214, 0.030106621676263545, -0.1603185248148952, -0.87171803122987757, -0.78384568328605009, -0.72453400306710858, 0.84894372235663362, 0.49907901718203035, -0.23103253967298976, 0.89847011294677892, -1.0604642882025903, -0.65147844902057828, 0.59203070825986148, -0.14747307937974913, -0.29689770310541425, -0.015964282477464779, 0.66057992320679926, -0.26379740489030368, 0.91432841456717329, 0.1966963800458722, -1.0271027539332598, -0.57494660214504412, 0.055458782986522404, -0.18689669421202373, 0.15523974738530424, 0.58747582436631873, 1.1895756568495053, 0.68654922066139135, -0.083320493479186034, 0.7624067619792757, -0.77551375700184855, -0.40418922128246071, 0.22598824379393179, 0.13989547770394076, 0.065900484370830709, 0.37432275269645149, -0.7379227124870541, -0.20484353794577265, 1.2302853810323546, 0.11497914210423982, 0.05366864484390356, 0.25819297088635479, -0.035018391501706041, 1.1061932542694748, 0.51990818384888693, 0.48385109593510917, -0.85066042226827809, -0.71724283887987839, -0.2338911376814829, 0.92483550062043662, 0.44094915905619891, -0.2009493388444617, 0.70392122361867993, 0.029042533512414086, -0.33192072748632501, 1.0465817952885119, 0.50132151490590127, 0.86100582362442124, -0.10521409752122066, -0.12032677220773454, -0.82001022736853291, -0.8544756215401621, -0.51328149559671055, 0.69581409184246246, 0.55145135409972024, 1.0369506025201112, 0.015843598309774897, -0.24595541528291401, -0.78271164269647864, -0.40513612874529992, 0.14695860761628593, 0.09083984484315058, -0.59823647990825868, 0.27592829766806076, -0.35468938645212222, 0.0023460056367331163, -0.86914666757599324, 0.6143563989913231, 0.32944255156492908, 0.1217593089049392, 0.14640253952450258, -0.015239978232388226, -0.58532928437591913, 0.34395010433529372, 0.29391965346112847, 0.19456865736076187, 0.21496807837489534, 0.29894289922494544, 0.23921300536781401, 0.27098149545164923, -0.30780766616510996, 0.60708231220895237, -0.82220793405728199, -0.45247876342453863, 0.76526471839272203, 0.10125220097201597, -0.65155205693609197, -0.70205848288202233, 0.25502237509454573, 0.61182214500866061, 0.016126425687545021, 0.34415961774883402, 0.62358752631073788, 0.66293843540797392, 0.18131290196157823, -0.96589438101946068, 0.25688764877852699, 0.043203042906586726, 0.63656952661916644, 0.50442596583876365, -0.69318915393135094, -0.81999325633928588, -0.72968010335643563, -0.70998805596050696, -0.34908517793941163, 0.58928489361178693, 0.013827098490025724, 0.34662885594101822, -0.67195662390969879, -0.13472936366414134, -0.70191730464002311, -0.26515524436032245]],
	    [-1.0844193378138438, [0.45667797732190635, -0.71282271756761928, 0.2820842150665136, 0.54627653962785172, -0.68071789139314198, 0.5343541948280206, -0.50107680274104383, 0.79160439456254295, -0.5925264909859369, 0.38704067249405022, -0.51865508889496648, 0.84003822641775217, 0.1882525344006189, 0.51432872205567359, 0.74099764827380743, -0.71150424656215661, 0.31357711695804502, 0.28124238051322609, 0.45255610598512558, 0.037186044578844529, 0.28697291543503806, -0.63362380543529895, -0.096359024777434979, 0.40592256841409108, 0.27928722596822869, 1.0005475718526557, 0.66331363902701346, 0.47154792202512053, -0.31224931827408753, -0.45149187286136216, -0.22680552082171895, -0.45619529424239813, -0.70448517593332238, 0.71229394282232439, -0.60990274554931656, 0.41521481203648997, -0.36722136360298813, 0.033795422393101703, -0.20607564634464978, -0.6313674869493594, 0.11199310803248856, 0.1522225803893138, 0.66908386264401687, 0.09883490993724188, -0.41615901423252599, 0.27688816389326926, 0.94024271835139039, 0.83036654210577898, 0.9604982730789321, 0.40977666131951129, 0.34121971373663457, 0.32609623901370366, 0.47444187650412045, -0.21895072560604059, -0.030326738986643686, -0.0082303126839167757, 0.1413995952928668, 0.51662226365660147, 0.96316470893283224, 0.10093412607473118, -0.70798728234018726, 0.34071764051311937, 0.79681665012808889, 0.59496609522929922, 0.057292744106603698, 0.18489092582010452, 0.76658511799016316, 0.98618056156620981, 0.73629981081272688, 0.31946653431008643, 0.2603306072329773, 0.19529471786559652, -0.17330279251004418, -0.33111983071545614, 0.38361153651701585, -0.31620555398180655, -0.36033068342110358, 0.52082434367922603, -0.82074728344884385, -0.15890317586995936, 0.96375197744117891, -0.69110096790778752, -0.19323298317800627, -0.862172112400868, 0.44523778159567817, 0.090451984280601, -0.30277607813934315, 0.70572217310489238, 0.75696526682310683, 0.76206934083369648, -0.67282591621373689, -0.40872483716779645, -0.65990557315453902, 0.54808799988141244, 0.18388365832875575, 0.84561721702383086, -0.75081617911940524, 0.87750493229773141, 0.9442600234759887, 0.12620810706528948, -0.74424470948685673, -0.10889963397462946, 0.72386413512662084, -0.40433687940175111, 0.87740531077418304, 0.79666750123708607, -0.83098537996255251, -0.32161085533288181, 0.33207283404667748, 0.58338753443383684, 0.24364530567134637, -0.0046874534788096571, -0.16670625113549667, -0.59971881893655898, 0.8313438982291359, 0.49619045264588418, 0.17812568587213731, 0.078772224208144517, -0.93426267144274844, 0.58579834040953938, 0.91862488259585884, 0.37508230070013648, -0.87758968436557927, 0.36492656397013462, -0.098678032692694775, -0.74864427068706307, 0.26982991137038148, -0.35600464098229584, -0.12973249149994051, 0.70572926797871161, 0.74801636996269572, 0.38416800657769123, -0.26900667245889726, -0.21929680687818046, -0.90957142154946791, -0.68229228491609617, 0.25082219221536761, 0.89965039284317727, 0.24674824575314605, 0.44280210550767324, 0.93674426636121488, -0.82180303276582722, -0.55740079659021291, 0.8445173753877866, -0.4226760359061425, -0.38085429222270623, -0.10281108162909319, -0.6615233477695236, -0.060107071686947268, -0.67041569255318478, 0.33640814810825981, 0.43749510263655045, 0.73210769650435736, -0.83381970988934828, -0.78903786761712813, -0.42660025618051278, 0.94114189159530115, -0.19297242564240805, 0.2105644737721771, -0.61306770170325664, -0.15147839578799305, -0.75106425739876004, 0.48717686387681347, -0.54967940802048898, 0.85131988037494422]],
	    [-0.84163582182226238, [-0.44864102372505016, 0.83049093370915561, -0.74102470638545415, -0.32153815111770973, 0.67390747784849703, 0.41462491010367969, 0.87872261527670792, -0.31945953374599423, -0.8227996712677399, -0.73759926950962917, -0.055310784100471862, -0.63087331726452534, 0.69288533632627103, -0.16098568284290438, -0.59973246996709006, 0.64831474540530998, -0.49481652689488392, 1.1350345092668228, -0.7459121282161093, -0.48198882066240245, 0.17645648653031665, -1.0337525027933361, -0.22276264916202068, 0.50001387311906453, -0.02055267229764126, 0.4421448767250315, 0.68342885121187225, 0.1694324646319858, -0.31830259771657604, 0.21380550274110366, -0.13242088295880397, 0.7057289176909296, 0.86003754654840725, -0.95505485870086826, -0.43606122164461286, -0.5869608297636788, -0.71344510056113952, 1.3110081711454806, 0.93841734105939256, 0.87498705931158938, 0.41198596431537904, -0.052411957990983235, 0.4073671156659448, -0.21713162931051266, -0.26212725485479282, -0.0064384877426635016, -0.47848283049446805, -0.49912239777024198, 0.21839287308869504, -0.57536712539630919, 0.70518881743833239, -0.46750340681521058, -0.3038161940242165, 0.34089781299468369, 0.52627032152714825, -0.099140722209178175, 0.84590206148808422, -0.71799884218814214, 0.56983546832711129, -0.86161768929867777, -0.53966497224280041, -0.76314144213920632, -0.19990794776391163, 0.33041276116871482, 0.76338520522004194, 0.3471323299750394, -0.60125526090133363, -0.14561145867153211, 0.69947058245959448, -0.60678435571855061, -0.15955131140247467, -0.27077745719956359, 0.12338639724822978, 0.49346926276439279, -0.55215875931905889, 0.67623281612980668, 0.45015148620808937, 0.5602941198996122, 0.67473218085718456, 0.066848720444058068, -0.050414787704429649, -1.2098720917436074, -1.0704942638167882, -0.23252512314288931, 0.39275983857996988, 0.055107543172931768, -0.094989230285473236, -0.54814468088964441, -0.2653238982886007, 0.72344189536107795, 0.69542593663286389, -0.58107753237877802, 0.040840882210752015, -0.29017551244183576, 0.94148099671345897, 0.68734978032732608, 0.17878251453010635, -0.36765910119621475, 0.86137118647122279, 0.16530276804322314, 0.93349822829327023, -0.37372040900986142, 0.18201868686724029, 0.80403074529623697, 0.86016565843825699, -0.054188633035199149, 0.7651825696486293, 0.26589464128611412, -0.34291683367445008, 0.58730803509494067, 0.1278641391370316, 0.95242367033563635, -0.92222756597665312, 0.56527564035397482, 0.17609338654883278, -0.64546619811018568, 0.6066889273255075, -0.80673458867554937, -0.050087025509495398, 0.52353178710633896, 0.5914950696283745, -0.63686656434050504, 1.0330475884069426, 0.03178029062869582, -0.29677890499908649, -0.32390191900701998, 0.86672435021288374, -0.078797070105256425, -0.13955921118873579, 0.9361030995549412, -0.94607506960721077, 0.13465449870335414, -0.97388812467316688, 0.15852556291749839, 1.0644314725226638, 0.93373728664440214, 0.84462797229652908, -0.13928827442917471, 0.56933423298218033, 0.17246919996626353, 0.014568853767769374, 0.50726815920536583, -0.61305212378246554, 0.87799143480136022, -0.43142714831408113, 0.86790935570556049, 0.18873617552787764, -0.90307849874108648, -0.15761973540145766, -0.73606566129097994, 0.34117835528156371, 0.14767976941150218, -0.24381795564215397, -0.23814072030192718, 0.43701188556487391, 0.30375006659817988, -0.38014571783221063, 0.0023363749179784463, 0.15133262316611509, -0.41938953811668145, -0.10531448404052468, 0.80472548343686334, 0.95491108281023429, -0.9920026863776179, 0.92846067406072263]],
	    [0.8532925121940903, [0.22649319794048003, -0.40388673363990546, 1.0717429226896547, -0.24548997503356332, -0.54916514142407669, -0.75584083996690099, -0.53944130831726689, -0.065686358072881271, -0.44049352122283547, -0.30157782210453066, 0.83121014886800715, 0.56568788152283778, 0.062536469451107649, -0.42225380304639804, 0.2631535788629511, 1.0903555859990937, -0.44562622685757564, 0.11978743836137516, 0.82597643874561244, 0.2226584346422423, 0.98318641142006535, -0.48908468129471799, -0.40623642829012063, 0.75478376317232654, 0.75934857629186137, 0.24571508439130979, -0.061629408365813189, -0.58527543113765568, -0.37439948724333449, -0.54373134925884492, -0.37319369462764251, 0.90641680335013064, -0.94061726327796413, -0.39853066427679334, -0.73650741970161404, 0.12364029035297604, 0.99538348570471258, 0.58611953763556102, 1.2596541266253738, -0.067179690847671544, -0.12911762907992547, 0.019990897537994209, -1.164317899651607, 0.18726339264161973, 0.82126524274342949, 0.40770539948324941, 0.28714946165313121, 0.5919641150762317, -0.057421961605623816, 0.29904706800747372, -0.071722655162244325, 0.49826927337781107, 0.65123934642881143, -0.90079575655324629, -0.79127917436537953, 0.25132495889720829, 0.050183334355468137, -0.34547827156519489, -0.19016607151612006, 0.34324002956653921, -0.40522437356600916, 0.48301660989132472, 0.93370334646836695, -0.29314687175699911, 0.080108368011790942, -1.150601669624697, 0.39120056069109632, -1.0671649307668847, 0.16471893937892004, 0.10572875735067272, -0.57810187329179263, -1.1798071482111858, -0.35934159285578288, 0.47818511104596945, 0.53221246691690149, -0.025812002240515435, 0.32400632272272745, 0.28987410442590866, 1.0973493680885618, -0.19155082057921105, -0.18111500144002379, 0.1551186689426711, -0.081528373598405576, -0.21849810240796727, -0.68230879176668957, 0.10130006004556537, -0.58425121591691387, -0.1437170408435049, -0.36651795199570086, -0.75862076135437673, 0.58975282239927307, 0.59014798411036562, 1.0344479158010826, -0.18466925215829075, 0.51453219364916691, -0.27713045023970778, -0.2541764923534911, 0.098702539085362404, -0.37343356020240687, -0.12329398598299803, 0.16605074425220839, -0.74597552373772558, -0.070538516837534468, 0.17582836230370624, -0.20866549488826816, 0.92816943534389618, 0.55875922198922234, -0.7403192039167954, -0.4929566550493556, 0.88993927631674452, -0.0044441908241584279, 0.3764571867170482, 0.29468989074890073, -0.16828667741449732, -0.72383637673601853, 0.61446387350330578, 0.061819697548290579, 0.036068942325338596, -0.74522812541261008, 0.1663125667655532, -0.48606632478117479, 0.47348713674988424, -0.13667306305908314, 0.095035183582411004, 0.95894163946733812, -0.13167138105479023, 0.8379174328021588, -0.56534574545528038, 0.43693261479618117, -0.79263277888980577, 0.14061352371876129, -0.50008539087576687, 0.5195688600815288, 0.43374899049275289, 0.76864723068351426, -0.51290508403064872, -0.48153469129634302, -0.13885628710460887, 0.10554715586215047, 0.1019543109415552, -0.70932438223059568, -0.52525336468841288, -0.96390030454467024, -0.29383175346518176, -0.68550716557981195, -0.082706670745793368, -0.11682249657239745, 0.34989779261655429, -0.53337284502654381, 0.40565626532817056, -0.81876814006163856, -0.79268785553248611, 0.47335345744299873, 0.92315872715703207, 0.94636639199058215, -0.47863097538190774, -0.34783717244342721, 0.67639595214044523, -0.99438443159822376, 0.27146768438412283, -0.23173406513920436, -0.3022930165189508, 0.19345155723316876, 0.59340094280846922, -0.6748493152261974]],
	    [-0.18358928142759753, [0.096312154810500025, 0.024884106738058291, -0.63725505270422866, 0.5355785306965537, -0.034282541293195856, 0.53435741000435644, -0.59236771688552226, 0.31039995409939375, 0.72333918914152484, -0.012530221845593492, -0.14049200329938188, -0.40667350451969464, 0.20690854886072707, -0.087341473336909781, -0.68176939077231857, -0.036289954705278495, 0.16394277162107271, 0.48228293188712534, 0.090982255594097824, 0.16946950334911881, -0.13337007549770136, 0.81748312673508539, -0.96523532186697492, 0.015070454584439882, -0.66966215418268848, -0.9902519555527548, 0.43203833280769827, 0.78378555106204795, -0.54791779167722454, -0.14231577199161172, -0.018764966304387707, -0.615973701924595, 0.22109285541654189, 0.37086920408624202, -0.18176542867584614, 0.031186396327117723, 0.019962659066873296, 0.0078357357223856929, 0.59156131995324757, -1.1140223778221507, 0.014911426848459784, 0.53262086173604339, -0.083554093358734177, -0.75402854084685222, 0.88574772314615013, -0.12971920289279265, 0.0030442752103803697, -0.3607569540740227, 0.70451383424907466, -0.6418815997727102, -0.2800682872104272, 1.8203667804321342, 0.28413428266624779, -0.9600141358217813, -0.086175289162635949, -0.22286245301125368, -0.14925235603830364, -0.54693031173432582, -0.89984958086723621, -0.16258046248529867, -0.36338267499821747, -0.26976050911925648, -0.77549074076440228, 1.3180506272520172, 0.38229716144949027, -0.44086923307169423, 0.74363322159967749, 0.64567666612128138, 0.47119003775975127, 0.20275517553226396, 0.45644876659205857, -1.1445445260928475, -0.92198452879909809, 0.30317408492249803, -0.61854813017652432, 0.95496411160785233, -0.55190200770931008, 0.56295856128877253, 0.89809980686796387, 0.41667078090496701, 0.41835099157647432, -1.0367034279685541, -1.1406648034118043, -0.30755782083082039, -0.16763784717958075, 0.95174735132177324, -0.95590381293810733, -0.42371032313313556, -0.7299761577493008, -0.3256043138338327, -0.70439303239496598, -0.6905646766506105, 0.71706046624858999, -0.56745534741964476, 0.3715809641220717, -0.57998728835406432, -0.50390612666259726, 0.17795090502835237, 0.4518207267940465, 0.49615555520608251, 0.40646670056734707, -0.53401227753143998, 1.1258610567963048, -0.58782733874274196, -0.85117967449664922, -0.088092983341020545, 0.90907619527856165, 0.071100178939399183, 0.65956756358158597, 0.32501896245143902, -0.27173502566216201, 0.44627412177446346, 1.0310636190726217, 0.7423960128290843, -0.16291075717592921, 0.36352899788070464, 0.94915468090308264, 0.49213011843386906, 0.97156598168361175, -0.68976615782099193, -0.35278049281099821, -0.030923562759541806, -0.31184017845553991, 0.031754383601412348, -0.41740486846256381, 0.52307387479207434, -0.77072004659155724, -0.72566717670045777, 0.43797620037959006, -0.019032044237492107, -0.42393365352639678, -0.37009671810326011, 0.52735137854607406, -0.14800198237391929, 0.32945619081948196, 0.25135778657980618, -0.53386056866809073, 1.0066029518404258, 1.0259815046966263, -0.77485424332810726, 0.14826245490541093, 0.48153348598948192, -0.088330709364289647, -0.76691903016394758, -0.69272054945558303, 0.029245800072416471, 0.5771532207431842, -0.78059638476448967, 0.69677835463082194, -0.84018452965212909, 0.20041909566552818, -0.53607991119467813, -0.94638372401001214, -0.25780003633800497, 0.98003126253283024, -0.16916538240860124, 0.50573050846504863, 0.82357817335875261, 0.45351820379037988, -0.57571873733287515, 0.060806955002258301, -0.66859024856769445, 0.6907595529037851, 0.48315109716387106, 0.56764271916240228]],
	    [-0.55544347049505005, [-0.49812216094360179, -0.5642388572029795, -0.0009587170280014513, 0.28632078574819148, -0.22446257818063275, 0.045875023330513368, 0.011025909037161377, 0.16385145334123596, -0.43097010029659955, 0.70336924789662159, 0.35463614872829513, 0.36295276334496446, -0.23775337970069993, 0.084604402304794046, -0.7011055917218818, 0.79152363501538414, -0.14363629555847052, 0.15772956628185186, 0.97945613905602524, -0.1486678373797016, -0.21377383770480834, 0.28176303794410629, 0.23441976270132892, -0.19850678951068007, 0.66144945440556491, 0.7461659188290316, 0.85035700846663831, 0.33346576696951186, -0.36718340362566404, -0.58208215472480518, 0.015495546764732152, 0.44259836007132675, 0.83678437847915588, 0.95929854769194256, -0.061345698073015487, 0.90770377204754937, -0.1281409898498653, 0.28773419291621444, 0.38763698992201878, 0.029774204617563364, 0.76265815814714444, -0.31382529142918592, 1.029743191990603, 0.15134646962697443, 0.18080014320723792, 0.03502988147480416, -0.77295782608531871, 0.87385009068918928, 0.53457193480662391, 0.020172664680141863, 0.16447304889260572, 0.4119985424433108, -0.051022923650440796, 0.75775945159102476, 0.71977377215262028, -0.30765036140889757, 0.60980848989701752, -0.70974397438626446, 0.54004252057171787, -0.97147397570592631, -0.45236376418918817, 0.85100007106392839, 0.28718502370158805, 0.15362104456595135, 0.66518362133682785, 0.44751871189387882, 0.1514961419573749, -0.31608764877985224, -0.066083825351501257, 0.39839212187052925, 0.7332913684394009, -0.12355254163485659, -0.59158738501119656, 0.27735788548164292, 0.45646577614280082, 0.18221821186673151, 0.41849324483075478, -0.34080589632119668, -0.2185268795497918, -0.020627006268109999, 0.47914406802674042, 0.11106575696294552, -0.044941897406003718, -0.012041900346417882, 0.91947771263481581, 0.74494980391470045, 0.48135146945554053, -0.63785298899933396, 0.080359630855088945, -0.11912671520190776, 0.27698895221705472, 0.77792680727989694, -0.63709763170101574, 0.19192900744633801, 0.41351689526654528, -0.18181992574355582, 0.67223739636844104, -0.6020839601670841, 0.23328988073092141, -0.28554501268731969, -0.029994424040205577, 0.76858722228921084, 0.96607733666499152, -0.98521441891821138, 0.46372115517720802, -0.601290594189828, -0.14705567996248883, -0.48310083974641294, -0.83090460047592662, -0.85853206553029304, 0.75173191944955575, 0.75599316308640663, 0.7265076656167011, -0.058756374132031115, -0.60475331430500545, -0.31073428434067951, 0.64093492705136956, 0.57256450404604453, -0.23312517959055995, 0.021694327841984717, -0.33427883083718751, 0.5379741887204601, -0.36173482856072664, 0.21433186958425274, 0.60519728261842554, 0.92507099273059357, 0.62940046230254687, -0.55696122198845466, 0.69247735163625168, -0.93496702301432388, -0.13672214269735175, -0.48791752217383827, -0.1601757274385118, 0.5640194428935158, -0.78557134925423255, -0.44724843239657824, -0.69400282319596351, -0.64980310006417275, -0.26708983217905763, 0.54715718727331097, 0.75185512317968428, -0.073629606456428395, -0.038592335790977671, -0.018817053901235573, 0.084950802314705226, 1.0093098291495797, -0.90162269446484822, -0.78274444581701441, -0.27682180667445988, 0.2957214911871775, -0.15271702986268795, -0.60539859034611709, -0.48727852789764869, 0.3186555958430965, -0.12926642069900807, -0.61154455869868296, 0.3387081221035278, -0.53198384910851093, 0.0026132684330780146, -0.21317320998090428, 0.20821824958598301, 0.68713836830791486, 0.50471322132443697, -0.14338300836641582, -0.7030822146408624]],
	    [-0.85196224477952431, [0.070638116785462071, -0.50383542860676278, 0.54293250677751792, 0.18286804582208582, 0.81548329706096545, -0.067801705091509193, 0.54147169306218679, -0.72747599071885027, 0.73868692396058999, 0.72066699578158744, -0.95698573082195026, 0.63028070646457002, 0.073998550950020142, 0.49064213394155609, 0.57014783834125038, 0.81837794074345105, -0.25788022701877106, 0.15228603119031681, -0.97203656687241391, 0.16199846443389895, -0.26949492806298825, 7.4312752692443668e-05, 0.46504592902728265, -1.0330303545531703, -0.078882112297398596, -1.0241930032011857, -0.54646816999062586, -0.79245376867461881, -0.55921304060468879, 0.22601979553399443, -0.85033656871370411, 0.30744942134426867, -0.0019763319403658729, -0.79756110149556247, -0.53984644915470115, 0.74924895416196613, 0.47284706212167182, -0.15020408051016768, -0.25848392103691897, 0.36507597885146759, 0.30719385822380813, 0.065706860967064531, 1.0373120365662694, -0.99141702583815838, -0.084280454822599937, 0.55708188129254832, 1.1307344435228326, 0.40410987982922941, 0.98271730354474318, 0.081857198716863935, -1.0031090232593811, -0.26201130779212245, 0.50789330355094098, -0.17417485218834475, 0.73695770705235109, -0.24204774931201808, 1.0284551942526596, 0.982920327139298, 0.83540094450219937, 0.61094910773271249, -0.42130627876052185, 0.91328353177685739, -0.23436612632809298, 0.67985896130399126, 0.24407750972380007, -0.57359243891675105, -0.013334273469161943, -0.6658412846645011, -0.54978535861986122, 0.33838623324290734, 0.50184119859067511, 0.31420292730988131, 0.76478648867833487, 0.073356667375792883, -0.40019593828740918, -0.8832904873811207, 0.22812519439410356, 0.12287156118158077, 1.0213159742802527, 0.71593250345068271, 0.38596600491152933, -0.079405571082711041, 0.36412997996086038, -0.80097830916471124, 0.46700796478158851, -0.044936977778508976, 0.28192083335685841, -0.86505340031218714, 0.058543920778659907, 0.61775742941575706, 0.26756194789148652, 0.65806576884332468, -0.65025928271792344, 0.60454109905134756, -0.93636518323266693, -0.85546416910454004, -0.33090903244462017, 0.55407334813132336, -0.40467511274321133, 0.60509829332653808, 0.60448303042915441, -0.44554064674837141, -0.51006898139021517, -0.75177541601908526, 0.92092460089964545, -0.22434914226485472, -0.01111759085052604, -0.80989701796400193, 0.7332383416892968, -0.96914658387493602, -0.74045563014341731, 0.17584037654722376, -0.98501451505454629, -0.99827472424331731, 0.21344918464268134, 0.78820363404634297, -0.33425143046072647, -1.0473631861492252, -0.74853880822675178, -0.33993076408603057, 0.32395712344432304, -0.9115959546302328, 0.014750428654701829, 0.92938050436387343, -0.6736980412020489, 0.9059099637979241, -0.38447050065123411, -0.14061083372488101, 0.42440991435955611, -0.15567750914031098, 0.94021492786941252, 0.82188634989125542, 0.4879024896593489, -0.45060258618711968, -0.52788753615141082, 0.37042133701121788, -0.57692673279487239, -0.35074072890874691, -0.18212568894898576, -0.054605759030901237, 0.68109665519902662, -0.54506856882889332, 0.2906797692207877, -0.15509215666519949, 0.34168223928114672, 0.95641988942896461, -0.94699734498390009, 0.61119627457537129, 0.38138948899947939, 0.16157963674630071, -0.07920124887312624, -0.53871654207661046, -0.60428472428122204, 0.38919673388793846, 0.37623315123254453, 0.20665355017618944, -0.21997795906371642, 0.074175345135191348, -0.98786753511602121, -0.37688030293456842, 0.58215855875290234, -0.46166864380820671, 0.88217328431226116, -0.45803552773268263, 0.91031525720391615]],
	    [-0.72057562385972884, [0.78897042217790614, -0.018469835015737526, 0.16972787360325695, -0.12205390480732964, 0.19363480578218156, -0.095653280746229877, 0.021355858096147828, 0.88182132695238491, -0.65135967354136703, -0.58322375603192489, 0.029699191910615021, -0.39410263137640905, -0.31699503309654453, -0.67680384351391032, -0.73601515491505953, -0.53234649264504696, -0.85407641104559329, -0.15934242192373918, -0.90349473015623161, -1.2457319576314869, -0.13714317805351933, -0.7339772149608772, 0.39971573374931674, 0.3514453508215778, 0.63011012321918425, 0.46123856468935187, -0.48428009053078608, 0.64093325871739004, -0.14258416418339714, 0.18898516030461554, 0.11763881961850718, -0.41601197594958883, -0.6348480017515078, -0.50559116112476965, -0.75891562298554838, -0.29105545815200989, -1.1085639187200635, 0.056684123795636601, -0.56515143048746852, -0.6651137145462378, 0.20183146928798976, 0.39960579388364087, 0.46492087705360313, 0.91318333083981029, 0.066220427671150883, -0.3269918134268131, 1.102698566576308, 0.79874298031010216, 0.040894832180424924, 0.01445676464307174, -0.075695178339150071, -0.36113316236490833, 0.44997751109194911, 0.076856920034298434, 0.1823275177126864, -1.063261460160037, -0.54679564499168776, 1.3098272513083824, 0.088314557515977887, -0.53359060318372609, 1.0721309935184016, 0.64570683047303357, 0.52627799712193368, -0.13075089210843319, -1.0398169204499033, -0.035969507370916982, 1.2242530996414491, 0.039970666256734684, -0.18686881676686062, -0.38598984128496022, 0.23987412495731392, 0.16377107257192086, -0.15128127856458851, -0.53423426601174173, -0.80825055961293368, -0.40902013702832868, -0.79612753190039387, 0.43169914278053606, -0.27317009428805622, -0.25791221979664347, -0.54598415636901743, -0.79712827755539117, 0.61245232478714051, 0.52121033302578801, -0.47929585667670821, -0.021874657377381642, -0.74577918745564997, -1.2285368548897453, 0.36809619333592486, 0.30647423450651212, 0.15517605407913368, -0.5334662977551532, -0.78273927681991418, 0.52835698309331658, -0.62111706246804099, -0.6122487208462809, -0.040697438253291682, 0.76413179915810481, 0.24919365222082868, 0.68543990950096634, 0.62090296055241112, -0.80830208550650662, 1.0453547937466168, 0.90414592065885357, 0.096037223126574742, 0.019140878122867036, -0.68533219058850026, 0.73507475958077495, 0.90201467999810214, -0.48057668351063604, 0.041620111432085327, 0.68094375159222276, 0.32468730863763584, -0.70362586944845629, 0.14988745817172994, -0.41974312122650054, 1.024470934835626, 0.19715997603684937, -0.51410904261748103, 0.09168929294227067, 0.33217325700038719, 0.52361864164324268, 0.61127703964862168, -0.26417757688495225, -0.011635018213529431, 0.12242406422044143, 0.064404286796615168, 0.022284793732999207, -0.18582773902184696, -0.42397507493606162, 1.0246651129510271, 0.73886158434192606, 0.99086221901270077, 0.87322349154799306, 0.97053246493323109, 0.36497872823519989, 0.87269800395206498, -0.61909208439896612, -1.0295798307594171, -0.44340969039770711, 0.34233884397530961, 0.071185502979554685, -0.82598819642128429, 0.13784473430198838, 0.46337577963684939, -0.58711477413054602, 0.61841972350501528, -0.23379261571583157, -0.26086748875263593, 0.21616220935145436, 0.66145506599523407, -0.48377435524766227, 0.19182557265202818, 0.91715047525567706, 0.54491213615314282, 0.17915102608436709, 0.86878704358665537, -0.74128968867253842, 0.92659951040293032, -0.041262044324928304, 0.39537361594754095, 0.46211419885940574, -0.93465039236878189, -0.42469078384355163, 0.9442674548062775]],
	    [0.27766629784021069, [0.1444860080721464, 0.6581396510384907, -0.77527318985074123, -0.63096768975780304, -0.47655930306758443, -0.48634334671881363, 0.28583393566413573, 0.64922342287417412, 0.67652294469232399, 0.61124751626696927, -0.45823843084426558, 1.0108895009458894, -0.18748416358839104, -0.12915264781175417, 0.37036693960549405, -0.17694269456708125, -0.83585802599321968, 0.36614069017143314, 0.81215953044715306, -0.86296668034840929, 0.004939818782723389, 0.11528636279953458, -0.6172539247294293, -0.44964641221363527, -1.1212147792796672, 0.22721363057412466, 0.25304199826021445, -0.72918410960920399, 0.60827699749177011, -0.96144754310033553, -0.20809308477214364, 1.1065041562312119, 0.78884527263632198, 0.41043543428806234, 0.73312004511964712, 0.51057231482544618, 0.1118351720301813, -0.29014142814252414, -0.05626783255732714, 0.77582506257237061, 0.47807471150653341, 0.053418769871784046, -0.22803597067187836, -0.63882874507172804, 0.74253896797959817, 0.96493022528867434, -0.7950972919466327, 1.1573581770054371, -0.72730135724351452, 0.58019081733003164, 0.96395687347315107, -0.14761318546813842, 1.1781023234077759, 0.077106386179753655, 0.38135473446228207, -0.71010639825744692, -1.1665020693106323, 0.23969982807781975, 0.99000611117053761, 0.34032879399111038, 0.35327857988655065, 0.49254881902136322, -0.32073405635831193, 0.50743096367987583, 0.28462163213123332, 0.32701400216285903, 0.1666951448341224, 0.65140142324912798, 1.0032035278694036, 0.27842190417151907, 0.04603558097758529, 0.36986407591749865, 0.22071375199640589, 0.043361817025872183, -0.67058208750207227, -0.46548233988594429, 0.10688642707292732, -0.015181570874381304, -0.22650163694943279, 0.95813807095580017, 0.033399274589266566, 0.7327465082368384, -0.066477266020970732, 0.97340590051735809, 0.19448121463221357, -0.90451052612439042, 0.74985442126214785, 0.63952477949808018, 0.28484867134613984, 0.83662660441176695, -0.37642208251648535, 0.1831169256541671, -0.59991442865941724, -0.096118407324019897, 0.26786947138407091, 0.74220710471571361, -0.23902281541689102, -0.053943654517743363, -1.1142882894779356, -0.47847217932648889, 0.013951156470110884, -0.53430560189377185, 0.086623299507538221, 0.11464151872354375, 0.8628243038955915, -0.77642561544404354, 0.84417388039994024, -0.24111493639913167, -0.41157728870133986, 0.3177412201950251, -0.54075578037085681, 0.65197575174683364, 0.9005816709107487, -0.18475379446060658, -0.77496532936709472, 0.097528534352031127, 0.69847317824982824, 0.71042696026516627, -0.39261781207731472, 0.63807161197882478, -0.68059688878163171, -0.79742841869885628, 0.090761029138027888, 0.092928384392195446, 0.81499502177588112, 0.10141173290603785, 0.82765053118475329, 0.72510734938758292, 0.52642871517886103, 0.39064284651798759, 0.58896075331872311, -0.30184735983095501, -0.14432386276742362, 0.86550798337459467, -0.94973197621937755, -0.67839873365418479, -0.19830612653644883, 0.33169529860698937, -0.15518014611456069, -0.39172621588683149, 0.48591264377135329, 0.21271193201117986, -0.52092538400424504, 0.23531699736020026, 0.1025645702380415, -0.31326280753561681, -0.24015467076958222, -0.23547938801658039, -0.36941449308239899, -0.63299572220575739, 0.59472569510063811, 0.94143535527670108, -0.67356986643351358, -0.43402964278256312, -0.21085988765687858, -0.17917404220503033, 0.68347566514782365, 0.75946729932385126, -0.7348399254941359, 0.11054691248844684, 0.68045365308309003, -0.70466773952967943, -0.0075425601360716854, 0.73570366161954537, -0.56323680177151503]],
	    [0.41114075536227157, [0.92804428920279336, 0.73103671707740736, 0.13378399197816082, -0.50065300413495051, -0.52312523787369947, 0.65484635491733123, 0.071454032172570597, 0.5038743079656931, 0.24824536387432719, -0.021523399670532087, 0.16343251050219632, 0.4145179874608298, -0.13763007306163286, 0.73871628070469897, 0.50783612734653705, 0.31102302815929261, 0.20469949542324056, 0.5688381251800918, 0.4440543341374189, 0.51067283593715662, 0.95288244232260633, -0.42680622392281276, 0.5675919423270388, -0.052006725852216225, 0.49059698313701416, -0.28485206306758698, -0.78875120782130614, 0.75866826779180629, -0.51300084837283999, -0.81245252185567618, -0.44041851602855731, -0.78946407146104691, -0.41340013304446466, -0.11072773871402358, 0.33017269372425445, -1.3950410693309419, 0.7604348179470769, -1.019465290035207, -0.23521418577621681, -1.1568004063067874, 0.46376002111945758, 0.8386080574782715, -0.9555888550534114, 0.041259243552738079, 0.067836745417400257, -0.031435964503219567, 0.11901486149644887, -1.0227285838492837, -0.12932224035494741, -0.8869833352284493, -0.14776343791586835, 0.21907549455665018, -0.10541029375461265, 0.31551790768170701, 0.48734085358688023, -0.60081975264461329, 0.74695449256618318, 0.15422379327650571, -0.86426334048748621, -0.65632440537623316, 0.85455796824797214, -0.064401608888572728, 0.41697705879109964, -0.22989718268189846, 0.49473886755687096, -0.30129144767273819, 0.035581051600868517, 0.091511531391525611, -0.29720927552315363, 0.80678076191574311, -0.50417875644867793, -0.67778182567375933, -0.15328825309494368, -0.33267311328924543, -0.49864096220275678, -0.92627297559746347, 0.29309761872742457, -0.50105832524402261, 0.81855514425034448, 0.070487976803099581, -0.49962906501823001, 0.71130337990460457, -0.62757298173673359, 0.0039804235250990088, -0.36229552762938794, 0.53325476825323903, -0.14344320591294316, -0.39116676355129593, -0.95264742361490728, -0.53629701720758405, -0.35474164419742199, 1.0327344304471255, -0.60681147599871221, 0.73038691508327336, 0.98734476553898975, -0.80127381905096329, 0.015478633089425028, -1.0587337590769657, -0.076488475869268602, -0.48592113571867673, -0.61265619887701017, -0.73466943518195893, -0.41540006617754072, 0.6457091939111389, -0.090776923472133508, -0.49239776242307448, -0.078827791401898176, -0.69371404592097463, 0.16081157004190264, -0.74273573732916798, 0.51068044383827249, 0.1311197019719772, 0.8559034662995415, 0.80320206610318257, 0.84520302323827468, 0.19465827733449326, 0.64521283362254089, -0.84198620256147283, -0.12284641898196121, 0.053795412022016938, -0.77916130933961825, -0.11784105153611919, -0.6834641889893226, -0.58513465062396475, -0.97325162829806189, 0.6197203343978247, -0.34789361974382876, 0.8403599339295369, 0.66024368978564318, -0.70558877586790136, -0.86081804876571277, -0.34770480742156762, 0.093076803285418397, -0.060091444565579792, -0.20198617828853643, -0.85768982811018779, -0.331023400737189, 0.52678899961024683, -0.55864084203903919, 0.33129830178418729, -0.63764042921845943, 0.6984135367881128, 0.18367558412398907, -0.47551524993754468, 0.84974451430026787, -0.064687097231236959, -0.83572581628490827, -0.83897398909595455, 0.46692869674728016, 0.88066345072513297, -0.53274202924404468, -0.30862770728124678, 0.47814120644108099, 0.48277396989907378, 0.66538245906501892, -0.41326389065950947, 0.39666068536909088, 0.5906712936675752, -0.84380094517931348, -0.40591598296682263, 0.38724830408868449, -0.42874369444696536, -0.051748887576972047, -0.49509577270270833, -0.18191383106031456]],
	    [-1.2760626294005888, [0.26062451663405967, -0.043503585938122181, 0.57103383494711735, 0.094165037685934719, -0.36340175876846675, -0.91621962749890584, 0.13283436586589256, -0.16172905240544461, -0.69441784558832642, 0.20175034114014992, 0.0079964541285300634, -0.0069824564073936255, -0.63583397499600125, 0.90610419829318545, 0.36285287728826265, 0.83691808750369512, 0.38720974218638643, -0.5685588098119253, 0.042448479941330483, 0.041429670735233855, -0.3715427217113384, -0.55151308767042873, 0.059053306237311094, 0.36483163070577879, -0.77645983877757163, 0.82101961094015752, -0.075843896765237853, 0.54574385484596855, 0.25754855505326307, -0.56962993584656263, 0.40058825688826105, 0.00054396730825165274, -0.605606446981652, 0.30281480827317203, 1.0108805141761281, 0.63511931288008994, 0.12200368373580064, 0.33706160413823866, 0.73366521277979302, -0.086121642953072577, 0.67407293604624363, -0.81048181650237006, 0.27800080425398599, -0.27311293055830754, 0.59073088842117905, -0.8433811536292255, -0.5057911613503685, 0.32766900988446851, -0.71367966599922805, -0.5607322268855045, 0.18327657336239983, -0.051195241105705988, 0.81170323789618626, 0.62444876434787644, 0.33524736349466011, 0.66295590249998093, 0.68712961797469552, -0.58610510507056313, -0.8429539591786398, -0.51978688373234827, 0.7794556159813858, -0.39982099354109618, 0.08451054479593853, 0.56232971442409208, 1.0431664113329557, -0.41936857865535782, -0.89294387474733206, 0.068569218866748535, 0.10119048648216462, 0.055314659118565639, -0.51359646187134778, 0.36557877052229149, -0.73073561414834132, 0.7927360698910626, -0.25398412762074485, -0.72606957211261736, -0.71908256614607258, -0.51607906399065351, -0.68910061055237559, -0.44177528137955169, -1.0957117853093854, -0.82468726099540346, -0.81993168493052593, -0.58066290756306371, 0.29826998046717329, 0.74290489192899056, 1.0038271540834631, 0.62823329298872332, -0.041116369803440203, -0.44896023385731376, 0.5734873399596534, -0.10964531633980519, -0.55707704374793765, 0.10684943258203085, 0.61132747658581543, 0.70318254227937205, 0.2358499349271711, 0.27888044064062295, 0.3585230501224273, 0.30362996492577632, -0.65033616132907746, 0.9932323978998896, 0.59971605457592303, 0.47945765295846055, 0.97169291194002483, -0.48782005173584614, 0.36714774412147755, -0.69514378009510791, 0.28561769401180009, 0.77828405194652928, 0.87828952193847853, 0.3269126639236648, -0.31289817030969941, -0.28105673014476468, -0.51123204875807271, -0.99274463318293493, 0.29382613733521851, 0.90484201808700337, -0.76742734418655889, 0.25508709799502588, -0.49208144540640963, 0.88046267267437239, 0.16711940824013208, 0.95047808549904678, 0.86840872735668118, -0.16045022285429972, 0.66065301273125421, 0.78220483469941671, 0.18972423503709474, -0.5130024013370732, -1.1202895125634944, 0.48874988692385896, -0.96101179185726437, 0.61596616275432381, 0.40171998359163125, 0.014877675880626365, -0.53110980640056893, 0.18090262099827115, -0.75074905032065054, -0.34095443879235748, 0.91910651953312594, -0.36202492808554315, -0.24907398080530724, -0.8730886167041586, -0.093218625304155464, -0.42961866832091472, -0.41120548041613764, -0.75541870560873414, -0.55334663159697106, -0.45940357951032107, -0.50446993604455037, 0.0069380503443419077, -0.23777505016305123, 0.33685880282635317, -0.58177745540624048, -0.51769354754150321, 0.27416548319708001, 0.94535416660870308, 0.92530842371056554, 0.94813217202868927, -0.87957833163753429, -0.40795162721220679, 0.73752243339010848, 0.87009839518108811, -0.6766578224031774]],
	    [-0.86199421175786883, [0.9263970350520262, -0.2810349178433923, -0.18471010199494511, -0.54591364496734029, -1.072623959501052, -1.0401268745409002, -0.17315818898033811, 0.9907877894327366, 0.011428712716018226, -0.67329310248930507, 0.15155305008457415, -0.39689197131118059, 0.21963814033905926, -0.78392185507995649, 0.30944391836790963, 0.21811233471645811, 0.76187034036647072, -0.29727263457687825, -0.41659668771577302, 0.56651669808430571, 0.27088566749664583, 0.19000521334913142, 0.019600039779302702, 0.89358023959533384, -0.60961218063405331, -0.19819092901524751, -0.5710686819985451, -0.31092119602204465, -0.45241619179014431, -0.92284454553504713, 0.31140152734013621, -0.7506852735059264, -0.67045483417066731, -0.27943402628988356, -0.17904534155107651, 0.53770915149304499, -0.40205000483844378, -0.54786269978574664, 0.075035320233881944, 0.47389218895355667, 0.02800523549661969, 0.69605256368950785, 0.87696187004931125, -0.055767240558625968, 0.8964645561691138, 0.90670992994789923, -0.66466796616671042, 1.1345706788565684, -0.73248620140202236, -0.66392445290835012, -0.29945294420187651, -0.65984861815149509, 0.30168472707359689, 0.74223360227476132, 0.31140635424755009, 0.66472379600120257, -0.19788989064193316, 0.77487703360807669, -0.95001941700324244, 0.10307880461615171, 0.60798841205426046, 0.60315315139371672, -0.18348922663004066, -0.25086323785980108, 0.7374774917766439, 1.1322795147384166, -0.012402790952046697, 0.31290669949848327, 0.50677634713588149, -0.21711909385854977, -0.044671359142810681, -0.68160752875072639, -0.60839762494079175, -0.77631136381821508, -0.96569488381165902, -0.10645869400356213, -0.16527789170200255, 0.31711922291868061, 0.054313924664385838, -0.056772494636652175, 0.48770832682106358, 0.30744887727921927, -1.0088363597650933, -0.058549659671728281, -0.68178168261320571, 0.14586379651637688, -0.020903159800476346, 1.2422908849225522, -0.28035905136306, 0.2628646754389603, 0.80007498986291103, 0.36869389091821692, 1.1144422828420504, -0.28920112602357284, 0.40413155103686588, 1.0334936559389214, 0.46266739084880493, -0.79984073422182111, 0.4387190083787248, -0.88227996683579746, -0.83720125041871885, 0.23100432301353221, 0.16281010936871168, 0.53506841452467846, -0.24291512479741006, 0.1236458170256307, 0.50893178335212885, -0.13996121954314883, -0.82099420004329682, -0.13425777368940023, 0.94845719775719772, -0.95074181299280169, -0.12307110228715715, -0.49539155739732138, -0.76801885229167299, 0.40434658533634416, 0.51496779741367094, 0.033258706266593295, -0.3825927256231465, 0.41933372111252565, -0.98731999998600684, 0.8364628053803439, 0.16294151697742035, 0.11067089139725469, -0.1004027085161376, 0.16316939773088093, 0.93856203380403602, -0.57258973848101136, -0.60244256043054378, 0.31673720456348792, 0.25207160402279666, 0.28422510024051445, 0.068224036653669717, 0.40639466723296108, -0.6344577144867396, -0.34604504998265706, -0.26992960329869575, 0.51333229729941121, -0.26141302879077988, 0.32002150390132261, -0.85589237693238873, -0.32627639380214801, 0.93640367861753171, 0.014774503550599777, -0.51982877413257889, -0.28246990863832139, -0.57049741444131841, -0.20337898730577436, 0.74965945336542417, -0.98727258726722589, -0.94014991461310859, -0.07510326734491006, 0.25915510669468689, -0.55737494288789491, -0.45911646838573839, -0.25409275488628646, 0.43455382824108535, 0.46697479465227743, 0.22238142897509997, -0.31836069077567131, -0.47222197151666201, -0.81704630810485268, 0.88958395889744857, -0.98228811148485273, 0.58940077608591479]],
	    [-0.81575019962678275, [0.67411156795904459, 0.64256792108546623, -0.78635098928891556, -0.75763948055229413, -0.0056400485896870769, -0.32759995516617973, 0.17498558584263843, -0.76729274399727199, -0.5012987638611236, 0.19513486044037906, 0.15085797855434535, -0.7383227214167849, 0.80317724630272003, -0.59943841826879196, 0.51544231047470102, -0.84394481201832816, 0.10023886189458904, -0.36070225975714265, 0.11894230826601643, -1.0201904849270269, -0.67207497881841816, -1.0148860689205614, 0.30042340102672893, 0.8003824709179852, -0.092315551546498065, -0.062853082121767337, -0.81020890611390195, -1.2527469022339606, -0.54199657567083592, 0.10916587678775258, 0.92952203534122679, -0.87786512891996871, 1.04307319378551, 0.95468706230070866, 1.0974446026768865, 0.16352177219906774, -0.9168650623226885, -0.48297956335273967, 0.08846295555605399, -0.42193305710411916, 1.0170766798112523, 0.7099246431041869, 0.57994256215181317, 0.37292127041029866, -0.99814512570343639, -0.66163914916511946, -0.9370788900013034, 0.25014335023995432, 0.87827452495499181, -0.55295117582933662, 0.85398109870270811, 0.44705733512523288, -0.10855002906057672, 0.77549259780901836, 0.63521151684393518, 0.43191256235694547, 0.92991500521001069, 0.40754643584650929, 0.41669841146747971, 0.34025529092258222, 0.96802490436077138, -0.059058018059549439, 0.76750575341437388, 0.95576248602600655, -0.3316260085457412, -0.22549582869911997, 0.75579445323534933, 0.43809845966441996, -0.63077716591212551, 0.054022116124126753, -1.24442939498778, 0.27554110684877042, -0.89582319440946256, 0.74740617797296061, 0.76457220424737748, 0.29971603763243748, 0.35503488418085594, -0.091561292761319565, 0.64363832710179059, 0.31259433426030581, 0.00093274208829271198, -0.33584085447455347, -0.70920590952419926, 0.90713234406637144, 0.74902194405407385, 0.19547327815117027, 0.88343267355080168, 0.36927785107615507, 0.012547267384349407, 0.56413189381049667, -0.032186179920827132, -0.73311479031066396, 0.42775947128897623, -0.8063473237412313, -0.50785502284027173, -0.45155524293781824, -0.55461602648115593, 0.61267710556684107, 0.022768005434533108, 0.31531403497684912, -0.90259666629572777, -1.0297692669417826, -0.3127474454001169, 0.16357999473706239, -0.34714509459459841, 0.37083707817656575, -0.64679217757491625, -0.67677141296422227, -0.94488197822331321, 0.54831011580070566, -0.1301357660756923, 0.053654517005624389, 0.25967795825591938, -0.471013310437156, 0.12513759667652155, -0.0040313960763335988, 0.10002009728944797, 0.57005214177819741, -0.056654112584171336, -0.9726465646616137, 0.1960557819903489, 0.66293755897365192, 0.10304395015192389, 0.90970622876052076, -0.46039386265438409, 0.40045965480825546, 0.044472329828434264, 0.90616270643427843, -0.5770193417806051, -0.9159184295895354, 0.024124692193031084, 0.8962279735489751, -0.46476239218672927, 0.34139700003707579, -0.52447268263405822, 0.5196387271892815, 0.61260540502680372, -0.054347847221027236, -0.51234014913880754, 0.043476894731915128, -0.78888556989414915, -0.55508115124187474, 0.038134479501129054, -0.094852787867310245, -0.53744457625915265, 0.16989100816457003, 0.82274302372810248, -0.47092545701915267, 0.046283885889855131, 0.12397386229793295, -0.33598862943249358, 0.57938262336354351, -0.75816322245203116, 1.0664102817927101, -0.68259089595923128, 0.23521083327111797, -0.67522561838791595, 0.29204515412441051, 0.20153506198514978, -0.75868758718828677, 0.35653619699932326, -0.035724984531656512, 0.74255625481686138, 0.18984327393843503, -0.99195893874577079]],
	    [0.36136340759572849, [0.81870751059164604, -0.26408664216542765, -0.16346791556300824, -0.085392803547697252, 0.41868569111888287, 0.11559022458139225, 0.92264883199926684, 0.54404117498800952, 0.87678446141506106, 0.31198849120362776, 0.18060929014684485, -1.0174216348337057, 0.83970236338093518, -0.37117572863610704, 0.98640004649087176, 0.91033387493845563, -0.11200554341150536, -0.624592971667704, 0.47372827997864281, -0.83349562974058922, 0.60824194798500464, -0.46065432298434622, 0.20943088985161429, 0.14542416046572154, 0.7588705563418543, 0.85998469123012844, -1.0220201482014786, -1.374441168825862, 0.87232705856216852, -0.60607021292397589, -0.083827143285744518, -1.0568276162725398, -0.67379908181818027, 0.76769985785886885, 0.19283079087001409, -0.063269090056765523, 0.34976850512377838, -0.78264018082673636, -0.72205261230423357, -0.22477989903425671, 0.013133102336464628, 0.76659681278055458, 0.57957087818653541, 0.69134467903724661, -0.28085323549321584, 0.66775696387696837, -0.053230875045202714, 0.23721967900132468, -0.25357486549372454, -1.1608882415023458, -1.0582154612070251, -0.22488293068050055, -0.99079556294026405, -0.77108896850298791, 0.29634031040213532, -0.49372017219393227, -0.41519380666114847, 0.52203478845444917, -0.18736457007697355, -0.68156273836714698, -0.38350354599606667, -0.063928167813308526, -0.58225793524664604, 0.35980197161054106, 0.55117246775393791, -0.65497881241621125, -0.59727233169822735, 0.2002424102556839, 0.23580606872584278, -0.51269995809901281, -0.26299148066567585, 0.59802746412669905, -0.74829522991481601, -0.37862371867933764, -0.92480635734948091, -0.53213893783461486, 0.73453035154117541, -0.41237495545887354, 0.24535779641839034, -0.2671133843902937, 0.84892162185533149, -0.64630332457718087, -0.7385820758236773, 0.7629352634633203, -0.59894529750346415, 0.83383060299321132, -0.62460187981353421, 0.5165891801509922, -0.020113602643350104, 0.66597068530562153, 0.14053802881424832, -0.42088961118262069, 0.35407631430711201, -0.85532776975491276, 0.12036156232687366, -0.21971945816019023, -0.95705067899084184, -0.091808461852529069, 0.369713715469219, 0.23012999808348908, -0.82153990688074974, 0.41696659273752507, 0.11543063892371418, -0.65554223811495815, 0.93283768835673253, 0.27482155113677975, -0.33936073344371703, 0.41967406801206131, -0.74423509132380594, 0.112087124045312, 0.85506439981828564, -0.49525644484677661, -0.11745525281437647, 0.8846122129929157, 0.53329042079451083, -0.48716952071804553, 0.39196232157158178, -0.77021467230679741, -0.03954384198932058, 0.18003560571767008, 0.0060954264410557086, 0.22090994219508275, 0.67957044924886434, -0.80270566576489844, 0.2603350392811416, -0.29964550009546609, 0.52020409572037352, 0.14687395337226725, -0.78119658695761074, -0.12656886457351005, 0.4680184352073769, -0.85981953492614116, 0.36745937629012848, -0.63334936033871636, -0.88811748676477087, -0.10372068706343075, -0.31799389053874222, -0.35569250830583538, -0.83643300363558015, 0.10100154729671482, -0.3132523278677028, -0.14186651539310519, -0.32790994907844168, 0.41120029933126345, 0.21653074807611741, 0.46379624916656315, 0.88679906702478328, -0.42287062098189837, -0.27802835819415328, -0.003349232471716368, -0.35557572082598038, -0.92962379546169793, -0.14313737668879531, -0.79157493198260187, 0.18397798249065844, 0.73778052678811656, -0.73744782015883148, 0.33322326570365507, 0.68216876201098797, -0.38094643193663646, 0.068619913929846676, -0.85168551678073068, 0.61301260574132699, -0.23834141666925235, -0.67868793653101145]],
	    [0.61179828752151921, [0.48862104709444049, 0.57352006596818805, 0.12529705981475917, -1.0195436064880625, -0.37084542101909745, -0.92690722654109969, -0.92747815063214367, 0.37556387202499109, 0.82018108620932451, -1.0418003690969144, 0.026638332963310928, 0.82931546777066112, 0.3609255676794646, 0.12530900460417227, -0.1664955350005306, -0.79182547376544932, 0.89246029932099402, -0.84638886341308261, -1.3774117436494582, -0.059363637158090239, -1.1648971280062759, -0.84000904581038094, -0.29092090101021062, 0.80629539515529647, 0.70638967393483876, -0.90747883828479114, 0.24152932014758, 0.69961032437216697, 0.55721653775468227, -0.69196633312656108, 0.009291348973185249, -0.69797192909783634, 0.69148209447737508, 0.051371347952629057, -0.60798815967634345, 0.52195841708005697, -0.35515062712878198, -0.65928267839856181, 1.1369864820110038, 0.37708846583924471, 0.92112795610693388, -0.16664524005887257, -0.60041869868590081, 0.79843712711936277, 0.18850161067617321, 0.40052831050769239, -0.17491356330244409, -0.59730136039255599, 0.09336614852691523, -0.52321572784821313, 1.3391553013578896, 0.3926741493715396, 0.57408391841457374, 0.32823492779970859, -0.76238195952491983, 0.73403840238040086, -0.2530750922798361, -0.8250637995252017, 0.072309811504915666, 0.075860778025314657, 0.33024849913764576, 0.19592028635847497, 0.90040808868585209, 0.22924955491323712, -0.3123522820603884, -0.76559047714347417, -0.90355182561458469, 0.50478911930986292, 1.1992626574644938, 0.35970685211599635, 0.23017499905907141, -1.0532435546723105, -0.048543733081355948, -0.50490092410304599, 0.90514476650269216, 0.84116281403438642, -0.14878672832747691, -0.049772756986149885, 0.029016001006937801, 0.21102366439389617, -0.89333902660052278, -0.53451861673446388, -0.096824585287110937, -0.57226894840994846, 1.1140577355662615, -0.24117524443677876, -0.14599247474893198, -0.15476549705633352, 0.76675085387873565, -0.95356239932965403, -0.024663080413233524, -0.22553778651975553, 1.0726280377409569, 0.038997351260541484, -0.14461095843638894, 0.48390275651862336, -1.0032642031915142, 0.45293570400555172, 0.6181853434533191, -0.56284409674164093, -0.12160077919541014, 0.422890957339635, -0.049689900997230398, 0.99234349507072794, -0.057222626875298652, -0.6983262257927515, -0.12040048383457146, 0.39982196694308197, 1.1291530349264884, 0.064272907418962855, -0.63387704179364579, -0.53697866486558976, 0.93283513638167948, 1.125089164701317, 0.68466161020049932, 1.2407737349402463, 0.24735583936108857, 1.1437426632313552, -0.28171861646347274, 0.25865836351035743, -0.42560460731470157, 0.054336810144706461, 0.99896760234199722, 0.96696068054695072, 0.0014941959216884218, -0.13590309370508749, 0.28033376765713369, -0.45296417214780466, -0.715966388900794, 0.46336111800927959, 0.90637118283275631, 0.87272661817108454, 0.60817668508529787, -0.15279594063494886, 0.21938122365330029, -0.90575283403330609, -0.86477075688682303, -0.33105385844024254, 0.82432773869897569, 0.47800612703698092, 0.56134450561574711, 0.99024251474769065, 0.66427174437822678, -0.57851668439545356, -0.44438556832884113, -0.50587985767502364, 0.98138746751827155, 1.0282713434847044, 0.43391664200860036, 0.51685566824223894, 0.99700042793053612, -0.60933084186787978, -0.70614461176799215, 0.53504394769249397, 0.32203521136824054, -0.48600450580186666, 0.37661829478860187, -0.45746261105365232, -0.32196549833938126, 0.16999884239738927, -0.81643000370748009, -0.22173507439407358, -0.92648453057208147, -0.18273460796853502, -0.92424850428244509]],
	    [0.19658040920871789, [0.065851781658785399, -0.92033619300498049, -0.68155750520352631, -1.0248718546850966, -0.77532890310538971, -0.22346527020834892, -0.30825523140253541, -0.00120160851843212, 0.78344976812940048, 0.68367076559817741, 0.54706941872813064, 0.58482876351839164, -0.22726362685311904, -0.99836620828101208, 0.75924758409105508, -0.57243300017249676, -1.1710759795412906, 0.30634550184639597, 1.032104337750912, -0.20649166019590534, 0.15717371992179788, -0.67024238858707252, -0.19486699325146853, 0.79622828032296677, 0.79568830445986771, -0.76559389762850516, -0.58099294701015525, 0.25144984520435687, -0.40526333990231989, -0.73157658722549357, -0.48411046070890268, -0.18840529026891706, 0.16434905320174931, -0.90162790978852736, 0.95964128487908784, -0.074179196781372095, -0.35155725726391651, -0.18072801415857334, -0.68122993826332257, -0.8695557242322659, 0.63529538028106147, -1.0631675653004327, 0.27199564609704679, 0.58055619381718115, 0.00025700504941839064, 0.50453338208461485, 0.99369961537090068, 0.089483801919881256, 0.33000739085766084, -0.98344139971368405, 0.57534105325811624, -0.597421626916391, 0.13059725153356783, 0.30689208946602131, -0.59871108373439508, 0.53766407984066089, 0.91230819951749198, -0.70656342487595469, 0.67594977816988389, 0.62959918708301643, -0.29462598870558232, 0.34896072313986315, 0.35426488695520103, -0.74350508731719145, -0.21154715656434486, -0.1041196553789632, 0.11070776746646917, 0.73813880370084684, 0.47411301092555463, 0.2611544908111848, 0.17903326018190097, -0.32148316349163147, -0.82810504507310256, 0.90511664042191242, 0.050353171469596392, -0.3729845332371623, -0.45413144581990306, 1.024139529241046, -0.71038468831643631, 0.70025732136640384, -0.2450950533246051, 0.99628557951835439, -0.10444365258113099, -0.73476747464454595, -0.67049123228396978, -0.39473709583253297, -0.234539932674424, 0.33505298981036291, -0.52571874127020213, 0.92984946251388978, -0.71222984096796227, 0.64607698012746506, 0.04434171340250781, -1.0429369960522057, 0.67315305877232878, 0.67798574981309456, 0.22036804865879264, 0.87226163979477633, -0.37988519926613468, -0.1279611978671327, -0.38565981928021292, 0.35775415103078417, 0.84927394398843914, -0.78077121959079288, -0.58380910241966077, -0.85071545645910362, 0.74270885717209412, 0.46175932025101235, 0.39590617956848545, 0.056958129528581689, 0.61139083814578743, -0.77893489918294845, -0.23936239357797764, 0.22588225693563005, -0.15686004289857658, -0.32834984916351917, 0.12026565112721581, -0.74605817047815892, 0.13924643321084779, -0.21346587246539778, -0.64797911807941311, 0.87171579333191385, -0.38229711230574576, 0.9167150359525984, 0.74313713311509999, -0.97942816724765847, -0.82956717382543887, 0.16111792799993102, -0.27742689506539847, -0.38576398408759799, 0.19993171201619961, -0.205935035520589, 0.15824795846763043, 0.85327337379927326, -0.20000852189377727, 0.49593938047135722, 0.36789734697960275, -0.72476884721472379, 0.55383105455622406, -0.50239298035326219, -0.64486178548523987, -0.16392025474319427, 0.05694119831635909, 0.96752828525480883, -0.43877111512385408, -0.50119310769002512, -0.85378383476116892, 0.42029317308265612, 0.27685633283366712, -0.15412147604461368, 0.44705983633010388, -0.19513393602481791, 0.6790971742955928, 0.7144177708359315, 0.67277723568390269, -0.59438966205271582, -0.58424258244718641, 0.4152640353351828, -0.6739112872169768, 0.32428288420780182, -0.80346252448390132, -0.54643337865933028, -0.76850594169423103, 0.94563750863430918, 0.88750837260926585]],
	    [0.82727344390527324, [0.31044688020437583, 0.84604190520824818, -0.38071323411094826, -0.55193820518959746, 0.5565888448878622, 0.26745733850823289, -0.60057014631339933, -0.75009146185446929, -0.41804180809135411, -0.20337064865975421, -0.083794170198269666, 0.41957679374513002, 0.20501146218127217, 0.048233664833869705, 0.92838313542130702, 0.59071453257764095, 1.0540434761982143, 0.24425784046083909, -0.34753557263433266, 0.16847306567824066, 1.2207852761201281, -0.06831924981658051, 0.80709954152936902, -0.58269207938332879, -0.6555714971427905, 0.024330248203028024, -0.04177947801380253, 0.072918573769351375, 0.51741732713566702, 0.11409173020272756, -0.44760559667838001, -0.10331529380055497, 0.00061394156709024283, 0.18881627481645466, -0.24114184442881409, 0.28246563563824956, -0.40396703054926114, -0.059844801048023234, -0.63528390375683108, -0.18829382996448291, -0.95924921527832452, -0.26100655202866957, 1.0770341622440016, 0.50814202642763928, 0.55165675866349217, -0.26817451310699353, -0.1183035554042564, -0.50317607297879974, 0.38375922847102878, 0.065009381506900263, 0.2763842880967442, -0.17553278387509022, -0.2561392458488525, -0.31627971459690113, 0.85964836741660067, -0.73711831239218373, -0.28429054071895676, 1.4578787354186542, -0.93462624167721031, -0.050715248767941423, 0.13946169571582021, 1.1288818591853551, -0.45903460247213029, -0.046910114332104257, -0.30047506865002238, -0.74540913483021043, -0.57224534346919298, -0.15953716624402695, -0.75388159578327629, -0.16190413903154571, -0.028454883456092227, -0.77131027050246426, 0.60192345210650888, 0.7147905151809073, 0.80549448081193109, 0.59912592866877767, -0.93050740510245844, 0.37891922547053919, -0.45266084376190935, 0.94790319754757535, 0.10531367755404747, -1.0289668077018901, 0.089083254408503884, -0.96402389391377119, -0.026834552377599692, -0.76116569080337215, -0.57751492140994087, -0.46301995410565794, 0.96716417525295784, 0.76683648098061652, -0.89512730701042942, -0.038780209966610787, 1.1001006837955156, -0.12526559938132692, -0.50925734509565768, 0.12563717571785632, 1.0068892243121814, 0.15714555647627448, -0.33942781030285302, 0.079746280276538101, -0.65684975001928225, 0.65979130980291101, -0.088714233049178387, -0.64862154850638165, 0.29211460334073197, -0.5455830163158697, 0.33256114762510325, -0.57095646451023307, -0.70991318476279763, -0.87615864779955299, 0.50014991883967586, 0.28515928909715271, -0.34054008580949607, -0.3911580480266228, 0.89500527010029818, -0.39292881574340371, 0.667074808008568, 0.70373400532392549, 0.8779556971821787, -0.51491105901553724, -0.48980397367631173, 0.20944575201399032, 0.44562517359010961, 0.17845458055598987, 0.71615622545622171, -0.44231600662484599, -0.22212402489451355, 0.0659468961480702, 0.72715525840438844, 0.23257502739266153, 0.6690780563039741, 0.66614121385797764, 0.99134297097979807, 0.886311168236664, -0.93598315258177789, 0.56906649653493258, 0.93113548155992665, 0.96646510441877387, -0.33757518059933556, -0.10435122450805392, -0.28151093281977019, -0.27514863834680203, -0.74486274435836608, -0.67616651356637869, -0.15063920121477856, 0.87635303830096889, 0.48592849973263763, 0.1292293570724094, -0.55483545223137631, -0.65188856644317195, -0.15542072385097816, -0.89759773456449665, 0.064633520056045585, 0.06039306931117968, -0.81096057154716783, 0.43811970271232054, -0.43777905724666666, 0.54996245805351562, -0.14517465092412626, -0.47932112933526994, -0.26407824798257695, 0.66175525958728221, -0.19724432771130096, -0.43319714545332122, 0.17235055566533619]],
	    [0.56818776383174829, [-0.62815197981564996, -0.64590876205760006, -0.086095898666901177, 0.31758428544230649, 0.77808110307650302, 0.4744901452259408, 0.57194324098553451, 0.47589831243282926, -0.64154666112830228, 0.88896221916883411, 0.87695469124675696, 0.060885823200873518, -0.045948797902644854, -0.42555456755043775, 0.75805934229920058, 0.17033283692962209, -0.83049584705831136, 1.6729551325427729, 1.1184991642939559, 0.12707086273588517, 0.087218407951148436, 0.63571428099108374, 0.88117522580438634, -0.13802590158560202, 0.037413025999386694, -0.074208625583220805, 0.4804137229638179, 0.51257639764276475, 0.15938967386503206, -0.76782640228191434, -0.20522602151729544, -0.61574830476380171, 0.35149389322433833, -0.29773077173591006, 0.45001012876955793, 0.051595628424284279, -0.35267124970023417, -1.4495704930479172, 0.18845352191608156, 0.091686139281899892, -0.05425052156191764, -0.1524969511079676, 0.72323692984142096, 0.32004264358733631, 0.84640732826831777, -0.7695534747024444, -1.2450934125146664, -0.16350404848459407, -0.097740733061576615, 0.18747425770255322, -0.0017872544154957444, 0.97067971717575796, 0.23140303957915992, -0.17448939250896489, 0.85824073562190928, -0.27718599625769141, -0.34479698044202189, 0.80866626323131729, -0.88107984898460057, 0.5792774774282361, 0.94577953449175711, 0.04559583658051735, -0.39834111726824573, -0.86998212649830731, -0.13190410677527256, 0.21062659261060226, -0.60166350675311897, -0.40165342249987551, 0.253038383853875, -0.83522171651619859, 0.054231739023252332, -0.22698597896197981, 1.0029153774488677, 0.81626103674938932, -0.76800974994157034, -0.45917362909163367, -0.80103689971937053, -0.019424430704671893, 0.36506004873152104, 0.060244101706788442, -1.2458539467684833, -0.98474870731550279, 0.055269819254952592, 0.49055961125605679, -0.80772803065099574, -0.12194251882588172, -0.50832386693450438, 0.17850297637021414, 0.84680265189835069, 0.48836389469265229, -0.32477532590373187, -0.31127904253859862, -0.86434751403286147, -0.086548504100489962, 0.12858931582608576, 0.54858205526236847, -0.49650847043739837, -1.1277110402067678, -0.18297235561096981, -0.44095708816325963, -0.6826011030722936, -1.046480220547193, 0.77991805775424539, 0.19967209536909372, -0.63550063740872131, -0.37493830770711251, 0.62801765241080598, -0.1801743883792532, 1.0230134851900559, -0.4596612031000149, 1.0349265272294388, 0.57912240462050979, 0.85925608075252391, -0.29041912912676515, -0.13910667599898038, 0.66229563354654974, 0.55732316053657138, -0.28715312877251659, -0.40563574537798824, 0.61429336353918573, -0.18238919711016238, 0.66298042563913473, -0.80981538344800663, 0.21634635170773558, -0.95329645568118748, -0.73429719672841209, 0.14447274874867566, 0.36534466865913162, 0.59778706763713507, -0.89858264113241926, 0.42290883735840556, -0.19819367663375667, -0.95840805843748322, -0.40784195091660469, 0.17826708748605902, 0.35467902160943499, -0.11885403565331376, -0.91700077885850351, -0.83279281349352197, 0.58251424870404822, 0.38845854389959933, 0.76192008109712883, 0.76203707304983992, 0.83910221408942764, 0.57870206374445854, -0.68223456190918619, 0.6263551008791105, -0.74380278493394214, 0.15381822164523545, 0.33057305135935477, -0.029123073758863801, -0.8847037400793466, -0.76742388663670758, 0.55415025793882866, -0.20986577045007385, 0.26828123384326624, -0.68211374777047951, 0.73793276878105774, 0.9282680569560422, 0.11977355293653758, -0.80932741006041886, -0.0090168094284432954, -0.044011830134419228, -0.0084257218164298653, 0.86851203038900437]],
	    [1.0694628860965389, [0.34155155542323218, 0.049365058114129265, 0.51033723044331525, -0.23840582024047022, -0.1391774309567857, -1.0575017330313798, -0.67214306560592996, 0.20546000139868376, -0.73460847050755662, 0.39110274393578981, 0.48024218316512585, -0.068976379135274005, -0.71486134457941364, -0.60636343069351528, 0.94046156724580077, -0.85531385300163598, 0.098019501157561237, 0.32901578598728348, -0.22643106828802545, 0.42408132057564007, -0.68584534202219627, -0.7369462159530128, -0.16692947951320314, 0.41578901106242644, 0.64484239371361962, 0.1854103012974716, 0.5740883970014683, 0.42607280132619418, -0.080914121721835416, 0.023963300302508816, 0.46271859920833819, 0.73542666887165054, -0.45971214989082426, -0.11261399411859668, -0.47577703144256167, -0.90169687778651819, 0.3838729070181271, -1.3948077611669734, 0.30714890093833164, -0.57545656343816842, -0.036729495052170595, 0.16997888036760136, -0.91080955860184754, 0.93873074637936105, -0.24317893432625093, 0.45111726342788872, 0.8577523009383976, 0.61764379238084499, 0.87077387455964284, -0.94588755551507286, -1.1227393855446492, 0.82392236841467237, -0.27231046114905144, -0.30988577498945713, -0.96316166389021585, 0.35629462158780656, 0.9088093192876332, -0.97602778606570417, 0.63110262836701736, -0.21127094236967592, -0.39112275957472492, -0.57141377788228853, -0.13106731363052537, 0.92374271952630493, -0.31526450179175647, -0.23862564592423968, -0.22484086290067465, 0.83488665724820699, -0.54987442225285266, 1.0336924751163421, -0.6758664113816264, 0.85707921355495897, 0.32210829713494421, 0.42898320797293688, -0.82201821179916812, 0.32190912650027992, 0.38130460142050698, -0.20600112420082189, -0.8210259405978434, -0.16740612989141157, 0.43107615868704652, 0.16353898027941996, 0.47603321097547191, 0.34244359093048293, 0.25810813860058912, -0.68832795633122823, 0.67862428839980493, -0.42610329329044955, -0.10771117143693899, -0.8578852292012924, -0.42925498070248541, 0.6462281945385191, -0.86771919272586429, -1.1509102585362025, -0.28989802468529519, -0.99523953651071462, -0.11109054598771867, 0.41134590567692425, 0.89522999159799399, -0.79940888239391406, -0.72764143539597004, 1.0117017817466276, 0.77712886278817872, -0.7261671268117621, -0.59009977272742242, -0.064437261371511886, 0.20291603263430996, 0.1205936720976699, -0.8587891192177588, 0.86120852454681263, 0.17057453929254085, 0.18767722364445244, 0.046886874903611195, 0.082090352154093674, -0.25894540266906008, -0.48629869047045415, -0.52847485006757433, -0.67134767301635601, 0.0091582906996382166, 0.1719706034045142, -0.70071124856847167, 0.71807457951178943, 0.90878433451238338, -0.46082849727443781, -0.23604045497931267, 0.29349462997595216, -0.63905507651296267, 0.93356395446445306, 0.43703913424344937, 0.26436218122482802, -0.376461742346898, -0.10766860313996685, 0.45966965906783863, -0.41386880096468859, 0.85277412831951316, -0.47379518954829491, 0.29819439537737602, -0.17231244220903716, 0.48538387069320943, -0.06751887536325496, 0.21363091982130086, 0.91079294868934568, -0.45639755540157217, -0.90735342417393305, 0.85552574524215863, -0.51834796928963134, 0.89026702264175639, 0.62716673510316856, 0.039082623279870429, -0.80508222839272414, 0.049406437389310782, 0.42029146527169692, -0.71362772573935718, -0.20513334948705186, 0.93878645366160884, -0.17278673378804549, 0.86264850055096276, 0.36936392593233824, -0.039560779331520191, -0.19307428899367252, -0.65822170007161351, 0.17409584169650771, 0.45875560044713026, 0.58770310945565729, 0.65957949174194175]],
	    [-0.15650103889363526, [-0.76566159391358946, -0.88639639104460966, 0.3317286162998842, 0.12292044444105645, -0.1132258223422338, -0.6333568542318313, -0.28908895160250775, 0.24704159019115768, 0.19106069578800022, -0.071951051145395725, 0.62400172620604144, -0.20909399335411155, 0.52381515419134317, -0.95505085937801582, 0.41151556133174871, 0.73405545179470155, -0.16212254504094561, -0.77132254657245392, -0.33812534374094549, -0.9413989927139409, 0.92285877108989534, -0.81398817505491627, 0.039108267194975475, 0.10034742409550705, -0.22690521771225197, 0.20243079367982503, 0.88333458162665535, -1.1691240879940361, 0.29863845905604169, 0.4505447615806657, -0.063843047589239837, -0.5026104760556328, -1.0466742178152284, 0.74259777107484559, -0.03801442736006122, 0.6450649196102729, -0.011329982996341527, 0.29829598757849657, -0.97678400646811503, -0.27311293653289148, 0.88784156958647087, -0.54158255000550781, 0.79401277036525497, 0.41439574017402953, -0.4781443351487964, -0.32514761396460357, 0.49552889189215615, 0.77927047176514896, 0.88851261052652342, 0.54185164586131496, -0.25134648962575867, 0.61893731570718746, 0.64581308286698536, 0.4672693728140786, -0.59832758065351177, -0.66094820603452231, 0.1402276515637258, 0.057449052872014988, -0.39892035112083496, 0.9544816474660156, 0.58004101645234352, -0.69708052473219406, -0.93706488354139161, 0.30574391227788505, 0.1748086490297725, -0.43355500571478173, 0.13269494508785978, 0.99441536445408596, 0.71868813564569989, 0.0019137902943607264, -0.11211837686347738, 0.097012371931956415, 0.33030929108840795, -0.41379383317146151, -0.032676778633409453, 0.58434595620108687, -0.097851203089071304, 0.015987534110084706, -0.5446336769781025, 0.054000073101560915, -0.31536256823129599, 0.11134056744862528, -0.44209904816839884, 0.31361091912391836, 0.52056103580749014, 0.080642088887405081, -0.78199681006553312, -1.1994219795064558, -0.37648750269402215, 0.51779739527716928, -0.43455074631618912, 0.92225705416946746, 0.81486933129902417, 0.89822356726411046, 0.79449909889023651, -0.80798539419169457, 0.9300177263939553, 0.14767985368229353, 0.36764540087169995, 0.71029805296193171, -0.63703848002271057, -0.75132340103882267, 0.77089515100656503, 0.5960863780335165, -0.34338054179291627, 0.17111769254903286, -0.66469165551905196, 0.48552328145638535, 0.93103052038229928, 1.0099323450272175, 0.6589087259333346, 0.96236101269760588, 0.60946911288391747, -0.2705408183404866, 0.76614131663074447, 0.60423834779640218, 0.6785200094641084, -0.67461653024729251, -0.57438048706746125, -0.41505385257468541, -0.85916178318617897, 0.16964427357731854, 0.6112492686432085, -0.037965281563455695, 0.43648877269628172, 0.038217701112840535, -0.59410542410931311, -0.49608116936601765, 0.26350437997453852, -0.35512196687677688, -0.96442588465012635, -0.98671356250648312, 0.95865678097850682, -0.4530848685337015, 0.51330705466725923, 0.25114833116403007, -0.12055628760717203, -0.36650038324408757, 0.28340910244091055, 0.024504248326984376, 0.81367994797047238, -0.39907571805891506, 0.24630040970340575, 0.50840185521606829, 0.2935124372418233, 0.37132101796052275, -0.37435509259271588, -0.7584853269951598, -0.79449109227024639, -0.58344150377486326, -0.46416441580038387, 0.51660020915038585, 0.40917432844308615, -0.59592444304746417, -0.0157034511693445, -0.74114690738972244, -0.77824201382900726, -0.51847702132047735, -0.48421825484254938, 0.67281000100475774, 0.78943529539218171, -0.72534521968515553, -0.37754834167724338, 0.1470507770585201, 0.66710489327644495]],
	    [-0.23020036104759292, [0.13394773609134406, -0.33974446203857428, -0.25857625560866115, -0.84079011247158608, -0.1000709959883518, 0.8341915204119823, -0.25023756801582031, 0.58131661207562613, -0.21692558194622352, -0.5587050633238696, 0.18952299384474247, 0.037999310711269038, -0.44869120669518242, -0.16210538404384578, 0.52334312471644129, -0.89774146277026612, -0.8161040214906794, 0.5186250560381509, 0.0025532751312499023, -0.27341161442840001, 0.81248071452943782, 0.80795170659013227, 0.50035198785710999, -0.68635003685261886, 0.58740144866546729, 0.076195039298448425, 0.42578885370576192, -0.026116519851362575, 0.6679661967056244, -0.10811246691299625, -0.60519441839378163, -0.23127130405308977, -0.87105059489226189, 0.39898923002919129, -0.85846511181322971, -0.67766033745751064, 0.37365725198540301, -0.39128772654125066, 1.1007782069998242, 0.81817367725109491, 0.44345168752894576, 0.56798177462611754, -0.35015300271237881, -0.52667359412697845, -0.73174777603348251, -0.82706709467854866, 0.062784095262449949, -0.29114453632420784, -0.3013852579003517, -0.2819690565653003, 0.8152716312762387, -0.46436181795608805, -0.21523514894280235, 0.3811872893265027, -0.31185782391552114, -0.81924506724657109, 0.65063687789443048, -0.078117445503885705, -0.81962791181794126, -0.55712607096132483, -0.84844461782036595, -0.23387361051047287, 0.35754481707318347, -0.59966251662298231, 0.20531825930450232, 0.5304110821136212, -1.023143266724474, -0.26777175834690164, -0.9598413551793008, 0.19055281721182785, -0.16653079493998252, -0.47232871246819103, -0.74575195875808342, 0.66777660060356403, 0.63155467313791758, 0.31379836140925588, 0.61657253041208049, 1.0300941885823576, 0.39556043932366158, 1.365298087689216, -0.02831247115600817, 0.61595028118704787, -0.0072050216059881969, 0.67170899981892862, -0.68445854069718537, 0.45204451469316659, 0.086933084229810262, 0.44474775290841129, 0.0082175566740360396, -0.5207296861486117, 0.90828457454062439, 0.88351758439348349, -0.0062784293215829108, -0.24481442726067032, -0.69119276971381294, -0.1846483651198737, -0.40152003854145396, 0.43056164026553356, 0.598494573113592, -0.23907349300560451, 0.97381952519110682, 0.095642975120182383, 0.89610930491190399, -0.72133885348905447, 0.39629147515130136, -0.099901387494819263, 0.069011010403067077, -0.45175684840291375, -0.16087791130785822, 0.88815982671717209, -0.82719408286445595, 0.10287227141309489, -0.72349948925477747, 0.050734805101693731, -0.87080683606417109, -0.0085587114610899268, 0.17991122552660305, 0.81592214875426705, -0.99976294892342699, 0.1752633680688247, -0.98042756270375253, 0.16826098015248883, -0.91791000931796085, -0.59720880119686415, 0.63986593747414078, 0.24034210972819167, -0.20861055631818354, -0.23286615362138782, -0.085342329592903998, 0.5835396648111103, 0.87278149816483319, 0.89735057092221215, -0.45376500830829403, 0.98564440792733088, 0.43780714942595933, -0.5036905130758812, -0.2699427369543318, -0.68257308515460524, 0.16287137090271137, -0.79198809834459283, -0.32922322232935314, 0.90579670807020884, -0.25449154396953433, -0.77705237720241571, -0.43984466673753841, -0.33828507031240806, -0.26282983224407497, -0.43776707889968042, 0.80173324793414436, 0.45988228501751061, 0.89355016361947703, 0.77842251296657683, -0.95073778110519858, 0.10345845042563025, 0.86612328765070579, -0.27343966567025124, 0.047132353917289649, -0.066729508175209395, 0.9949902068616, -0.61276978793580072, -0.11845349683850515, -0.57126804564436418, -0.70754077260266901, -0.42482254115729012, 0.21941231452437293]],
	    [-1.0237573720327455, [-0.41583283524031744, -0.36306377067267542, -0.52470998362982535, 0.1624035565475665, -1.0240679108258155, 0.73294245168443051, -0.22824942472543336, 0.11496133512692841, 0.20401763531203262, 0.35577715946672583, 0.49057061058597923, -0.74127407581088567, -1.0248295730017958, 0.79040360552662814, -0.013456543821753542, 1.3397970787587943, 0.41754305084896703, -0.81004923343050561, 0.096178905550510216, -0.73149667149953612, -0.32214209444825848, 0.32381328936070469, -0.67956657447210866, -0.70308878480988735, -0.2493070456334997, 0.51212496831002086, -0.18622821335944625, -0.8402083173588879, -0.31188815799795655, -0.84948717302387111, 0.16754939851874562, 0.32403135878998551, 0.82575703246950005, -0.56650634403684808, -0.6460991497133608, -0.22325581504355596, -0.32411855622960767, -0.086024624025424296, 0.83234277907414433, -0.65482113056535762, -0.33497023377657631, 0.74809100452669886, -0.59534443225845635, -0.52048764323666497, 0.89521516134952961, -0.52568110644083976, -0.64306928343667524, 1.0290836516545765, 0.65192271310425665, 0.89289685557887821, -0.65185959545567362, -0.8931302033878471, -0.88898935411347213, 0.35946635938901683, 0.98960597638717196, 0.72747501570905904, -0.37376705876253796, -1.4403373650481386, -0.66753554445469343, 0.37645770287391023, -0.52379084068425608, -0.15538094886425505, -0.10120137654119807, 0.75144531427863559, 0.38480118292714399, -0.24152734427640746, 0.28764942360284806, -0.76620963950907872, 0.006253318419064886, 0.33171167388463246, -0.62124141848372727, -0.55208336767670818, 0.3308744259379745, -0.96933082296541273, 0.62217539728887705, 0.44675780358482975, 0.55787190958190291, -0.22670056757812099, -0.31026469257160477, -0.6970188080666615, 1.0127916968551867, -0.54864819067575998, -0.25647116965146005, 0.47492602030417186, -0.003062037506515335, -0.85739105418194206, -0.31243497773525286, -0.16447778907628227, -0.28613211424609813, 0.98824306026623954, -0.58132761897776575, -0.17667583617063859, 1.0032922392268693, -0.29198008423786914, -0.2159513091981726, 0.72591922687018151, 0.17306408342872343, 0.92384723348509279, -0.1522556672466456, -0.37873733618341887, 0.51470369298361607, 1.1904955301975619, -0.63584030885005716, 0.3565052004830217, -0.94679554239214325, -0.66823134069195889, 0.51793376951798509, -0.2451119459859307, 0.86714603942931467, -0.96650506709198925, 0.92238510190648126, -0.65046359292834444, 0.42936897734036822, -0.42348664131783448, -0.72621447830456987, -0.31936331282444935, -0.91973545468457185, -0.32225837435218679, -0.73858749632241627, 0.27565349719609994, 0.68666338065779464, -0.66997803175957116, -0.24893837557985934, -0.98402634206925155, 0.50109031254134262, 0.4448241627703447, 0.46057701020354908, 0.0068859013771889691, 0.60924336948138536, -0.23664212880508648, 0.19076208506293177, 0.77798970752989038, -0.81105452825590241, -0.18927083776859449, -0.69462841462839431, -0.42692121257922067, -0.65079535157939461, -0.19493474577971184, -0.26813500217601377, 0.28586372692601797, 0.26560087315248165, 0.68986834352003068, -0.83496761662246854, 0.34273659169228199, -0.18864380394117169, -0.93788312933934603, -0.76643902118041496, 0.50671493002680401, 0.2523594559292941, 0.42201544123028545, 0.79731042624883097, -0.026079328750565917, -0.11301328067472433, 0.54640470391838636, -0.094301070023222272, 0.5166895486817521, -0.69576314363960956, -0.37380349604498558, -0.68333898165495355, 0.7837086965678246, 0.12189243947832384, 0.71000433828649911, -0.90229286934600594, 0.9015102728769655, -0.58136886048473047]],
	    [0.13738267618032277, [1.0809397810464625, 1.0272237904793811, -0.61094492545271595, 0.61581558952317561, 0.70801927457011316, -0.69869685425564021, -0.42022894119893023, 0.24686483610977053, -0.14510849505365161, -0.61524909349450674, 0.41753267258802179, 0.16180386388466464, 0.41606878983993162, -0.91575940751611484, -0.82040744420271072, 0.10642862824514036, -0.82414757271840944, -0.9439762567090173, -0.76508674555480227, 0.28384869282861652, 0.63777637750748029, 0.12466678969758133, -0.54836810635525235, -0.34134414165415161, 0.068149385477920904, -0.57301773493457264, -0.37053771861260065, -0.5143135756258419, 0.35331178128550406, 0.33411696578415517, -0.66570269974909846, -0.1299949417778902, -0.55963750084221298, -0.76128938639128163, 0.22113010808529032, -0.47425335599686352, 0.5618522877313985, 0.63392772369988981, 0.67464405615294454, -0.06114102616507483, 0.099855739068248961, -0.45562993259831996, 0.23937245921858705, -0.77900283538879889, -0.73143991472696612, -0.45729511116522364, 0.011780729569594726, 0.091702795430577771, -0.57004515542415812, 0.82115742181680706, -0.90935469842967931, 0.3878014142504036, 0.83445001576974798, 0.42031897816741653, 0.43308995735782052, 0.43941289491986696, -0.61029799483275327, -0.5597793361763822, -0.78756542879032032, -0.77495524334988497, 0.45965551187505393, 0.60595028167915355, 0.58523870083687801, -0.16638755103921568, 1.1994060720337807, 0.36181339063877538, -0.10430848774269998, -0.48935687823068635, -0.4669264661939056, -1.516492647792254, -1.0112920401699159, -0.29878979522015431, 0.66173787863000644, 0.076756820730755876, -0.79262268646516931, -0.0063945513720997695, -0.087888449564008569, -0.29816245437533473, 1.0719525255242928, 0.89612583052236439, 0.53637216605491067, 0.58188485426732006, 0.94497326791383029, 0.044090458574689441, -0.66008634922748188, 0.52797012028202828, -0.79337890088124519, -0.81820214695763793, 0.76143471176541966, 0.087264036976733905, 0.35599951597279089, -0.51123911885832196, -0.11102565689454136, -1.2441445510835467, 0.020357238904418422, -0.0028906840397722303, -0.515172816129156, 0.50159686487562438, 0.37928204821538108, 0.87302362712942183, 0.94462934800112452, 0.32700615539952427, -0.089369055551566656, -0.63356173435358065, -0.6020732186655392, -0.044950199000682971, -0.052775160476156803, -0.99162090785658974, -0.81368536776237688, 0.24363977628150904, -0.046004650026427223, -0.30924355838312606, 0.49232334208703915, -0.26952172887013892, 0.49345253267218325, -0.094184421021788825, -0.096586858245882021, 0.39951500689205144, 0.43290948859372302, 0.47702580856552118, 0.92617892741472463, 0.15662508666222061, 0.4194096225259441, 0.6098872086911914, 0.080840482901768346, -0.61561048895010961, -0.90744068319701787, 0.056487865722882544, -0.92842864792539237, 0.92344355062015349, -0.96052234251940372, -0.71014091277584335, -0.050125708326467469, -0.29561814002454229, -0.16266050203790736, -0.30940212748565854, -0.055161198738480813, -0.56903700068420493, -0.23286594290714185, -0.80224973294472268, 0.44330356608313459, -0.39501222633005051, -0.42283723559961178, 0.23895972998586718, 1.0235512679862597, -0.38010152820697968, -0.6159051516964571, 0.15613037800691812, -0.35267462532020322, -0.43226724571670694, 0.63730580623231536, -0.36367342068013397, -0.87052793642817394, 0.24534601094951428, -0.92448411299654021, -0.63785503681638667, 0.090076746190870263, 0.53920868509224007, 0.57677030536045859, 0.63562281705581913, -0.66285085194818771, 0.32165519884264659, -0.68738566618209118, 0.62405653989173371, -0.49416856980393242]],
	    [-0.22433533556252716, [0.07811016576778694, -0.30066602361846612, -0.63805312987213159, -0.16185822035411876, -0.64094177757098225, 0.20389128975132628, 0.68154360180651918, 0.065548581216803528, 0.70908609011970547, 0.18832913082891595, 0.50574640505635005, 1.0328403479625712, -0.49510979640629921, -0.65138728321594863, 0.09339156131248294, -0.85264963468515609, -0.40217872884335287, -1.1417521394055052, -0.20370118787732133, 0.3620876028851408, -0.14633819982721061, 0.73099235018505659, -0.45658205686236619, 0.83114339168202112, -0.59308469181574708, 0.63106071459079205, 0.61394898414707044, -0.96414587032190791, 0.042661691693936118, 0.62085693659649754, 0.29079637900045047, -0.91145579052997927, -0.68997433012830889, -0.14050890344246142, 0.70250440780222678, -0.82344366530916657, -0.61601685186816324, -0.069697483106407318, -0.87533050551905367, -0.72788145660116943, -0.79481494974101763, -0.84160128065342621, -0.86623471659204709, -0.78500518076269699, -0.41543788812971583, -0.72644266747746011, -0.036809205006216046, -0.25901735516454338, -0.078880809037148517, -0.94188270265489826, -0.18520277312914862, 0.4536813924380535, -0.37706766570173189, -0.63782408897083809, 0.63818833310949996, -0.80370647852205823, 0.36825985160834956, 0.1215550593525883, 0.014891740509519214, 0.54219117183018195, -0.61252750702369796, 0.47744792834841104, 0.74643633949050769, -0.53026278289417639, -0.30876438527648864, 0.36410329750359399, -0.52017171067632051, -0.79231902907357699, -1.14444261096348, -1.1301293710783404, 0.20483464151017994, 0.42976151548873598, -0.79897783217936491, 0.24133964217064235, -0.023074016273463727, -0.65046187992674398, 0.59197753450563384, -0.31195899626331108, 0.5364665561043076, -0.57021682987192557, 0.8429072248171563, -0.13978024904500674, 0.47007807891501202, 0.82374804603181839, 0.93712876470086293, 0.085828258153541684, 0.81918335356774807, -0.43849479872425601, 0.56310747057523736, 0.35283336818213007, 0.38463776827797491, 0.99756019936711127, 0.64699357026106541, -0.10309277193688164, 0.41218600163467772, -0.57710200365210484, -0.020488173876880161, -0.32594540094488422, 1.1079125892553094, -0.15900310282180913, 0.078779978574485834, 0.016195553858052967, 0.59336925056773804, 0.12237893814310284, 0.95434639102898289, -0.2534659878296302, 0.46353393936342818, -0.25221076566838474, -0.17631032389573387, -0.029236422954692413, 0.40472921541698459, 0.4574959230202631, 0.42817543208363845, 1.0183186904553947, -0.59544589399305792, 0.78136245450229957, -0.53480063437535053, -0.57044125493018172, 0.24409584256481356, 0.045045938459019302, -0.80077824137970821, -0.35845189184305792, -0.88518119734040757, 0.50540672281429488, -0.05453197211718145, 0.023587461106696645, 0.53435247193224333, 0.28158256445626534, 0.42700457601283048, -0.73743782915570144, -0.55654150071657271, 0.66769134171197475, -0.55256513597528845, -0.75342019509857683, -0.8437236039772027, 0.063604241000494235, -0.13858029119704601, 0.016561137520891035, 0.61778510824024924, -0.47117582819845183, -0.60227681264283428, -0.60671540255435874, -0.20473112889963108, 0.72355240765909057, 0.93472047480512321, -0.6367766074815786, 0.18634058445243282, 0.44191735332641829, -0.62248820935156257, 0.56193380618629818, -0.23445054822438968, -0.6661374812034182, 0.19139718775586254, -0.73585431298576054, 0.82586378189128595, -0.7899450111216737, 0.23153819833354722, -0.25036375994175847, -0.34390212656771552, -0.61792604906752624, 0.50966950377908171, -0.50341916573599454, 0.16521899628542114, -0.13429527997073953, 0.62350482906269478]],
	    [0.49186539708362709, [-0.66863898337367389, -0.67088492772752018, 0.78141774753119642, 0.38802944754074686, -0.91995548154189821, -0.88247961492062055, -0.89636245627183597, -0.55261742671351133, -0.58618804984817641, 0.84622553715480819, 0.43377550484429561, 0.52050648543493239, 0.65215239651209722, 0.80123848012863741, -0.68887405505967281, 0.42680313684035798, 1.0495106174845772, -0.85329398406212464, 0.46865352318286746, 0.3836094656575425, -0.29104967138765181, 0.039051809961864158, -0.11286857283807314, 0.67853976079913403, -0.090561234358409501, -0.8953855204517126, 0.35248192733692701, 0.44082925700577813, 0.30673050306311223, 0.31286814234636839, -0.27228386996954257, 0.88399283502880166, 0.032121511646327927, -0.24503743722517185, 0.6344152173655776, 0.55870081552888895, 0.71823684505069918, -0.47603116987313121, 0.97648974864229154, -0.1139143740817397, -0.074232984955500791, 0.91885740153141326, 1.0436333630243992, 0.22607488236173076, 0.119358467657942, -0.58164249774943733, 0.5987238444881664, 0.058299279797706036, 0.44242430094975266, 0.88565356041236287, -0.20780350277288032, -0.94276033707122775, 0.70898004654773172, -0.13762446166295239, 0.35324368857715721, 0.13629233708439767, -0.094798559079909236, -0.41928874826150053, 0.32383414641114233, -0.68915115317383391, 0.080929938759899178, 0.045947878214756079, -0.0074322204879451927, 0.79961613353741301, 0.72477749959240945, 0.033841971322291269, -0.34186259796725288, -0.4835825110686543, -0.23636909369352227, 0.15946198983899665, -0.14024199220217273, 0.083985620546028067, 0.963115777918233, 0.58901878383856465, -0.61018499376063584, 0.12246805370527902, 1.0129096910379836, -0.15587590574464119, 0.33925050706290805, -0.25311139081160422, -0.20737021848302509, 0.23864204828692864, 0.75224373548942802, 0.44515856120480352, -1.0446777143770989, -0.66114447974758384, -0.41627575718409482, -0.73768122801950009, -0.12108770718895258, -0.41225356168431615, 0.25348884499836166, -0.012668012160399948, 0.033809349727002815, 0.086479700564411704, -0.40589208920686282, 0.61702631225812188, 0.61517257890289345, 0.89008500223078169, 0.4655055036840447, 0.11178195023257044, 0.48046769186379135, -0.77554987945744935, -0.45876492287672577, 0.66974756349787679, -0.82310836559493938, -0.47501223720257568, -0.23814304520762586, 0.41671551104382343, -0.090483321066146816, -0.39050905264947894, -0.30107475273089807, 0.057776744022232894, 0.17947897503392718, -0.2409126952612885, 0.20973465763286653, 0.78665773657717719, -0.60021036494528346, 0.22805887503653741, -0.8086023316130132, 0.14012451971497261, -0.017914015989406361, 0.73257334849874611, -0.73712500322179653, 0.31227612262489035, -0.39696238941126616, -0.84647504162169529, -0.23810081901136526, -0.19040345118895527, -0.42221494224906592, 0.72260410884155546, 0.62637376695337998, -0.080176096848555853, -0.87377408163230641, -0.91613099347471061, -0.75383160605359545, 0.95839679555737978, -0.78389111491212804, 0.92012038724599898, 0.31065238819238489, 0.65007048528977973, -0.86491528223611636, 0.29978539159192968, 0.27664683955250918, -0.074610943128118098, 0.57694425431228358, 0.4148065895767778, -0.16821549874524364, 0.10409244296055772, 0.0854396370714091, -0.54545903745101332, 0.458148091623025, -0.97458668412906158, -0.083639059124216916, -0.84849143712232722, 0.52371645711047532, 0.67360923267579176, -0.397741913351918, -0.86711260244556154, -0.94031948235865848, 0.57012438015546585, 0.95281492158919834, -0.67714134512573887, -0.99638578419046375, 0.56038764079573156, -0.47112543041921984]],
	    [-0.70219910483317416, [-0.51660731838223239, 0.72994345515596992, 0.36894410453993981, 0.11013592522098466, 0.45559806904717759, 0.46346065619246701, -0.74030861378322566, -0.00355913902498585, 0.51372891559978862, -0.61124362747018024, 0.058249362100171044, -0.45812427718460691, 0.31733761339085415, 0.30808868664153821, 0.22441225936989517, 0.36058109106477626, 0.043740636530765722, -0.64129564223225244, -0.41623860149545194, 0.27162746714138103, -0.5191328942569754, -0.34162140602037511, 0.35414679178245417, 0.079939970039582253, -0.052827633676517154, 0.8722438455114272, -0.63497395784755806, -0.66111749342664394, -0.97297138537948125, -0.036488109451093154, -1.0705988380789242, -0.15988627859216503, 0.59876748352590381, -0.072329831503770897, -0.31450684078820579, -0.49524108779443055, -0.89425574260492169, -1.1895943885049387, -0.48041353857798824, 0.56358394049665028, -0.33437826499144085, -0.27829251063375054, -0.30952358606409613, 0.44085135926705959, -0.82614512183370814, -0.13504601514665188, -0.6942610176385503, 0.74735520989602289, 0.54163480016434962, 0.0010882415225468497, -0.74753791053442309, -0.772972258817618, 0.6294323030633161, -0.35273788386017862, -0.51596021948997484, 0.16204697656409231, 0.94435301737146038, 0.69136743442277204, 0.95037095650767434, 0.86789577758512038, -0.8674125099467257, -0.89011392814533896, -0.39846512224919445, 0.48656442498286345, 0.71917769649502794, 1.1751626968130879, 0.28739757679465455, 0.96759284422665703, 0.51008160874435948, 0.52184544098596852, -0.76480850758634344, -0.21336515215860272, -0.063012791921839506, -0.90096794992599072, 0.94041113699871937, -0.88284417468652132, -0.68988448275117342, 0.32998604716806473, 0.070379727562421002, -0.68855792475084021, -0.7893495466837851, -1.1722529355542484, -0.19401446876210371, -0.046456644061219098, 0.69792603361087524, 0.25727400682866941, 0.036251850012935974, -0.83876279961474121, 0.66991570118596455, -0.64631937937150119, -0.50792103317048476, 0.3729142822576485, -0.43499503226290409, 1.0696988423501399, 0.62698531930939838, -0.01031506682892719, 0.87878145123784568, 0.025353932394389118, 0.014845390922036452, 0.88136162116040417, -0.45564227475450503, 0.76683158710400467, -1.1164238672877522, 0.20990854706057607, -0.79307733884205789, -0.45209301631254606, 0.8885236196470232, -0.64387211564243274, 0.43118905297153531, 0.18271165011100635, -0.71760141154832002, 0.81556683333981872, -0.83751606026084491, 0.052414114090656605, 0.71834208721585591, -0.13627755106108275, -0.28270297010898265, 0.88061632291212766, -0.78383245472160068, -0.31207436731880878, -0.76222663067209584, 0.63324097282332681, 0.11845691569102502, 0.49523349260590288, -0.24833959126316421, -0.98773114299615172, -0.024605560347313503, -0.37936506845271928, -0.92669135476804021, 0.56008691716327297, 0.8965487178253948, -0.45097414860916263, -0.61897676433401583, 0.045116977928122408, 0.7112075290176868, -0.094783893907351785, -0.2958954399280635, 0.72997873398786062, -0.90487169102468146, -0.80207208505482142, -0.35276918431559801, 0.95203649573075011, -0.47587884792264601, -0.021871938154218687, -0.67300574795342383, -0.42641379477733388, -0.65509301100889283, -0.21781778111050676, -0.096751165079825951, 0.89818732642915311, -0.31036087483595065, 0.91686094209480684, -0.79423598109167792, 0.87039237021781801, 0.56875490836772569, 0.39699309932069377, -0.31577206041638517, 0.88279185338685229, -0.70002907787274948, -0.051363065380936712, -0.40256490632467257, 0.62351418874666886, -0.32956849999928783, -0.56281037075134388, 0.48889238897310516]],
	    [0.277859744716424, [-0.31765899822235177, -0.39565805490369871, -0.40197909607812721, 0.56823512272092147, 1.0478250520923258, -0.60118221567082308, 0.93824744120569536, -0.77605785385011028, 0.5066500387716486, -0.069176423942850035, 0.76437613218056, -0.84049431067363378, -0.77022876070614299, -0.60890572001189236, -0.37620033743082582, 0.62325632874913939, 0.17742274672482555, 0.75158760859213058, -0.30317808142720692, 1.0295914708977969, 1.2232851361414101, 0.67292477709409249, 1.0630449727130704, -0.1402909328935851, 0.3981888948810608, 0.71448574917679064, -0.31060175648832844, 0.24792794603062804, 0.37819792269803015, 0.20396229999802662, -0.83810735497537081, -0.014270875591475869, -0.97667082254106397, 0.72375998515415119, -1.0654458261940662, -0.1238975182272859, 1.0391880343958064, -1.1299101048502291, -0.44749351198964032, 0.36923016820303373, -0.052304065961621599, -0.011059360675405553, -0.48424338884764495, 0.24509249317583154, -0.56534937416171926, -0.67247306695676823, -0.35766232474794807, -0.088863342892676764, 0.48870244343806818, -0.81476453074521327, -0.98225077458840815, 0.75527028485715286, -0.35336826344430528, -0.58042018531069772, 0.17227494647298194, -0.93583603616809707, -0.18863937755315655, 0.50638256039958041, -0.30257558563170506, -0.0063366991369853132, -0.23472026219017664, 0.041935336158349698, -0.71564518346025019, -0.17171658594312028, 0.75683016510072432, -0.2072378882400257, 1.1350193897576089, -0.44839135295068822, 0.33077988238993067, 0.40295801826727801, 0.046818891401009845, 0.78032152631013774, -0.17199111503234429, -0.75068453396421997, -0.516397391593171, -0.41556222202051935, 0.15219482058482561, -0.4525591842057462, 0.6851056866387597, 0.58657302250019305, 0.75544801258993299, 0.36580129077169704, 0.56016280869194934, 1.1081002945204126, -0.63252941571516241, 0.3504915929059943, 0.022893372761038151, -0.28125290796571906, -0.090147850853277672, 0.20923172080304964, 0.34549305661896251, -0.27798816043662822, -0.78422386264366406, 0.57131726314637665, -0.14663955755410452, 0.96382783070188494, -0.030948748086591874, 0.08180789955103232, 0.84978904569411617, 0.84266868115500326, 0.40272827636355607, 0.24930045835082768, -0.35720573768684633, 0.44670622314971525, 0.87952814826974213, -0.80727895009125072, 0.55690482947542963, 0.092874881744920729, 0.75079193858407489, 0.4303486985894483, 0.2367316360466146, 0.45869960434391038, 0.11668082708967049, 0.23283033013511595, 0.92339358570844243, -0.016226160648530687, 0.037385387595529014, 0.99443693345430495, -0.40566733193647253, 0.95486246016637233, -0.4541445407747613, 0.94813611244645857, 0.12504830022177524, 0.82029830036203166, 0.13474116498097832, 0.68424164011129296, 0.45851255061561108, 0.42961774415640164, 0.47230703448257405, 0.57284126364722465, 0.012644070392533313, 0.2717189497388201, 0.011187155390555316, -0.98500242313319564, 0.68990123628634137, 0.068729913151232183, 0.1519714834764069, 0.41451601398111304, -0.1747088760005239, -0.54157818627944054, 0.15258509177395246, 0.31727643903105568, -0.60747364601571541, 0.30709157644427704, -0.58611818974750729, -0.93624588847975432, 0.24580924791618336, 0.25413867430022674, 0.48865508450253253, 0.96879029246762594, 0.52078671230098239, -0.92053343519324049, 0.48800939640412899, 0.86966255936476555, -0.02580313613387468, -0.5318320255722444, 0.5226310467654296, -0.99120119642977789, 0.11213686123249049, -0.418215760857233, -0.31082492094686187, -0.56976079798210399, -0.15740219706574621, -0.62810027897531273, -0.32150705477534358]],
	    [-0.7595803058684294, [0.85779930135097693, 0.34168870421323372, 0.26622447587231207, 1.0136548384847972, -0.78632449505572921, -0.79781631769889538, 0.14665120969413911, 0.21314177755574645, 0.51622150879475093, -0.7804609039355016, -0.63445995661030197, -0.062233183837490678, -0.5723578047347837, 0.55288890489303433, 0.41997605380615211, 0.55601386189002056, 0.34331173771841911, 0.86416951821259613, -0.20809118524316131, -0.32040428508399954, -0.15456431469436732, -0.89319009814459949, -0.71153040185402194, 0.58591146505189018, -0.53937235975309927, -0.94231447677497304, -0.89332981458699012, -0.90666646658432726, -0.45189332103597302, 0.84992552703934265, -0.25800945587737306, 0.64112741915913884, 0.32926078100069323, 0.79298920730357758, 0.80981056283520259, 1.2819558306125303, 1.0659393967811319, -0.71386736979868037, -0.21181606363966782, 0.438166965239496, 0.744767831229877, 0.6315438555695071, -0.69517149962890334, 0.65436276745157196, -0.47503507170675641, -0.067447051916431869, 0.30844430310734677, -0.49794475019479034, 0.49819907123179474, -0.63667572225070368, 0.16987676565873955, -0.47565017781304897, -0.77093027538219339, 0.97144301173069136, 0.34790924719752808, 0.28834435976848066, -1.1285596183405839, 0.36669612222670128, 0.45790159941492553, -0.4238590268275475, -0.46894262719734991, -0.05218522703603564, 0.13208665884490661, -0.11333098150568147, -0.46856837968318837, -0.32126942907457245, 0.8028051075283732, -0.75752077298814102, -0.57712861488747558, -0.57323843052313694, 1.0465711125939665, -0.68211287067026183, -0.49375664599887009, 0.16216158728885882, -0.87143398987408704, -0.55765184219560004, 0.025095961027449668, 0.58670294570049442, 0.8278320844552215, -0.22852262179899865, 0.82577980784355576, -0.49754676538799553, 0.19563351098096882, 1.1984614746928495, 0.22424068884345272, -0.4060469097844398, -0.55025244541247575, -0.36753893353908218, 0.095904142935023196, 0.046009362976735746, -0.69934706281972614, 0.67196908881332595, 0.77897983634151025, 0.78977786869735667, 0.74999028068732587, -0.61056496631317447, -0.55287518276177194, -0.34386855345473999, -0.45853989270630718, -0.031750809731391799, -0.25484462421449833, -0.52829451345486411, 0.34286936380307681, 0.95980782609580917, 0.40449101996626613, 0.81201243323581751, -0.068678192435327176, 0.43953533853644439, 0.6507024229738918, -0.80748876367752209, 0.97865815228904163, 0.51177761495977425, -0.60234357899147639, 0.10284084542947736, 0.75861250804982749, 0.65740805718265916, 0.38236619914759418, 0.12537735082355972, 0.578181999042921, 0.81851162289068213, 0.088837932476785023, 0.75860169277863598, -0.95333755839996792, 0.20431759930655344, 0.92300320987584683, -0.82698440841215282, -0.051807735384978501, 0.65709983047396248, 0.95952286035271916, 0.35646621540934359, 0.45358705532884724, 0.5763257920981435, -0.21420017555199203, 0.85427022479640013, -0.95174111431053288, -0.50629658837645886, 0.19557053806374233, 0.57559853664202409, -0.51988844706653614, -0.36925030295835382, 0.5691438490824583, 0.41164384205142285, 0.44429881537963045, -0.50990566793501158, 0.1976899418484101, -0.7183555173172782, 0.065415979947449909, -0.1543325976214299, 0.7652907512568905, 0.37908514302780061, 0.60712919795679021, 0.62180188468746722, -0.1927149357418918, 0.89202023356977456, -0.41991385843586543, -1.0033646644392507, 0.33684734733575039, 0.99206128076777766, -0.28077472485095217, -0.558018153532299, 0.46095139280075581, 0.75715253460211396, -0.28340864005635003, -0.84297736787311428, -0.81760412443927777]],
	    [0.75753918335258152, [0.0030567432164891723, -0.73859686826424253, -0.28136252241541854, 0.82294139729784921, -0.16615228337496557, 0.54386502053771746, -0.069900148210733593, -0.99319219530135716, -0.10873063402011776, -0.75949660751279457, 0.0012353705644915108, 0.83136271176861953, -0.38311125897730891, -0.10156629626734448, -0.7299041017442609, -0.47294472881979238, 0.76681613034707563, -0.40260464716490241, -0.62788693623159342, 0.76371772389604131, -0.60814920971558806, -0.39758760137625049, 0.80121419411117289, -0.35259527319804701, -0.59620434205030937, -0.083027961971512437, 1.2117724977045834, -0.59270943808196519, 0.54731802171676991, -0.29634793617867627, -0.43101455263539501, -0.22626586202033105, -0.34800699877313251, -0.27865294500801119, -0.98912715145196062, 0.95821082619411457, -0.32424809824045664, -0.19111666240062189, 0.64749889741714384, 0.52188773456060877, 0.90314377313989069, 0.24168205923364408, -0.84208312310079236, 0.041729646403465395, 0.50588336247821974, 0.32787201752884293, -0.086781281243217157, 0.47190782875356335, -0.091292538899422418, -0.62865275712722091, -0.25327759345613154, 0.50743520287506894, -0.46571952862327276, 0.2462265617872767, -0.36004012687793424, 0.41663950081243956, 0.35763438693688998, 0.49277573764828825, -0.19271736033367834, -0.065927657864034206, -0.50560324534416146, -0.75620110027776466, 0.22663256870144124, 1.5050422334685747, 1.2997273580779218, 0.66660916790641656, 0.91493563047901072, 0.73677192432052252, -0.49333953146898563, -0.96270758568200965, 0.036294828401191297, -0.3051980784974066, 0.16991171700686672, -0.54953190204693125, -0.19840889156962049, -0.51244945902482908, -0.39374957008739409, -0.25150305585307836, 1.5205740522857047, 0.053380009466723249, 1.2022169011474602, -0.034005175123450471, 0.88791056503929855, -0.71413919475779852, 0.32001555401738252, -0.89417422764968923, 0.39875742361393041, -0.94701993320279132, 0.24398016896940994, -0.52086651395338701, -0.24757323432765144, 1.0050021911212894, -0.81057507529592865, -0.40500936255351028, 0.5611810108800801, 1.0598941960866584, 0.60535962558505352, 0.53920907242818295, 0.36614889610986712, -0.20420990428537339, -0.013278555918622601, -0.21570336099808962, 0.31934072543517922, -0.095719256621666082, 0.37222828920389539, 0.70708177984475185, 0.2201432214913365, 0.92390321733626424, 0.29333709147409914, 0.92814497529610607, 0.44384752148274342, -0.4381503501121139, -0.72919961080619078, 0.71604389636326193, -0.71636640486137515, 0.24983267010439084, 0.12183235636373564, 0.20285014042682506, -0.30175607064936311, 0.20894746108349632, -0.032120005389329201, 0.59792180913154547, -0.99187390965545486, -0.58183573758762108, -0.75641903945057776, -0.72866385776503806, -0.76470496243518649, 0.41468691812555902, 1.0194439169447076, -0.12744547737515391, 0.64195384149691792, -0.61354741156898573, 0.2035735128256464, 0.86765748347148219, 0.63159415564595378, -0.96904281121387759, 0.85754878845207438, -0.031297169595084454, -0.65120425988466268, -0.16241421326437716, -0.97386620842742078, -0.024276870876016095, -0.010477104959037472, -0.2786393441401635, -0.12549472400146924, -0.67657970886911134, 0.012767103354757186, 0.92416038821257074, -0.56148319820380688, 0.11097207864402203, 0.45529024080072206, -0.74772700350083365, -0.63402945456440196, 0.94326009054223003, -0.35671458117543337, -0.78043830958913718, 0.10461673288468651, 0.92988690342140379, 0.23242846518734386, 0.16070993092018249, -0.56658597084346507, -0.13832175553369463, -0.88465842239968029, 0.37739969954997576, 0.20700013189721456]],
	    [0.39122646483467527, [0.69750691651279673, -0.67943876614071064, 0.43788959818098855, 0.8078291802450599, 0.45945449799685534, -0.73306439647307609, -0.86912082488614573, 0.94556339382272381, -0.41575302078826015, -0.29061216252684963, -0.53067932247464134, 0.018076985453520576, 0.059311315423220469, -0.0061759814200010865, -0.35985457062194115, 0.98007423554491413, 1.1501158498174202, -0.17801781883669104, -0.85668817197800606, 0.23014531817704806, -0.24440162039883565, -0.56761873073452851, -0.18393704826684951, 0.77709322932714908, 0.11311667952994348, 0.86308094070744634, 0.52132623987242188, -0.45238087427281104, -0.82724952963716258, -0.52462873444684632, -0.22437569165066518, -0.078007352766839344, 0.32124075337034458, -0.81274618470839743, -0.73784947787198263, -0.33045753950471646, 0.56028672397266521, -0.25568192453838007, 0.80131319467622297, -0.21138098745687095, -1.0789169909914771, -0.25958537264607828, 1.1241869280467915, -0.220601369010055, 0.031745520921333537, 0.72612453492055951, 0.33246600676671401, 0.084777361497913567, 0.43978605000901422, -0.90187691066569142, 0.62438756338607493, -0.40613449369828653, -0.25652849627383456, 0.2362249783196845, -0.30885735649237323, 0.33070335668512851, 0.14517178692256932, -0.057585124487955164, 0.96972952776894772, -0.28885167311621718, -0.16351730469447973, 1.0497909374090812, -0.13623855105179711, -0.98577361154924026, 0.41665774019610236, 0.21506878141330457, -0.74930920274329271, -0.21048126883093696, -0.35401969785876214, -0.68898899212475118, -0.99850367874270551, -0.73365440726714293, -0.6955763891542327, 0.89863545003158696, 0.10222465207677778, -0.92302363428655687, -0.29755564377050081, 0.19387076056493399, -1.2258619930199655, -0.27601417261844519, 0.048317485264856214, -0.97399966384030823, -0.67412047802033559, -0.59744505853907059, -0.97547847478712502, 0.41128718786411606, 0.35414970606155111, 0.52634786220330232, -0.41682897824824244, -0.51364819620883617, -0.3791029782501914, 0.56758762933025808, -0.53158317886674389, 0.27814556836895604, 0.56310565764746312, 0.15650933250104421, 0.89721712133191889, 0.12987873131524139, -0.64109968991001731, -0.025523035421727614, 0.060499707238097986, 0.3367847450701601, 0.08815634703136041, -0.84118549189151615, -0.78347029666943935, 0.86802374867501164, -0.16573483049804277, 0.3191160673590524, -0.27720590111635124, -0.01088623151582066, -0.2521466628692543, 0.56666899818742344, -0.49646870831116446, -0.87973489638632074, -0.68626976625645542, -0.32474641760894241, 0.36928619125274237, -0.96767891619530855, -0.84895330411598824, 0.073345981314273501, 0.99193513431622726, 0.86841824057975348, -0.57648301659257117, -0.14611069150616965, -0.44984954824184398, -0.23018267342160734, -0.77644987720228875, 0.14363530840454003, -0.56496564533513582, -0.49179181665841565, -0.66648495880180614, 0.72204756041250329, 0.712597493252767, 0.0027964896564329996, -0.8806782127147077, -0.81097622784500056, -0.10564900321629687, -0.56364072301685142, 0.82866343599733994, 0.49122550120557518, -0.60023132837339088, 0.2735404920893178, -0.59466490128388927, 0.11741056571478353, -0.14727921322239754, -0.49789051427555636, 0.83386847520659513, -0.30907449121820879, 0.14355357270638072, -0.5211544197610245, 0.62234908242877707, 0.32230382028490545, 0.79670428385361025, 0.12668978777596707, -0.14946644365020903, -0.12411266455417901, -0.27611243341461522, -0.092758604457850877, 0.7842846632656103, -0.14369600784660497, 0.54746234980841368, -0.41389955248582422, -0.4016027395468309, 0.89915170949567558, 0.68300165173563676]],
	    [-0.13410501322386845, [0.26999721843694685, -0.95468217999063953, -0.17881159322281454, 1.2344949729251911, 1.0949609818914019, 0.24274352564850438, 0.76540407594101734, 0.46357618976912807, -0.87629872934490793, 0.83740958579341329, -0.39652730122614838, 0.65335485281996564, -0.2238529634544365, 0.24311033713914099, 0.32801505212578586, 0.35828433930728626, -0.004328712971546903, 0.18525903008213349, 0.2727637665408727, 1.1311938630389062, -0.42514839273557703, -0.40584275121910302, -0.28480689548345561, 0.40241581226361961, -0.60071140895623332, 0.74001966869199887, -0.014568793361359128, -0.39333122150452188, -0.27883779950149862, 0.25773453535335267, -0.17266209520181711, -0.74866691984269884, -0.60105771530695729, -0.56588186479416458, -0.95272844837430981, -0.58901400402575987, -0.22668932007215675, -1.5261142110716734, -0.35239741231582067, 0.96514328806485328, -0.42348947511356222, 0.39241902407797996, 1.1108225035751202, 0.45795631226590083, -0.16990250762384806, -0.12325357301355665, 0.71101719349477477, 0.31035982442878213, 0.23269775613248128, 0.82802294865366244, -0.20704644267272004, -0.75372659175341539, -0.24044332931450246, 1.1304220337835535, 0.0046340636940252157, -0.34086501655913087, -0.50904550540245985, -0.22156345035466549, 0.35910510053222022, 0.27908040781281107, -0.30568487962780017, -0.99382476577885592, 0.18965885415386899, 0.28854191493353143, 0.68514209863344611, 0.39801380514250034, 1.4849063985519062, -0.30321784774353128, 0.21529640553931689, 0.6553744874317422, -0.4753034621844322, -0.33510983433815322, -0.038609497356231412, 0.927668325727391, -0.16089847647839672, 0.84179557110093672, 0.50541619374254632, -0.2448279050747931, -0.66986167000177788, -0.87540070907546386, -0.97206613439436573, -0.79463798444902156, 0.10715840563216232, 0.10149234018417598, 0.10087005598822268, 0.42746150557973162, -0.75003747668763243, -0.44644274793052136, 0.026575748308713776, 0.063703856158343175, 0.23076796090381246, 0.97650209511952901, 0.014710239582685688, 0.01443019426808234, -0.20759852090985334, 0.93905588843488774, -0.19215818601952714, 0.53928341358049281, 0.93002357365983535, -0.13900470016111321, -0.27661947225360189, -0.2735286983826612, 0.029505515751012092, 0.25440888666886802, 0.87148333761308994, 0.50086274700618216, 0.84909798135518921, 0.70591404570861316, 0.41993247834153469, 0.46543648596112719, -0.78729054670004572, 0.25820623062715942, 0.093365699901492849, 0.60047463935524259, -0.24130204062900515, 0.40388044061514194, 0.20156601475166361, 0.38067263467324425, 0.33660132308848906, 0.71095785829082625, 0.6358135780230364, 0.54142449131606984, -0.26401521088534902, -0.65959884844515504, -0.71883047048464721, -0.80657480433447537, 0.55080116093144604, 0.53459859848548674, 0.3050918632768348, 0.59741603918672925, 1.1384699489974266, 0.76942438010831082, -0.048849627287585407, 0.46530792886600947, -0.18913072947592907, -0.53511260454626541, -0.19681498722273821, -0.46354478529333432, 0.13468241527466257, -0.8321750989539568, 0.87115841854821519, -0.76339304918506079, 0.31992433546750215, 0.46263282190458144, 0.3950362706923663, -0.7381339239437672, -0.65460538961233494, 0.26713347442117708, -0.4540692115915263, -0.63075701229651737, 0.10304059458027327, -0.28915872943672311, -0.53976989537138231, -0.59690257555724813, 0.74588422373283292, 0.60617108348960458, -0.51151809041725527, 1.0645447188395996, 0.44852657886838299, 0.32162433331109463, 0.53624613711422575, -0.9128211254029035, 0.82373159981673871, -0.74035398232328142, -0.11690140837714069]],
	    [-1.003973374085674, [-0.5817734205869689, 0.0036986464158395549, -0.92896760143796842, -0.81334928508223558, -0.57920725786982985, -0.51604927492429464, 0.28000705936901116, -0.048070529852591394, 0.14956163812721074, 0.033513522301348395, -0.3698920816839541, 0.48887966078512279, -0.28630328080505063, -0.87383463367318437, -0.62388967484330737, -0.62106493425099873, -0.18795449663658129, -0.52646408219725038, -0.29342967221985805, -0.78822758131928072, -0.50514679920928518, -0.88688937853403671, 0.22514917881451108, 0.86194977884729462, 0.18224905778106276, 0.27169832943587729, 0.068543506080239167, 0.95608576695297631, -0.17331505767100794, 0.17699671086136637, 0.70067103459119717, -0.17735961260047745, -0.23770537658181889, 0.72517850509271364, 0.17625568805008601, 0.032315265255842288, -0.87876990571603297, -0.4041545355359602, -0.22656418303393355, -0.57258551218295217, 0.050275093378860401, 0.038579067178638994, -0.88214185087337327, 0.57022482103819028, -0.35635937976751886, -0.4687474434162891, -1.0670421157460948, -0.80659144450299114, 0.91995167610305406, 0.7329645481671615, 0.32295784140801764, 0.97858352111660352, -0.44758958782253377, 0.78270588200606084, -0.93382723348258501, -0.25512095584792749, -0.23964453252310713, -0.49500641740991863, -0.9722474325991346, -0.11828042933188421, -0.76819421570008295, -1.155239728976921, -0.68472973635846035, 0.68345314017915826, -0.7211536566059632, 1.1650318792818173, -0.48856199946000528, -0.32870168419115264, 1.1262963520735156, 0.52360683249180062, -0.057386275779747108, 0.36714822705473743, -0.74336950949040836, 0.020670893942360349, 0.38577024751866995, -0.37296088235251468, 0.68204378088203221, -0.62414377696263434, -0.07488238051740384, 0.87843532219956399, -0.23164668355274157, -1.3121171269102734, 0.2940547404352879, -0.1028271274950301, 0.11802499901381426, -0.21099804219268653, 0.50832611582330922, 0.26897298706952616, 0.78260228582231661, 0.26104692162824561, -0.68573224393001886, -0.31005959007892692, 0.11787889472097193, 0.76194576512616319, 0.88566266673078964, 0.35882147926252833, -0.089377912757443265, -0.89208156157056029, -0.46644570956487691, 0.075272634022469323, 0.62441821970059064, -0.81355439227264315, -0.45094549463317501, -0.15411991507121772, 0.27603790369677916, -0.6949643010610278, -0.1238869501631409, 0.10252687924680483, -0.61768103035590216, 0.18321281775311141, -0.27711941092187758, 0.085837405437563782, 0.64163077230265109, 0.38583352592895481, 0.48762987556220949, 0.89601472582579644, 0.61536257897988789, -0.1492271085884371, 0.62691253297110228, -0.4647189485388411, 0.21225126601828506, 0.634401751501806, -0.46901454539749043, -0.18217142053425653, 0.0045486281894512393, -0.31937638154369907, 0.48644356551251056, 0.96612087759458043, 0.16387075891908695, 0.36594900311544554, 0.82668213214492858, -0.062415164716975224, -0.89860678060963839, -0.62787029985860943, 0.2213925702873597, 0.39353436755182708, 0.12332996004095566, -0.11697714976523185, 0.10826319805847305, -0.35396907978601905, -0.71544523024029483, 0.4924547737695455, -0.73598608514936659, 0.8749961285985498, 0.56689814154741214, -0.037336794153655768, 0.26468522975548325, 0.75971927265308559, -0.72809626615001688, 0.92387899646327298, 0.69411210066453388, -0.43359233333552527, 0.48427897109783946, -0.2070247034619927, -0.19837588602153383, -0.33395094250667967, 0.68156165499760035, -0.14939788530849174, 0.41945372526990982, -0.28887508709231979, -0.58460276385356247, 0.30277964675239177, 0.99034633782159931, -0.50016650311306954, 0.22342685856479827]],
	    [-0.94970305269151867, [-0.54184800799781307, -0.57571433457149634, -0.93604509583320983, 0.052554569576176532, -0.48704818501201846, -0.14384035064717421, -0.49964874116777058, -0.21881545759031021, -0.87888701697474669, 0.17194057011176708, 0.39615449360685162, 0.67260203918183259, 0.052753101735795456, -0.69404202055383735, 0.82519751314970113, 0.065059218364808671, 1.0154165563444089, 0.68120698274376956, -1.1591983971604047, -0.89980792084570893, 0.85482575184436782, 0.75327202369052859, 0.069886008319467105, 0.48342707420377662, -0.53221852841085004, -0.19175061858244694, -0.83080998766053571, -0.70517709852084454, 0.28232120841062097, 0.39220438712031336, -0.96013251459649451, -0.99679971523230404, -0.21537557026666734, -0.32231065484986882, -0.41992290939124355, -0.26517377661946923, 0.99297426291098256, 0.8293108414160576, -0.49781622025813982, -0.15287011460298408, 0.26619339177356188, 0.18901413969889544, 0.33517627851362297, -0.15686218294238483, -0.89802446362813204, 0.80164852439582568, -0.27144914221936145, 0.69574235434659892, 0.37273927682077407, -0.54596846383953801, -1.0094082176102908, -0.75812276601797679, -0.53232525640697803, 0.27104555122878538, -0.81676934111414912, -0.011947039756874157, -0.58633796607457689, -0.56501145665659236, 0.37538209465389666, -0.97283452831280282, 0.039388699270811678, 0.38684057117333226, -0.57935353455209615, -0.71249898860112437, -1.1323516992880465, 0.27231018632576504, 0.33777488438004288, 0.83985002953613208, -0.64043546382858096, -0.25084808448637308, 0.95825358214292422, 0.25700054483911311, -0.20308366030502206, 0.1301303536506547, 0.81990579608086556, -0.95471365677814435, 0.84651143804499629, 0.054269265090560292, 0.36260807184586463, -0.40931402528770194, -0.80250816858937413, 0.98246595175836493, 0.87883331226600636, 0.41135671821188458, -0.22971932285881605, -0.7757703768709967, -0.61684909362120988, 0.40475558605494877, 0.033771099278750778, -0.1364988175583508, 0.89365540861193138, -0.11567328116099139, 0.057968147867788658, -0.31020521605663254, -0.064130312348470095, 0.32471399023146158, -0.28522649940916667, 0.044310611689271286, 0.88288321992457319, -0.22222685716135657, -0.25572721047200286, 1.0313307007704355, -0.65894544687946466, -0.22965683358216171, -0.032716293380596735, -0.29895463884270707, -0.53801865662289683, -0.45039833535505297, -0.79278438205047563, 0.30133247857719075, -0.11029691571791747, 0.78358136064916839, 0.11848714415377898, -0.30897204492704572, 0.29914597796545134, 0.94328593961017548, 0.0053677055823687699, 0.578206956892795, 0.418362150142355, 0.89810243291777669, 0.12443507372736388, 0.83561238327588561, 0.67751139009056183, -0.3080492137930631, 0.32622756846608575, 0.50995669935055787, 0.1198545565687488, -0.68491226805518779, -0.97339752374946298, -0.97671039763678691, 0.87967014655000075, -0.42307621366569137, -0.46247808857201633, -0.51675842466586686, -0.48429014913950663, -0.50312662976671541, 0.8814684677889767, 0.95852717237374796, -0.52214128575765617, -0.73959385212603779, -0.25952238941751021, 0.73791699741701966, -0.80492876893682597, 0.14702421797400986, -0.65411027799411203, 0.35825802686414787, 0.35356000733969872, 0.00091261629824619921, 0.44491054024796534, 0.71089264008995556, 0.005250061186468113, 0.94500388906699906, -0.95592206958280657, -0.89596304584152242, -0.46660794207181461, 0.19485284457818919, -0.33300274295487853, 0.52006346818254479, 0.099894585593614263, -0.01295977583483765, 0.84164352317842672, -0.059538459169330649, 0.90640232860579695, -0.31424918420525794, 0.35630191817114554]],
	    [0.29617660116212619, [-0.43769839223885437, 0.065240188347330294, 0.51047960006147508, 0.68312654284497121, -0.73148854067552294, 0.3131003060187591, 0.14628345910787821, 0.25775645963096894, 0.099654914261566127, 0.04175946384127141, -0.5305350489283539, -0.44147677660185058, 0.09672329316558273, 0.50584428523717118, 0.42715966916098669, 0.70400898771462284, 0.34214795087768879, 0.136662312092869, 0.49359076042724448, 0.46898395076938054, -0.37848884284165829, -0.12636871588004917, 0.3630847665832197, -0.16739345237636219, 0.41850162866623042, 0.11347076406181753, 0.14028194893973278, -0.53024683491932934, 0.57887258864735869, -0.37319410359220151, -0.055774705962263006, -0.87160782971798823, 0.37457772844801268, -0.68585029353825733, 0.2587198453858468, 0.51329743508008563, -0.36942023531783874, 1.0242457635097446, 0.19961640633117875, 0.39936575086998582, -0.66174397140059449, -0.6065305498690442, -0.76746415056489192, 0.20320833174442721, -0.09728933967836273, 0.6537951099977749, 0.85140082595875743, 0.47975193409465305, -0.87146284718284051, -0.5288649208263374, 0.027921168331863602, -0.33481250147005948, 0.3425354060586408, 0.54677533371695552, 0.053592781192423042, -0.37049112293078956, -0.12223516887890434, -1.4229638553491555, 0.91375998957087401, -0.05644002130159631, -0.20141413557493706, -0.82836952081585469, 0.91984115380545961, 0.89998558172727017, -0.15783243408324374, 0.14192479575288433, 0.34204090097945838, -0.45788074283519054, -0.57696696530837566, -0.56996075923561684, -0.74300322125547291, -1.223351592564069, -1.1194966269911797, -1.0031869419218609, -0.84236556877075874, -0.5470998577315479, -0.19794960773994238, -0.032456178120587022, -0.1904432430426504, -0.72936203902136787, -1.016432004303754, 0.31348409532139215, 0.45181619800338935, -0.79853775682622896, 0.14082623488495244, -1.1695344891265842, -1.2161400367359014, -0.079195602266142376, -0.56679295176827005, -0.86099333091889529, 0.68331044892672177, 0.41991024287907003, -0.60700298815888498, 0.28196782784005775, 0.77973430663031507, 0.40348416082332356, -1.0486706522100253, -0.22856596892704018, -0.10132297181015719, 0.99211900369678863, 0.23917385549973491, 0.73830626829153767, -0.23845478444834939, -0.37733904805273805, -0.12159399344853965, 0.75309103778968867, -0.0021854107914243198, -0.19556403052250038, 0.060468677375423725, 0.33535940332784914, 0.12812373266009777, 0.33159972931738668, -0.49841365397906656, -0.95012048228197776, 0.077145858209511517, 0.76602581123876234, 0.043582902533425151, 0.68921541907898631, -0.079021511796599692, -0.4396064820103382, -0.88284045793424737, -0.28898565998842429, 0.51515589196823808, 0.16931701083978914, -0.89104918936287114, -0.96250876256322104, -0.49442177725494885, 0.62738972502528922, 0.37013601376745742, -0.035123638209424476, 0.011975499469568746, -0.13615351153669056, 1.0495944014900371, 0.73226891465638977, -0.29911274580874847, 0.72899070786283449, 0.44788141987253227, 0.31103193815717156, -0.11381009246104269, -0.38510035089815253, -0.14553035360042077, -0.28147024629038475, 0.11891613248844407, 0.81418867210039503, 0.87847225804127382, -0.94110520709543533, -0.15372303789955014, -0.37191549150108238, -0.59839338825265476, -0.79679167825380359, -0.84942942022207146, -0.76507562583867539, -0.27301978913526598, 0.15676474033645843, 0.39052283261954862, 0.87681230960109247, -0.5453179807267643, 0.4882107994295618, -0.8007838051498718, 0.11362116760831786, 0.7425984038167095, 0.68996510490955898, -0.32348216865975865, -0.13035872805642001, 0.05615955565082742]],
	    [0.34243828842004592, [0.37549790289275808, -0.92986155278772498, -0.081953504809000738, 0.72871597679592248, 0.040942180329682054, 0.16229636350363114, 0.63455592146213258, -0.58613215149075815, -0.32529995177502524, -0.12285738807861299, 0.27123557349055227, 0.18952571825140019, 0.16928217061756359, 0.16618277305431306, 0.51335216823390573, 0.78749952108097276, -0.95204026175332712, 0.95616424591984039, -0.02699499013315762, -0.66906462809062728, 0.048804920135607679, 0.051618542749594487, -0.92139113953573915, 0.24648113951296063, -1.0380832633529613, -0.80657092956764587, -0.057525862394293088, 0.36224952259066995, -0.77260840597942038, -0.029309092228217537, 0.75763529247496064, -0.32855125641998623, -0.11264497398053011, -0.79915917713650797, 0.41885271457327877, -1.0230037502698612, -1.2485715767221874, -0.12004531576595472, 0.72573698963831723, -0.15303114104768853, 0.60970738764096155, 0.49793667534602493, -0.94966777905805932, 0.55374457447822789, -0.58860336716079131, -0.44053356940311494, 0.089050639033119952, -0.012125457350222468, 1.1456705535518679, 0.5059852361172682, -0.52816624265601941, -0.65423744840669518, 0.90297232780349002, 0.36774151515244663, -0.95071940576645109, 0.51892390225687213, 0.67117335928934496, 0.073059714663433695, -0.70604428863521496, -0.47458094317093247, 1.2765392101289648, 0.41139653620016603, 0.26115776874756719, 0.66165156179724482, -0.67268534705009653, 0.023187534533487115, 0.39526757236864185, 0.19018248477569868, -0.20198008670443332, -1.0789180378248386, 0.58945796021255281, -0.043182870107641103, 0.38373975267948957, -0.10961870217781555, 0.58847876820006495, -0.13682022305348401, 0.76657497849987344, -0.25313671085249989, 1.0140048200210927, 0.57492779091903279, 0.11492017587290641, 0.3885210044012315, -0.47636965486471983, -0.81366937035454912, 0.66509279860147796, -0.72539003068442953, -1.1584576511588633, 0.18856468637755941, 0.88715709625166705, -0.0046101327018888139, 0.060748163555033548, 1.1052688100867509, -0.55489805770612621, 0.84838680288598589, 0.86835475779597371, 0.84049565766859757, -0.71529267776443806, 0.41816036819742863, -0.3865871586187889, -0.10220036466000146, 0.99427675452010567, -0.79939451025484121, 0.4383436236937342, 0.039513652998201254, -0.44726338772366103, 0.63440379643591338, -0.60277349280787973, -0.83404454106181503, 0.8281110154207092, -0.75038643200899091, -0.88901718777521688, 0.87826914107023601, 0.3309555819756333, 0.29518771300255309, 0.6480295468737528, -0.19559306811597563, 0.34685122742483204, -0.66829793379057489, -0.90702346398641054, -0.1753800721106385, 0.35750905285981488, 0.33149478242769487, -0.68484818538126135, -0.80924462659470342, 0.89521344827646621, -0.15717333634120917, -0.027035328316218181, -0.56504206175219585, -0.51015578649565441, -0.79476334578510677, -0.68137491135273076, -0.08521725715978104, 0.5616110500710797, 0.77097695045691617, -0.87988967566688103, -0.45538212838282466, -0.17978110960892943, -0.699959059407119, 0.012251048391896769, 0.38780789828301176, 0.78174102735884377, 0.68878153283072874, 0.82278407896479822, 0.071079913074841933, -0.92067739293277651, -0.30084810833611436, -0.89644006476132876, 0.85246987749298742, 0.071295873539171439, 0.76201332800454225, 0.98137919949369057, -0.021433412837629038, 0.17233176736731748, 0.53324533023196519, 0.029286064621684316, 0.58930895966525565, 0.26234263839116712, 0.39486414851253315, -0.16739487982902845, -0.47734476564591533, 0.95304981636560893, -0.79351755877828967, 0.41621136265106484, 0.94039181662334204, -0.1734192557264187]],
	    [-1.0794826502050088, [0.55827681124119366, -0.30396899407773281, -0.20685125699961382, 0.00060723701674714214, 0.28722832103732604, -0.74030783887423701, -0.58082262962024245, 1.0779507577859315, -0.15109320359082531, 0.31584124374006778, -0.20345031632548288, -0.27481543837500283, 0.89715467220789669, 0.45132245689523542, -0.51395303420640404, 0.27948900882914807, -0.7259894655171345, 0.045627352254727575, -0.11966142224116534, -0.11796543860375096, -0.33308148113841585, 1.2487155138162205, 0.92664627510778652, 0.32930116609032084, -0.76679397481314593, -0.77129747911632418, -0.80440813438007031, 0.78905863266434495, 0.5659794021807647, 0.85758014516764836, 0.17962304076720567, 0.40111261072692284, 0.38276192299755202, 0.6079298342284527, 0.31971419215550528, -0.55553459076529599, -0.37274607593879661, 0.86662505554706692, -0.11967943715671943, 0.82340275773891491, -0.86605469924045908, 1.093370380616046, 1.1254145930839556, 0.17595629116229183, -0.40723781171485962, 0.90351636563153281, 0.023681526398047346, 0.32250842998172685, -0.088650624101505635, 0.43335690534288407, 0.12853843331261325, 0.034761847262535055, -0.022801952323061238, 0.5582134571932017, 0.048522702180194305, -0.82461512406451887, -0.22445982053432142, 0.674637399510993, -0.26450720743566219, 0.12232206467419382, 0.17251735994309414, 0.15294702055482748, 0.54930801758182068, -0.58625894145546464, -0.19034902908615614, 0.62257262307873873, 0.74406801556553881, -0.20233544155532793, -0.94908870827747982, -0.72944951600472241, 0.90015547241330429, 0.35470237353211848, 0.59433015925403054, 0.081782980240052275, 0.14407575215986834, 0.27702576760715591, -0.58161793389732985, -0.098027029868551427, 0.73301324133288015, 0.83215622432709391, 0.1747231483382872, -0.61544948146457379, -0.16072991993417324, -0.01947662567143766, -0.53036640510211464, 0.35565253115989975, -0.36381164579096109, -0.16356169722747044, -0.21651336619124378, -0.64565010818435176, 0.0618832824162956, -0.69440089609643496, 0.066187120201529767, -0.6361678582694682, 0.0044254130416380389, -1.0527343827324951, 0.83394705805906366, -0.5949965743260387, 0.49255883974973164, -1.0810168108163516, 0.055068290357917916, 0.92296281708993577, -0.056478897687018838, 0.5018751381066211, -0.63665022124004123, -0.45454138144670453, 0.66750360897816752, -0.6510831773874719, -0.51624298908090338, 0.31560598863527778, -0.45424271825592749, -0.70129659148639312, -0.48579353592401736, 0.8777887046490398, 0.88042265601751735, -0.79170442411423536, 0.43879272898035493, -0.15130381301381099, 0.074260338743764726, -0.72134221363335271, 0.64944312627796241, 0.26036846824288373, 0.34361938837655859, -0.85077422543032655, -0.040146051499594257, -0.75638833198158084, -0.7377115264151608, 0.37340721530268084, -0.20766709586238, 0.8384100596826537, -0.21306085518042811, 0.78074070982543176, 0.53953255137057132, -0.12673233743311718, 0.94936880117198241, -0.77357672407934719, 0.47845276638027745, -0.2199998081399348, 0.76683844319252259, 0.46636652294768266, -0.1304779140806287, 0.16117906573486443, 0.73457273660320299, -0.26159239026473119, 0.29576029088794065, -0.08568887673614177, 0.13475060341742165, 0.70748675922491788, 0.2752418428809319, -0.18363815088424684, -0.10849342262179286, 0.33558089050087253, -0.18145536782419538, 0.27257199096350954, -0.89349234563941149, 0.46838929855625777, 0.28939822917309882, -0.58789345888422473, -0.55968513354695204, -0.23320603690132402, 0.47192226604426502, 0.22073432894381084, -0.24984429121486751, 0.37967220656178347, 0.0032880904190983884]],
	    [0.43791805301178044, [0.45464306836264184, -0.54890687905240187, -0.17906184402535424, 0.050608573740459954, 0.6952656060197252, -0.45476906160722025, -0.61739193203439113, -0.57555624712780329, 0.072244723098991978, -0.80492391911732208, -0.61368726533832729, -0.86256172387193786, 0.3325766016203448, 0.5773465598439429, 0.043693788528488486, -0.037346026858174515, 0.52265299399680842, -0.5038526656801785, 1.0499066416629212, -0.6693106470702388, -0.32144181793330534, 0.78829454643883512, 0.91405918779329098, 0.56060299234387012, -0.39007189151860011, 1.3370106754413078, -0.30856072622032671, 0.74898019838778884, 0.88426069789237038, -0.83652702286492264, 0.31317161578809949, 0.67147436495514956, 0.33828238364379437, 0.75788493475796148, -0.63255889024607681, 0.58534980007934556, 0.35405756180165288, 1.0497225102547973, 1.0877337097850963, -0.28385613973701163, 0.44764992751575822, -0.94244158814149537, -0.72229338761439343, -0.3353448447570298, 0.14236123217006824, 0.94378944893022865, -0.3968431499115917, -0.45807139142715692, -0.71555069663038418, 0.98581002917637306, -0.58555621372493727, 0.58386656627422406, 0.47175563522171249, 0.31274776525764258, -0.64544470902583595, -1.1291041902345149, -0.028134741389738586, 0.69409082949408007, -0.89415759110366111, 0.048800959557544044, 0.71363877914300244, 0.52983290415276507, 1.1979938579716234, -0.97360289190659288, 0.077902305093560206, -0.53434683516671522, 0.61307347703863069, -0.87187569843586321, 0.82310361608238181, 1.0463944678854225, 0.32373264515933564, -0.37081305212303217, -0.95587650853066108, 0.66785521828244299, -0.7510632609555854, 0.096904904684599724, -0.14176518908140356, -0.77254933512951496, -0.76506488245588922, -0.31828715069739294, -0.041919051910791941, -0.65728503161309437, -0.1778328026906453, 0.022298661929748453, -0.093668187265026195, -0.14694450300061826, 0.71382611020217801, 0.44429961145400587, -0.91186994374652808, 0.71549344803776749, -0.5023434207433769, -0.50917162002984639, 0.26960807071532622, 0.88651664210658365, -0.20552109244432856, 0.81592635413481751, -0.88491152720136923, -0.1142090012521587, 0.54108894417182596, -0.27621648212053501, 0.49834854163590547, -0.63358380065338904, -0.45849530629426188, -0.6713900457067542, 0.97255347758250021, -0.9336973620499377, -0.58688048145814264, 0.50737902232206389, 0.097104846073509804, -0.45675672728064992, 0.99728144656182882, 1.0196234669556847, -0.79494777146143825, -0.38343748248664999, 0.17345964724126861, 0.38720604665531633, -0.86816901082484221, -0.40533125898056532, 0.72921855818673298, 0.14171824575618766, 0.39577113465729968, -0.83352823183936664, 0.17269680291967396, 0.60484717524071141, -0.52442195735621389, 0.65481330952630157, -0.61110118016878145, 0.99067113248434158, 0.88242692212225704, -0.53943545859921316, 0.8679690579000946, 0.3710022201043443, -0.40816750685442349, 0.53442436523897519, -0.23449328109994316, 0.30599304683830153, -0.15610680465490026, 0.59807845864269282, 0.44603683579520803, -0.96500647899640424, 0.68138943111138961, 0.52944057078079743, 0.45515056983430191, 0.40195198030337354, 0.82422482677457198, 0.55329160276010525, 0.31202476728906708, 0.47851029546527279, 0.025226210513802617, -0.14988612028050685, -0.88912126516307333, -0.93695468794401138, 0.9896646178160996, -0.8407907564172139, -0.67922814620562311, 0.70700098554683943, 0.48820993959790948, 0.35343942869400924, -0.16291944089124838, 0.11071650030230562, -0.51854883906897786, -0.15347774315411189, -0.27788722119275455, -0.4397124440112965, 0.86205740507225026]],
	    [0.65269692280181923, [-0.17761460654094299, -0.095606014370676756, 0.77066867677672912, 0.82141293189291598, -0.95731381797628656, -0.12002046689744153, 0.86670794968332521, -0.42217002460055597, 0.50751594797909105, -0.938661460256766, -0.78650827833908221, 0.20232322701951216, 0.62812673801972718, 0.66003223158906144, -0.83189993512301874, -0.33482478019954021, 0.78500350552162679, -0.2804908221592754, 0.3322594054665679, -0.0039962845848133602, 0.52492227699751526, 0.8170245801968109, 0.757025802576475, -0.48323117763621193, 0.59348583946041056, -0.24051639765534652, -0.26379430079431859, 0.50308132159428809, 0.42675060033290424, -0.86442315830357574, 0.30480065836979331, 0.0510622519439227, 0.65389387216966566, 0.62051258525226427, 0.38837492247981437, 0.54682881776687908, -0.38502927474571186, -1.039865908437009, 0.45841097485776644, -0.83823004730321993, 0.48680780892589176, 0.57459344701020731, 0.82679777122634723, -0.98090737038448717, -0.25563077965631709, 0.76106335509514911, -0.4467387249834221, 0.83149470428461003, 0.35459261402404912, 1.0108542984019142, 1.0596651738144354, 0.5739917354691948, -0.25249608061671874, -0.42686731052941912, -0.78603117650303445, -0.43963526192596175, -0.84580198238542914, -0.20073928473032718, 0.098170819689769026, -0.10142914831525185, 0.22985462472656068, 0.74542286963863813, -0.21313862963411279, 0.86208356777437123, -0.22553101880244186, 0.62411430404027135, -0.17405751578000353, 0.1765939616058135, -0.36324048132118414, 0.27868416303009219, 0.061803039005095185, -0.40548192705319275, -0.17272514832691005, -0.41523236213045295, -0.98305707238400752, 0.5982719042878466, 0.062667848221845193, 0.50033245732855636, 0.40993528186205086, -0.37830622933750835, -0.41608702007135645, 0.024241514715916981, -0.83976717305588089, -0.097591186849074765, -0.37067450463224721, 0.84172674272277104, -0.13501838425025475, -0.35624031588801913, 0.21987922197451049, -0.84219116671056815, -0.16531162606792038, 0.27775326897960362, 0.32073134322127117, -0.71185281884082641, 0.79964557858774399, -0.065030962857664118, 0.71749185385585512, -0.015713850372862725, 1.026309379082804, 0.45262709630772846, -0.35562118975172491, -0.10161483953475098, 0.97795010149784634, 0.53035732015068171, -0.6238725100475041, 0.20575662919221668, 0.52762092526047466, -0.55663034849746351, -0.647008350787321, 0.70074228462692512, -0.45384488727861322, 0.93319505896919686, 0.32494939949287155, 0.82424345103674268, 0.29323549625191542, -0.43122003990165225, 0.78640290231481214, -0.3424745297728411, 0.77803275107653835, 0.85498619425440048, -0.30344248149840902, 0.95805102499075157, 0.71500159531380614, 0.19652917075352086, -0.35130342554811705, 0.56483812419377311, -0.84277105202041369, -0.87346130574591463, -0.34214376581936401, 0.0045306000503681446, 0.49009207032697893, 0.80198614782776467, 0.4745783490203484, 0.47276721743250771, -0.20029180228282858, -0.81846973870271122, -0.62847840353587436, -0.58311200832446131, 0.46858604544806631, -0.7455310229762776, -0.74948554172289428, -0.94975574101510607, 0.15775275649309128, 0.82026662293421659, -0.024936171303531752, 0.6822578266598367, 0.39779570603312947, 0.35059506258249196, -0.45750398996497849, -0.30174534648295781, -0.48796587935305774, -0.1952250267225786, 0.51395083111983053, 0.54169081558714216, -0.90739465625935611, 0.17983894432220499, -0.66852603506339248, -0.95094553677935456, -0.58984062384755809, 0.6314349894133322, -0.7160144510021289, 0.23676122618406303, 0.37986273036201013, -0.76940993175618155, -0.52393728189047595]],
	    [-1.0017631307426558, [0.15448247993738831, -0.61983888544054866, -0.9774000530320972, 0.16754119951585414, 0.92870780212674364, -0.52875150455509989, -0.42938812210079347, -0.74262421633375675, -0.523294357057282, -0.28273431752612299, 0.58797010754490464, -0.61323554772051625, 0.097414734540597153, 0.5780744757487708, -0.99532079537074902, 0.74665551609597325, -0.50220477959074161, 0.84998554436986107, 0.9209245605438422, 0.6410230981455125, 0.29614599074383141, -0.50520842370489139, 0.29076187576177737, -0.70589916778649076, 0.5752278894239321, -0.48103022832419595, -0.60391107384291931, -0.70958686930593173, 0.63686341999053242, 0.017733315960673179, -0.87775937282266359, -0.15625396430684105, -0.83795548261083308, 0.0058490796281801061, 0.19227399932464048, -0.26261463937094809, 0.44273979579603101, 0.010552055490701494, -0.39949135859053597, 0.9066964974640378, 0.51681982232550672, -0.62906385626032801, -0.14350715595635619, -0.12498272136251511, -0.22547343094761652, 1.0539898668524994, -0.54881693861530634, -0.10730619420811023, 0.76573656782495791, 0.82307832352663945, 0.81909687468274373, 0.78064860428483684, 1.3834397484432954, 0.27464617506436878, 0.37957432301204314, 0.82576205383560231, -1.0231773104382034, -0.89095425597839661, 0.86676900202734408, -0.31262471386494162, 0.098139743858707149, 0.8891785589394241, -0.52837621602148221, 0.0036576316353528256, 1.0125129059168871, 0.42056258750092768, -0.79754134386793252, 0.16584026569650034, -0.11169377000792372, -1.0780148996199701, -0.6004771607080579, 0.31521819339687557, 0.71323579133129256, -0.040530339233262075, 0.91953448951974881, 0.13895711781311121, -0.92573969552684499, 0.13517149144233728, -0.078030366543719892, -0.761669938615398, -0.70852704265518573, -0.58690712732284767, -0.59908881223893862, -0.34295314491334383, -0.19984296831660928, -0.19073298293194071, 0.76978235686492791, -0.18033374704191021, -0.87271834979886609, -0.71531713750288417, -0.79700708728887071, 0.87138025199134495, -1.0687621026083483, 0.33907450798058186, -0.47241630794189943, 0.69596517562755456, 0.095722264516635763, -0.6478609537777168, 0.14238988698049929, 0.49481786715446019, -0.091989133222377992, 0.44007471791410729, -0.86612372946240501, -0.15589028882421488, 0.96172258790892307, 0.41023795564419813, 0.13080372642325377, 0.8779967711260499, -0.99588559361860507, -0.19425365959454283, -0.19847271386048082, 0.07086216870435548, 0.17827759926070663, 0.0065191113009861875, -0.96869634800481563, 0.020504632639272262, -0.63810436916310553, -0.52225344079270597, -0.74136414118531491, 0.5338699817985858, -0.63080453616860099, -0.50097243432865224, 0.59404005238333135, 0.57775029559374125, -0.72772512797825684, 0.86031865893360804, -0.52177483847639894, 0.49101916726648909, 0.10747779949494171, 0.37764593501027516, 0.610519460946087, 0.82943906437636172, 0.75223040685504039, -0.28852458377558921, 0.2315674793396596, -0.94988934975936046, -0.86863212058202566, 0.53648599086023108, -0.75157310369778618, 0.99326559343053078, -0.039747293412570925, 0.53302303175014398, -0.42496112272074238, -0.18208136893764704, -0.17036053187898911, 0.74238774596959156, 0.55004309309956489, -0.34076834465918621, -0.038439866295262762, 0.12125073343421211, -0.66454600378411244, 0.46304361053955817, -0.20173030576464065, -0.79283698061082508, -0.24015880371525378, -0.90832879313770154, -0.84408732639822204, -0.5254834984727863, -0.91961764559818326, 0.47573999960140712, 0.14262848051510479, -0.18898262734609061, 0.051848732272678388, -0.095368222468168451, 0.89748403104655039]],
	    [0.98385721614610044, [-0.96773393329882551, 0.54842823203954238, 0.097912636860359892, 0.73523212979585184, 0.20431630454854979, 0.52901591563408168, -0.49870111862363542, 0.90521249783231217, 0.95152956847692194, -0.83987979341828367, -1.0269163294762715, 0.6746798855148437, 0.51533216657241399, -0.58266549292482384, -0.25920484845765879, -0.68798715988430792, -0.88177297818024059, -0.32936412053528491, -0.45788020033061044, 0.59843918804994545, 0.78633128149615572, -0.89179149089565868, -0.058731206229087542, 0.28067683141935518, 0.21306754323548044, -0.3557091092932485, 0.30498561575561745, 0.53831715729766072, -0.66302259429755439, -0.82958801671536175, 0.93212504331453039, 0.099851033755123983, 0.63405809386889866, 0.33987052458011241, 0.17265826198046902, -1.0691248834545433, 0.12049074161643093, -0.393183437385139, -0.58362076629383475, 0.32408618479197732, -0.46097606812692804, 0.24111957237245932, 0.085364837603952012, 0.084363083435861921, 0.27848007697016119, 0.21433597227468659, 0.18203434224119455, 0.71177817212596151, -0.81803796007253315, -0.23612225339261783, -0.016915218476617616, -0.35302068172922546, 0.39329917212695886, 0.25282655519829916, 0.22537188387313598, -0.35555806143718222, 0.63180276783788725, -0.072506035944992969, 0.34103021904626701, 0.21894401382591289, 0.18561025826155844, 1.0703097646847792, 0.14700986728183454, -0.98058841771019201, -0.56564844447394413, 0.80119111192060932, 0.96088780331471768, 0.19064968475337138, 0.66687648742929095, 0.87005274266089339, 0.51105743396975822, -0.39198106542290256, 1.0202501984715415, 0.82511695054673195, 0.0041670983128891947, -0.21778843442896653, 1.027191844170585, 0.12634954306494792, -0.19487360266726556, 0.43242853062273356, 0.13420657273761072, 0.49054454595918179, -0.36251883401839691, 0.97294335814289001, -0.34776160974653469, 0.25926473639344089, 0.61945002520526726, 0.85167640072195727, -0.35301969913229314, 0.1498586566480351, -0.36106638861857387, 0.34747787911072814, 0.87761932181599012, -0.44554086574243867, 0.038151418361705956, -0.77034523991752379, 0.28587286749130664, 0.70074046139451884, 0.20227473846524108, 0.37867646683737544, 0.55839809784616623, 0.73518966561630184, 0.60616455768347666, 0.50924690320676447, -0.40282549767352682, 0.91947442543649993, 0.19781588248476714, 0.91195393130951818, -0.60542532389585479, -0.5316197887141767, 0.42199377469507837, 0.71991613366417029, -0.05577175284325521, 0.2351826987719674, -0.52601081982075515, 0.68878789386087824, -0.59959011491554415, 0.34407289071857455, 0.86652368317866535, 0.49135109873233151, -0.66281329670962585, -0.04811829362337524, 0.28137554942814275, -0.79847844909537768, 0.98094042996417319, 0.25145435257449844, 0.22656493243231288, -0.89613848665393347, 0.11061923039746033, -0.22971126487249457, -0.68035888848532611, -0.74923439625133681, -0.33878029348446936, 0.29528327322798986, 0.71476462076967684, 0.60706641402877615, 0.14368617648531701, 0.67052393133170463, -0.73990314414124803, 0.87861333218086313, 0.51408545767787339, 0.046308766705425927, -0.7956343443454531, -0.46541157831880714, -0.56386693354034023, 0.077438555334764042, 0.97126454483611246, 0.63371212935653665, 0.36114451056154173, 0.5233354544727864, 0.7649197182330717, -0.61175097150621416, 0.69322571874814398, -0.096470079450359528, -0.8520130208924388, -0.84356337977355511, 0.4970687640642219, 0.11744022161915375, 0.39180811449485581, -0.91355221523896968, 0.54135917119527921, -0.95980362483854065, -0.56322406998845809, -0.36342714536390219, -0.98386218320569752]],
	    [-0.35730638968791356, [0.51601197934080156, -0.24185354425328667, 0.18482187035089151, 0.69842524086196101, 0.9558182609707504, 0.70303323275658081, 0.47666225765136089, 0.23452017813737402, 0.16664099498678162, -0.39534900472763068, -0.42314195522763132, -0.26975953928759477, -0.37029822278285002, 0.4579054212783773, 0.14416257382243858, 0.40569021085716234, -0.11106603530419232, -0.029243924703843863, -0.73749753176748223, -0.298526103520796, 0.041393770358636041, -0.67417581826365292, 0.32278149566306141, -0.5526209147215867, -0.96975295178312504, 0.71994470743286443, -0.51791342364678739, -0.38363800790878921, 0.32904220074495172, -0.63005867769727075, -0.026184051473950618, 1.1041190240037346, -0.3231466019767763, 0.2206519737448577, 0.057364313564637712, -0.95678110066225575, -0.50082800813851536, -0.78055003627294517, 1.0588097470709124, -0.31933190057378164, 0.70822700927770099, -0.42771992247600549, -0.31683998178197098, -0.71504975930981129, 0.017200362118347412, 0.40673648363397041, -0.50499308070538851, 0.41292055228549318, -0.88113932323775124, 0.78443312598844683, 0.28019031892247609, -0.79443068992100752, -0.71963210819049872, 0.18606355429984919, 0.7926374182845991, -0.1370227884343399, -0.28285215511724127, -0.80766933705539867, 0.16256702666223005, -0.38820271472112, 0.76258208213601109, 1.3792322912992718, 0.5124341246128703, 0.036666717683732898, 0.75756511155909889, 0.70881552196950071, 0.24919233655358536, 0.41313985896857436, -0.052135383899740553, 0.74694623171986074, 0.67914249763498846, 0.079713872610487763, -0.016334895145523932, 0.19176211654564276, -0.023405426623066772, -0.89632045175246899, 0.32689027678647065, 0.93466282026239422, -0.44472684016777575, 0.064076114905544587, -0.39971934159496175, -0.096735131331988244, -0.17113716382345145, 0.5811964363246771, -0.69521636255663199, 0.18186780952852594, 0.27316981815417246, 0.56814053037864698, 0.27607328250906726, 0.44804985335219483, -0.1030051409142369, -0.10533090689529839, 0.12123266105644916, 0.21433354250326661, -0.34151910156338539, -0.50255903466065188, -0.20414731098216163, 0.58282612799354372, 0.096059989431796333, -1.0836928808623294, -0.81208831283869121, -1.0693758232190338, -0.54667454592992759, 0.7956291288922932, 0.097815051071607845, 0.48708177536598002, 0.17436555459686426, -0.17202390643930329, -0.88560215958581023, 0.27308800455342647, 0.90409748867502704, 0.91727964219507629, -0.20862986465568922, 0.31817645993231713, 0.62473547910938598, -0.94959395031795413, -0.01497050182809447, -0.86465219746837307, 0.45458590233093327, -0.34835938640590292, -0.52982211408455593, -0.3903283105768276, -0.23237400498097863, 0.86611890783026269, -0.15375386982263886, -0.51474633618484733, -0.34232426291234624, 0.081114804870976984, -0.40584077341987357, 0.20135802515595669, 0.89786020082769968, 1.0099519837084414, -0.55420693975725233, 0.54700761384384833, -0.18329514786991072, -0.71744972373179938, 0.71365425309158681, 1.0959847045237296, 1.0783055767829441, -0.15103990038773524, 0.91907820127457773, -0.59063914407069185, 0.046658138867525643, -0.27614914690513032, 0.46375077001547643, 0.11701692218087022, -0.15481272523664011, -0.8778100186340283, 0.93468380031850429, -0.2021407356423417, -0.78865435149090202, 1.0132424220523024, -0.017766490616238625, 1.0079739836128105, 0.92134016987147793, -0.63220544955983804, -0.27386660824436793, -0.13447471487468377, -0.70337637131250519, 0.034968232985558734, -0.30546985043902564, 0.71626811780477828, 0.69760489548215787, -0.71904419284507126, -0.035822955930844058]],
	    [0.22308465871118907, [0.60981373029744901, -0.59946663585694859, 0.68377950556279354, -0.19185289440576722, 0.95265057675594766, -0.62563637387538951, 0.18842856248401485, 0.42521621266444631, -0.94582221622881413, 0.19947665838636577, -0.74154543572343024, 0.72099914534229337, -0.96282576460817471, 0.15155465335200025, 0.61259785594989635, -0.73931352637448655, 0.67004694877384119, 0.38713451143749927, 0.35508315461442336, 0.89666177576649886, 0.26323231225492588, -0.58455738519628098, 0.47891042814821189, -0.88856415306462788, -0.53582329143461949, -0.55159563363355368, 0.8963899874450485, 0.96326307679387113, -0.56112291178647933, -0.10215345604962334, 0.48226022895407344, 0.91892734297923329, 0.1260403307715465, 0.090109548700991457, 0.38786781241740381, -0.50596868580606702, -0.88104620628529795, -0.73343798706590768, -0.68116542449277129, -0.83536272157233038, -0.77089003525859012, 0.89290533735149791, 0.6515217603131509, 0.62132434717648111, -0.4400651204463355, -0.46632439374301576, 0.33601660918366999, 0.66606009700501789, -0.28750807292890679, 0.44217945100080963, 0.013140065096094273, -0.26213855220926707, 0.15444139409949609, 0.75452237987179449, 0.45355836642993463, -0.42240150287019901, 0.50052188588965474, 0.62028779449224014, 0.55725572530731626, 0.18219538049046013, -0.37758410518996255, -0.45121792943176542, -0.43884956132936553, 0.85945435881884269, 0.4731580568266785, 0.46674177418474144, -0.1912748754869173, 0.22088478793834909, -1.0778067777867428, -0.31602592362965154, -0.79109110247154812, 0.063485908595843299, -0.45987973761402168, -0.64204667761078316, -0.57883322019236383, -0.64815139678143152, -0.0081776462872812164, -0.83384341410413843, 0.18173954354952152, 0.36599157276382382, -0.43956752196697924, 0.3673279733441156, 1.1077438103006656, -0.61405552729705648, 0.87381721565825021, -0.63071719746618515, 0.039454125987451016, -0.67265286290306014, 0.45594360989196914, 0.0049453118442308597, 0.3305978194754513, 1.0660766208961929, 0.86938325503702707, -0.009388517147024664, 0.42590815905209006, 0.5342105573443614, 0.63969155000875688, -0.038642918429065198, 0.50309169249119212, -0.3983401940358775, -0.63747562961405413, 1.0376963061034779, -0.70005590099143944, 0.84349660258770975, -0.87364766603770982, 0.73024853947322432, -0.48633032860319558, -0.64028682310614859, -0.89122253753478242, 0.79330755827525112, -0.77482103059411123, 0.70081468624971199, 0.77495666022413445, -0.028756399451352485, -0.57430060987727816, 0.56284297925624993, -1.1665832038868493, -0.33189698670050705, 0.10869827202182455, -0.71633639086341183, -0.17909497566494717, -0.94654851924610961, 0.72816335640727836, 0.69477086709835456, -0.39451131731098527, 0.46939542671337414, 0.2307887873977085, 0.39956499255836253, 0.15230977014955357, -0.83523007698860308, -0.24081204643597501, -0.75137459406752494, 0.79069483995057954, 0.40929747973499853, -0.1628711117921007, -0.54244848369200749, -0.072429561657418998, -0.4876326568013607, -0.21977650936724083, -1.0458955665086176, -1.0880402392125816, -1.0448400245884244, -0.03593713735462023, 0.051085947978147313, -0.17359863155760397, -0.75244835959388734, 0.82148231677723293, -0.40008015090945875, 0.096430626548456924, 0.6420202715733565, -0.46850887363152138, -0.76978476577870436, -0.43083022850559727, 0.13781207549548591, -0.25471592361885464, 0.22102106527331675, 0.9341210162254302, -0.94662460977226137, -0.96527720782599336, 0.30283085764633011, -0.26927756426175065, -0.50684299448447989, -0.33323010796488228, -0.16299052994397512, 0.28274633379839287]],
	    [-0.24700842873854872, [0.023416117681337924, 1.1230168859514362, 0.31354743308085076, -0.72162127918915664, 0.85504531003423578, 0.38388828209373127, 0.49390771926407939, 0.47690119170167883, -0.75463780625284194, 0.52935374852232364, -0.63509684013622147, 0.75273765818364546, 0.57864268022946985, 0.84436474627956981, -0.17957357564349596, 0.27535732825481224, -0.51045285536976803, -0.79434757136668976, -0.29979187484872127, -0.27960735845162904, 0.052807886459787214, -0.33739361057776218, -0.48907013010076805, 0.8000102706301121, 0.61086424409800366, -0.90087800493066961, -0.66553204961526102, 0.57239362735837873, 0.33048921353670724, 0.27727484185387063, -0.67520829717114561, -0.20124962167150356, -0.18580430561186353, -0.62495263092030029, -0.26165062368735531, -0.34365442186506179, 0.94993535753007829, 0.61971835531583508, 0.81077801883047684, -0.066403798209978923, 0.38378989350664289, 0.43130114974686429, 1.2209339775255186, -0.83602909050091079, 0.56419836382259758, -0.84868979384957288, 0.67584818924146428, -0.48908750248889632, -0.77923695665070014, -1.0127278969369333, -0.55260493064113292, 0.19495813913410381, 0.29049998044282105, -0.39436471684186147, -0.62551763248375247, 0.60776911181928339, -0.21080084477757979, -0.40684700416806857, -0.08995373471634846, 0.033757973581001854, 0.12775134930488682, -0.65461737363066141, -1.0560230833348929, 0.79642609596303715, -0.34888217274186972, 0.87424154553517708, 1.0723756544389731, 0.1323618174288497, 0.68519145650333546, 0.38635581370856398, 0.50830492590784804, -0.61124210648872646, -0.41357601988277015, 0.25270501102382975, -0.92310882435913677, -0.24816304489153621, 0.3638219349316193, -0.59400279620359675, 0.4173554061310335, -0.0068592800450505021, -0.037872605667447573, 0.16994303551851536, -0.59167634985190187, -0.95643520062998832, -1.2908586251577896, 0.25504335135989931, -0.083617768093483522, -1.1624545484521847, -0.14161598815727841, 0.56628287419317136, 0.26212726116038187, -0.29928301874199131, 0.45516163851065899, 0.29898455635614296, -0.53978825669845376, -0.71270264788674365, 0.63997789014636375, -0.42526064299721389, -0.51366517157101077, 0.76281855277635147, -0.47478630809584588, -0.72129953242140843, 0.18250572451507763, -0.87592060674988781, 0.86971418403966805, -0.7416445715363621, -0.21200334554174807, 0.77932917969414239, -0.55445999435932714, -0.54204909429276038, -0.085040847769019171, -0.52104363967121248, -0.19636940532000155, -0.066605064578340395, 0.34043126081177683, 0.26917608064695353, 0.84312796299127879, -0.78880332461286906, 0.69365529350487554, 0.17020092446152929, 0.81000387694540554, 0.93614636873717916, 0.95170469057679696, 0.23954627743390708, -0.83459707725952714, -0.6361395734026023, -0.64357120030188175, -0.56743140681550464, 1.0002593273814802, -0.18663290470690924, 0.61348496693894528, 0.91752090456599855, 0.64698793062714144, -0.77499051996092871, -0.0062581367657914225, -0.78954897856781858, 0.23962461134126098, 0.80140627875647608, -0.59166993073609431, 1.0069171080322923, 0.3040868229491463, 0.89886641275774404, -0.5415417414151662, -0.93634477432174934, -0.56619502990443449, -0.34260865903044646, 0.28658281190693025, -0.5472050003514114, -0.17219674178692268, -0.082335495160412941, -0.02850111138092486, -0.28021681529859477, -0.19761486247646487, 0.07732471862438349, 0.64999360926373928, 0.087092243107674286, 0.52888659077855504, 0.2052874712804148, -0.97361857132239937, -0.38801400948783393, 0.77629568478870059, -0.35746134534199392, 0.26963489834139476, 0.52024070770067343, 0.54043651138294546]],
	    [0.19058769843963416, [0.11173144783826629, -0.38326595937237756, -0.50699833048526932, 0.11113074386627106, 0.42259818644266728, 0.93539698195763776, 0.84728459045453197, -0.079548386722834277, 0.92209639435278112, 0.4283843927054406, -0.041959410104384968, 0.35209113122060398, -0.14437481949751038, -0.46002836142183678, 0.50223282871676167, -0.90610322704942614, -1.0166383063684086, -0.37493706258663656, 0.84315261414481468, -0.42524194307517532, 0.40298144289093074, -0.66357669441262235, 0.21042495321437021, -0.072057127592479342, 0.35426094580643824, -0.048771075011970359, -0.94633937328252937, 0.3950109505126323, -0.057114353792191909, -0.68367546025440262, -0.85056121996751932, 0.14330308517744075, 0.82613928973966233, 0.95100160152565894, 0.59511405789542737, -0.1458033154541313, 0.36412867925111958, -0.72433109679257845, -0.11750654530770728, -0.20776089196896785, -0.080676285447342982, 0.17454762338438598, -0.83158827137077795, -0.98806403086224903, -0.27323793441243338, 0.3553035159282783, -0.34952775841546724, 0.27221962503295011, 0.28306697072941739, 0.53289205219670144, -0.52928337263640601, 0.73731432687277887, -0.53378853397589265, -0.8472009391421238, -0.11463304112941686, 0.66468313030492443, -0.6403009064651628, -1.1940229639528841, -0.22122538935372665, 0.02109143062830765, -0.029463192368863307, 1.2391815448898329, -0.16257356196238706, -0.78509307344857027, 0.20350315280164408, 0.31186668596779488, -0.09294546383641844, 0.12438408166954128, -0.89338339044715298, 0.15973066411238385, 0.78883380816106852, 0.036878853777472326, -0.077531387752174816, -0.74140472874049812, 0.15065412165058412, -0.48439046339071362, -0.36655484003693584, 0.48272437103193916, 0.26233287299408126, -1.1457175355156826, 0.45185400482481719, 0.18065927155386022, -0.67760259657331778, -0.5978868079869627, -0.23787368638298445, 0.62735872719661234, 0.38487144464172185, 0.11682523929216047, 0.76946828682452795, 0.78422955333420807, -0.50585439009967503, 0.092133298662847377, -0.26309446407939119, 0.29637450444105778, 0.46517836244845029, 0.70189872596952763, 0.27827289336060418, 0.12951298886420146, -1.0994699668169106, -0.25068265969734793, -0.93045071858570949, 0.44290927250493933, 1.2267319661369158, 0.54747411902304755, -0.70825033253910352, 0.19945363406516151, 0.93519191488275666, -0.76436010298268608, 0.78913511831371241, 0.50514908884915177, -0.28732868039543391, -0.1004858784327618, -0.32922369694164616, -0.21868709144714937, -0.15038901723383019, -0.20777250004849318, -0.24336163298607308, -0.41205225263583323, -0.78568229392386169, 0.31175406991452104, -0.81278004253601177, -0.88354446465728909, -0.89371098672010829, -0.28977497747280734, -0.23751515799968972, -0.51424149569105493, 0.55686213440588894, 0.92258859787736869, -0.7492559691550652, 0.71607279836894289, 0.94755717908857773, 0.47748300572258234, -0.37247866978448396, 0.24224147925158843, 0.31444675165807151, 0.39610688171025721, -0.86517661534762735, -0.70429203819300967, 0.35973246138188181, -0.79937243908393518, 0.35131344097760803, -0.34227608209732074, 0.93523518918686055, 0.021711923335271003, 0.11224144956859493, -0.94364960700220846, 0.42248745989710218, -0.87359896135290216, 0.59673118714613538, -0.62977456811992649, 0.19885466765354948, -0.68253590080899607, 0.79984306665414684, -0.21556580863473354, -0.9035765635035109, -0.49404345804843319, 0.052313290653721575, 0.60457736763494596, -0.90859434804995121, -0.26166293637629656, 0.90350807980403336, 0.41948132159542206, -0.47383210339605264, -0.28667033166706823, 0.085403004194163135]],
	    [-1.0543601650292742, [-0.095309054649497696, -0.95167577924199698, -0.685098477281741, 0.34800361860527057, -0.57332865779269038, -0.93120557586682395, 1.0565524001804329, -0.36485853408390601, -0.40972665026859895, 0.83388132755914168, -0.23024166609834465, 0.85258542788017555, -0.58063105656351788, 0.35968289024167444, 0.64157495665045694, -0.26443980847955817, -0.38454046740594416, 0.32055825076367167, 0.026016222344667904, -1.0489430442951027, -0.81008399925877617, -0.80034049135668772, 0.069137593095879149, 0.16433060063294963, 0.31818763267457395, 1.0194643936052601, 1.0950675344530529, 0.54806303799976908, -0.12993530430535502, -0.36557088230460444, 0.46116154761482941, -0.73331432848459566, -0.95466634311723764, -0.2536131235033911, -0.66991737311987498, -0.85685311214254145, 1.1013685284524426, 0.21677830079988986, -0.71248292009709746, 0.52345359561147853, -0.35362035957934629, -0.59212608909271225, -0.82357353184147564, 0.27299694410869707, 0.30789476262222304, 0.97929387258784995, -0.079992280423214837, -0.00050408923330827428, -0.32190210926998836, -0.48805859652416739, -0.19312595305958027, 0.40003195322360308, -0.19064231490180372, 0.57616177272911651, -0.54897038468526038, 0.10302762041573385, -0.1015587777382279, -0.10838187591714342, 0.9832651314843055, 0.27883685811090886, -0.64103208339726303, 0.066915029078927185, 0.33227158883359642, 1.1713071473673153, 0.021133810375014085, 0.55959371039700545, -0.21769777172772781, -0.052825241224962134, 0.30880093373536294, 0.27183396539212845, 0.17755898430364789, -0.22593747844890857, 0.0059121756193034137, 0.42772670983127636, -0.55465061754808165, 0.39821285495246461, -0.69064157484951061, 0.95867051105989787, -0.70930821328899518, 0.01383287988501258, -0.26823502234679741, 0.22744165678934652, 0.58126176742116487, 0.947732659142418, -0.23392935091963082, 0.9410249640557542, -0.40126243453720484, 0.43832816154320431, 0.46763536125823035, -0.4025946606145332, -0.99575731243128418, -0.21058780596508078, 0.83116832392226614, 0.40085109078325321, -0.044709903146073773, 0.9520424170927505, -0.59227485188107809, 0.16305572155156473, 1.033900013276116, -0.54024179369029879, 0.0078025305691227682, -0.65478646682368047, -0.53747124817010317, -0.66752442969773818, 0.44259143871847634, -0.85201345896216596, -0.20576222162444702, 0.1711923238371961, 0.44841216648204074, -0.29407266292935041, 0.016943270054767423, -0.9127808482421248, 0.7297877587087428, 0.69227235591959246, -0.12492578065697632, 0.16535005164698099, -0.75163958762917782, -0.76994703296402522, 0.83040711012232549, -0.45611273414927617, 0.18591178973870334, -0.53350183044260724, -0.60795698758595118, -0.54874896743559776, 0.36775321717360776, -0.67672888262747555, 0.69277098549077798, -0.12022795491580157, 0.93226381721025675, 0.02426105389877814, -0.52238403526417532, -0.022345374802900008, 0.84024894652584048, -0.22494828786359164, 0.70702945716878096, 0.21669590192529004, -0.86104334552355644, 0.10449414837026305, 0.7470781084620175, 0.39784922501337538, -0.80238831027143442, 0.69176914809774426, -0.39033043924529737, 0.31094804062596021, -0.24458541714995788, 0.017688087188975188, -0.31416822612970774, -0.16461842340952121, 0.19225671153417095, -0.34629032610715926, 0.79653393612441459, 0.21368631599315993, -0.23482807195282013, -0.77021755973861772, 0.45200545865646363, 0.034467080871470948, -0.85579804601197773, -0.029825415704576492, -0.22600765155573269, -0.12529057386564113, -0.52789428897009372, 0.49275170739579388, -0.5901021679137215, 0.21681140096238805, -0.63952893468712091]],
	    [-0.23888834140369744, [0.80286224828133668, 0.42264256746848006, 0.71988576271757054, -1.0487224833871791, -0.77443847670158228, -0.16948224980006751, -0.32040950228621562, 0.35665588197795883, -0.29690887898428897, 0.34299269574464131, -1.0393980569567789, -0.22924196278051098, 0.78404390948872837, -0.39729835390438284, 0.4701059975999331, -0.37629521808222527, 0.86159047310870307, 0.74141465559665565, 0.0023314903873680303, -0.48993002471763725, -0.30956818956933196, 0.27234853619934857, 0.0090033154427911627, 0.27281141820641891, 0.39711994653102645, -0.71991137196538257, 0.24430210743935657, 0.85872153675971286, 0.82759929385612607, -0.3050014460786683, 0.86414952941632339, 0.30475103728429886, -0.80679050442769762, 0.58891490588430617, 0.47023119533398416, -1.0787243688902313, -0.16776973465998171, -0.6330764549856962, 0.89665334966892929, 0.044727896900163225, -0.85514788209496473, 0.41569192567235558, 0.15542526545940774, -0.61435078931532328, 0.481096037728588, -0.78412339104068263, -1.3386487372597879, 0.87282122315584165, 0.64002928701138895, -0.44201658018336543, 0.64459250433137716, 0.4802706080130042, 0.041106822575832931, 0.96152937191957422, -0.75417285833305547, -0.77075396573293686, -0.10532989400714765, -0.056755801945478343, 0.891547057000456, -0.16806167666727245, 0.51488441635097859, -0.31502193695192232, -0.13546182631236039, 0.42115015988970117, 0.31032394247622386, -0.017603810965340951, 0.32515129926792713, -0.1357555191491662, -1.0172491180138437, -0.90692768366152432, 0.25328730015788414, -0.33432922987623226, 0.67844777787010924, -0.38553552845511629, -0.97675131857804565, 0.84858639249043422, -0.59319008466124967, 0.60025389467167589, -0.66060164690243084, 0.33432272480341796, -0.64870693381583844, 0.21613622830162993, -0.92375549422070924, 0.29774498655651349, 0.15707227383332376, -0.93611986543811621, 0.6401370601475459, 0.013045519320810791, -0.98433811556818485, -0.84038979534649472, 0.48532410407503207, 0.66299227411607387, -0.65737476287031948, 0.46557711639846694, 0.40218650640316328, -0.2189945491021599, -0.87801184412801081, 0.21536561967116052, -0.15336192135099913, -0.074893325373016711, -1.0926208634688617, 0.60429054163692542, 0.61256516427683083, 0.61758530627624098, 0.75836195507330528, 0.45746744351853197, 0.12611252071704765, -0.10387161622252174, -0.41702678896271544, -0.026060086941456576, 0.58428925832510159, 0.095496201975627373, -0.73219707286968794, -0.77159151083490796, 0.60006562059768842, 0.25050326493510772, 0.32777767575643341, 0.024650985676404048, -0.0084221691922289846, 0.88760292251137141, 0.85956365151537151, -0.74390093435558391, 0.91814130230483504, 0.28529063404533139, -0.28607555286641267, -0.31801042217504522, -0.60924986484201793, -0.47136206838328565, 0.96774048653321187, 0.67581899397488843, -0.095011272377476683, 0.7053257199945755, 0.63313699061876716, 0.0080720135969356999, 0.42412132621781362, -0.23223405500496341, 0.66436854320252148, 0.54858138067020845, 0.33783805445955978, -0.86803134897891743, 0.8886324257373186, -0.61949727937866028, -0.64356901416858625, -0.71219329206165305, -0.12742082624737863, 0.20027456884741746, -0.25443594752869997, -0.017733271016013293, -0.69119651652001779, -0.9494545732739208, -0.92417045655276608, 0.89819590017377526, 1.0320696096999058, 0.6187382855571516, 0.53853718189883304, -0.56628596735037307, -0.52109579961107677, -0.47526905917303947, 0.42157325674607071, -0.74384863822560421, -0.36844910054363811, 0.16740509376571389, -0.71408140596043124, -0.053078468285649327, -0.19069744306969039]],
	    [0.84423845886167992, [0.48857262424093989, -0.028066212996992718, 1.0356641376130555, -0.78359743601533127, -0.71546086026576527, -0.1834579662731233, 0.08782613927049919, -0.46537313596015584, -0.03944419435582977, -0.94697532726949274, -0.81203614398190771, -0.11168789628082926, 0.36972729118678199, 0.88763109069932811, -0.21807129576711537, -0.64778249720380932, 0.10623622669884487, -0.43739388471318624, 0.25288955301643473, 0.72138333715583458, 0.22906964396128726, -0.28817600186062203, -1.1755735700705034, -0.5219124961639402, 0.42933044735152232, -0.88573210432496707, 0.44425383028357296, -0.57706100617759082, 0.40845648772620535, -0.93199668100050936, 0.33842727590106397, 0.5216685169198243, 0.83104510483113458, -0.52063265997474717, 0.65510083343167314, 0.28705172349033087, 0.68118132783431884, 0.64095346789445096, -0.42727681566053793, -0.3763417873815858, -0.73009220763808791, 0.27794618625927942, 0.079577066981716446, -0.87925956023526619, 0.022764994814900241, -0.34224280765201093, 0.68217375839612315, -0.10888103324487361, 0.39096487855408829, 0.96495172000763474, -0.55669861412429844, -0.2564784267127912, 0.57289436509618819, 1.1000159470784325, -0.6795893044929977, -0.52600218674422583, 0.12519953811515705, 0.83583878674457635, -0.86398418544937583, 0.19604368164377894, -0.23195912806417385, -0.045472597519329985, 1.0701450928707665, 0.26154042997676941, -0.84949968710760493, 0.041809321253265697, -0.14296451863285453, -1.0171993741038228, 0.49150656103271689, 0.6272373531544766, 0.18737291579211018, -0.059803516719373541, 0.4337063530541142, -0.041343805170404015, -0.71351061980790798, 0.83017709752708924, 0.23010002197380028, -0.71919446602147941, -0.52571297751544965, 0.19574691146112244, -0.70097767768207642, -0.77667137223706229, -0.1191686784394273, -0.4215996662920139, 0.84940811929122606, 0.065616510020338262, 0.53541782526780468, 0.12833170981877595, 0.2104434052681701, -0.43090749425000263, 0.58499423861438093, 1.0328695403042252, -0.85072002756389919, 0.18191206393366563, 0.9235773718621596, 0.88107509818504537, -0.6971077860207181, 0.83538033938781753, 0.83839026682882001, 0.86874766522246594, 0.47906062967828283, 1.0179851502040862, 0.58371674014344888, -0.80398628675816297, -0.81789300051150393, -0.55407324125671953, -0.53317565902749309, -0.572535157026413, 0.67694128608762993, -0.62749939476999428, -0.63629056830303432, -0.41523031076412159, -1.0679956347876762, 0.50748333256800082, 0.45095695679949882, -0.82394753252987185, 0.25304895807663846, 0.55985901516132297, -0.30326483639961138, -0.5282881844971159, 0.40143556994937751, -0.78445150449871459, 0.45441470374050424, 0.53150945364658797, -0.65338974455500887, 0.55607742946923489, 0.69675086805350039, -0.72741022414631251, 0.13518009699484201, 0.031513022558686862, -0.32439245805672423, -0.63544573970019402, -0.52259215169781015, -0.52586201204884087, -0.067593503738628907, -0.60194014832775711, -0.57811904115675217, 0.28117394869118212, -0.74838590061012722, -0.57398987264095125, 0.32437186917956562, 0.17333714401824252, -1.0752724102512954, -0.95335091754539592, -0.49286579044736106, -0.54745052317054643, 0.54808861026315148, 0.12508663721133606, -1.0329704758254461, -0.013384590758332093, 0.6091263975565443, -0.29053721706494745, 0.2087420023749183, 0.61083951351436316, -0.069826276725911296, 0.35122298272742336, -0.086985649040042065, 0.8077759176352558, 0.07930550670678127, -0.073243757716991542, 0.31092702220369195, 0.2670934814494188, 0.16827903663809218, -0.19430389570825723, 0.059143485175261912]],
	    [-0.62030101096405754, [-0.017085983541940651, -1.203728795412556, -0.8341360246970424, 0.86547095212254121, 0.11775949111665594, 0.74545619458639223, 0.71851591088366251, -0.39520658098043054, -0.064333291741835427, 0.54150529683823179, -0.95982879581859537, 0.60331325809296532, -0.77971645686157987, 0.20142022746742416, -0.60055474912191564, 0.036708664805432965, -0.23235566272659466, -0.39419413026075883, 0.30223026006289538, -1.5732792703157696, -0.15526954576519333, -0.96536541458282132, 0.47337249083773286, 0.8833002515512185, 0.43819932092883651, 0.36805860048186156, 1.1448698380290512, -0.17194640895948421, 0.62100645836004797, 0.87652267407550188, 0.74783668589358798, 0.16283335963755013, 0.03593971166492084, 0.60336510417193978, 0.4602703367116352, 0.0092917645888769534, 0.61376801569409745, -0.45806861454744369, -0.037929646756976132, 0.20238950825279844, -0.64114445352386418, 0.78008851787669098, 0.16995585151108231, 0.47624344760391285, 0.63656238699647472, 0.75302038934469062, 0.70787737028229281, 0.42305003503481425, -0.35951167354586594, 0.56028287387046483, -0.0020441170864924263, 0.084617562386609696, -1.013488073370959, -0.56970215350752973, -0.21166390444664931, -0.93437767059459709, -0.52711683734218651, -0.58629697859820518, -0.02301188780743682, 0.92810125419720912, -0.20138562832458579, -0.60029258349601178, 0.83966326811844283, -0.72877402244943301, -0.1232472278523415, 0.68571265538965753, 0.18350627021958243, -0.32942410961746083, -0.81568916792687463, -0.55532330714333022, -0.98735113334218916, -0.37010146754251466, 0.68816737026895891, 0.90701781636454304, 0.064683496412519359, 0.69774235358957803, -0.27603252246679055, 0.43461612304265107, 0.56185063464151674, -0.88174052926730406, 0.64514396901889737, 0.64679097818216691, 0.70651060658633513, -0.16646122093607529, -1.0794608193908843, 0.685069181990827, 1.1596506534385849, 0.77653375218911913, 0.99850310963556488, 0.86904284005304522, -0.24112809324948761, 0.24452448931050838, 0.33046692220067858, 0.66600909027543165, -0.12002887772241305, -0.97683602068443365, 0.1902974131852416, -0.73109947037108514, 0.31336884271483706, -0.42292820198541636, -0.92281489713344012, -1.0703089341916174, -0.74139229389109407, 0.41746197837793031, -0.050996590277261139, 0.38814548260613491, -0.17562735760258144, 0.6173283058442538, 0.34532013081131735, 1.0314035669716384, 0.10852836756577286, -0.6607854370521683, -0.55251057791410429, -0.66541572948857408, -0.20717767439834367, 0.28041870018046433, -0.76254293219743274, -0.58828278856408722, -0.43919208169222279, -0.23435521139266399, 0.97605103296788609, 0.13901044021529277, -0.27957520017758708, -0.70553081230249148, -0.27945268824666164, -0.14693247834097869, -0.76872591536118384, 0.39510546660254109, -0.9045692162252843, -0.44843446615410698, 0.93762832929174678, 0.93291290291341056, 0.1601959806031315, 0.42739803532341308, 0.66587377129696879, -0.98394515129042692, 1.015057201890641, -0.43493167747531203, -0.53256544702033415, -0.53573327150854388, 0.91725322363631645, 0.056219900674566808, -0.09628476801798512, -0.40670368182297645, 0.24947323630284773, 0.80152540467729627, 0.23135574383432814, 0.47397929354533597, -0.16601504897072561, -0.15301486591361546, 0.28514534508373712, 0.45832439106275574, -0.28362491918784433, -0.94462091101897538, -0.81083305498570923, 0.40293263170551469, 0.0088588863423462085, -0.41112054846040758, -0.62548397171108239, 0.72122347864818792, 0.53611254710527301, 0.95632103340641184, -0.24720047184569549, -0.33582909048242326, 0.18968721006672951]],
	    [0.99406657816846122, [-0.14156702140358723, 0.28213089667140168, -0.11511920465386516, -0.71723011916646207, 1.1584621247006484, -0.13521376711974042, -0.10148690501260735, 0.23433675016143743, -0.57489461225992255, 0.6680062728775702, 0.39937756813957842, -0.087279604183938875, -0.34278925196256255, 0.64739525114748808, 0.53490186275776308, -0.067659052059319866, 0.60773942222064459, 0.052435206094964257, -0.81056954314805785, 1.060021086284245, -0.3514358605799246, -0.98526731571454729, 0.6709746173058585, 0.95916862608817799, 1.1786637840017582, 1.3054593450637804, -0.31011510620210803, 0.027135289562502624, -0.84811196592504967, -0.67523461581345123, 0.088769498742212613, 0.52457295478130694, 1.0839732150235366, 0.61807582571003905, 0.84518986130172402, 0.72094133521417658, 0.21441673981675513, -0.48501152739877956, -0.65111986877848316, 0.77492777405457425, -0.46932111737862559, -0.16674966164334393, 0.78057044492814176, 0.86805620044680898, 0.39097031219067246, -0.95078475815149022, -0.31653543527634043, -0.63456823967233644, -0.37757995973990166, 0.82549900416163435, 0.41461248802403455, -0.55394944069474461, -0.47884095977183072, 0.88697103986007919, 0.7501925865813287, 0.11255258684072558, 0.86152006513304025, -0.73178233426890404, -0.66549698073104646, -0.15648414160907498, -0.1255708879614745, -0.37213143401302556, 0.077751687086270629, -0.92121004651996441, 0.13054668594556484, 0.8561885619084022, -0.54176452381556328, 0.25479984806128642, 0.119545156671493, -0.3425454302834266, -0.62082701595502865, -0.82066311100499711, -0.53645204346018405, 0.16631596358124223, -0.65610560363350112, 0.39172382938653433, -0.18433261137052781, 0.85885928475325701, 0.41849178002173126, -0.19949199571155471, 0.45821691164640094, -0.79879401994859178, -1.0560519179067533, -0.82897303541908329, 0.81481045507802141, 0.16210898223522355, 0.69294099635307371, -0.012552546601434973, 0.45379614176099231, 0.18083908763154422, 0.12844671124007548, -0.33885970319394593, -0.63533320664924631, -0.94041154933086746, -0.87955315564937464, -0.33164331251179974, 0.72757358181151532, 0.7630563860652666, -1.0866530732024886, -0.6090497387480639, -1.1072327120468459, 0.58326005791546198, -0.68806973682317107, 0.28163348535353649, 0.53392385077037652, -0.40875807008851045, -0.71068639283519774, 0.82550528368080967, 0.82102929386778312, -0.34774609296596365, -0.6457520019452323, 0.00088198261223012251, -0.96206543639150388, -0.90973164135252071, -1.1033136096290892, -0.10339734798783623, -0.011752677721590927, -0.4780625922120405, 0.27038217846490503, -0.5749737024844751, 0.61550424766880785, -0.89428960806349778, -0.11351028132309988, 0.62546258673563537, 0.5371509700949979, 0.22731357107139974, -0.075991840570710636, -0.66731465621548036, -0.22568570559318007, 0.67823686397393335, -0.31768117566339371, -0.45570084941732891, 0.06394962625569614, 0.19125021871096037, -1.0144522664407203, 0.29517845390309055, -0.23976365365382965, 0.5455174749406847, -0.72479077862130459, 0.3837434301789695, -0.79388051860227093, -0.55287783164984061, -0.1121685221497432, -0.18520394187504813, 0.87041147856521994, 0.66074415514905627, 0.76669642375864433, 0.65589488492695813, 0.80512002702270535, -0.71429732440108817, -0.67647976684970201, 0.087340041745510022, 0.036389934611921033, 0.89045412840288873, -1.0256252788317737, -0.15442390552191904, -0.29532393764188453, 0.86980213485057623, 0.72501071930482941, -0.98256857233626249, 0.71383845301798488, 0.48275960725679257, 0.21222915128107323, -0.25341036297648034, -0.90083670089411716]],
	    [0.79434373173787898, [-0.13688548773318965, 0.63629737638062367, -0.46517133306216629, 0.37435630737625697, -0.7246803176884995, 0.07053546612454635, 0.014146421091213373, -0.45195531388449667, -0.79547165059935232, 0.43118627121322567, 0.90966969673180342, 0.087369632716449971, 0.68508080382796943, 0.72601321663770491, -0.66250332566487846, 0.60873747174509163, 0.77264929878145583, 0.77826701842055712, 0.26279691238876102, 0.59426218713654877, 0.30518276984686016, 0.71671539566694109, -0.015734266437117315, -0.32478346291741883, 0.077829881654489716, 0.7278111079664733, 0.55071097546314929, 0.45911420266829989, 0.40871349401294271, -0.020720024556442507, 0.13554750866590576, 0.10788386637729806, -0.51401726147968629, -0.059234937403955017, 1.0557795018899463, 0.39470130912341234, -0.70860565776376061, 0.38191165648803049, -0.21355640571045881, -0.62283398011437341, -0.38227379363892611, 0.018055999263396311, -0.17821107440660966, -0.562431060839652, -0.16362205561502874, 0.016407934957251357, -0.9997499516252617, 1.0505229023309837, -0.2682612782103615, -0.87732155919387067, 0.13611289681883146, 0.084102882283832517, -0.78958052750249352, -0.63501697383297973, 0.45086512765191378, -0.20995773557887554, 0.35251323475095081, 0.90986592851211656, -0.20366696114358945, 0.74732342599501989, -0.51695158350031734, 0.25236284795645236, -0.7899460524769526, 0.7725613744436437, 0.78395431619371181, 0.87309310437786591, -1.0968346797437225, -0.11684762916292508, 0.23955161706566216, -0.22426418837546394, 0.18516868142192391, 0.57341346210166821, 1.0871758589218983, 0.81153472918819014, -0.64623112997278387, -0.61367830047307637, 0.11831884879113312, -0.18944550373496938, 0.21855376216787953, 0.79921195416192425, -0.68532646503986849, 0.61891603263092676, 0.46757135038291242, -0.16746944618507451, 0.32945244249292926, 0.1869317294500048, -0.30480614779303544, 0.089974171039018017, 0.080855471164506129, 0.026495538661922557, -0.79708347573938532, -0.020936724428122857, 0.70542181379261193, -0.81547546264221804, -0.28344498647364325, -0.079964385767615193, -0.44894042404340578, 0.7842305239263162, 0.50433276490196544, 0.26199251769134629, -0.63713272112853125, 0.7177166225211089, 0.76396961576654432, -0.71310154561264372, -0.20681533459630499, 0.21173046716341931, -0.11886943398762759, 1.0268877777509373, -0.11820054788414948, 0.28505068870812078, 0.94287964595677964, 0.40480848493333887, 0.28517734603850592, 0.49610971482222443, -0.8468058465275804, 0.1910210642846798, 0.40246840161970576, 0.65577275406533775, -0.18529396769477649, 0.029428806164255365, 0.098331818298649884, -0.78616513749398187, 0.88420927654601189, -0.6420784997941793, 0.74538400895681012, 0.19170426070902499, -0.095004195659392235, -0.39450946337488835, -0.43089139120573378, 0.68420754733651168, -0.72335619191168543, 0.86821304506799701, 0.52851231763704898, 0.61753661545985794, -0.58528200469495073, -0.54819684784281864, -0.6147050491849253, 0.72509843030358467, 0.2218082330945424, -0.69003612496218913, 0.10151622331157069, 0.28147986828427185, -0.67140178372695647, 1.0556969107999723, -0.7020095859940646, -0.54976674561255767, 0.71949812196121521, -0.82877783082271728, 0.98639003841739281, -0.72245643311257779, 0.16798201336289278, 0.91895032655580955, 0.85862168157328844, -0.22972424036874647, 0.21241028069051834, 0.23099923107204606, 0.43586192424961862, 0.51142816736467578, 0.80364223745361862, 0.95657701760124758, -0.46340860937920203, -0.9658934449719363, -0.87283330436419271, 0.37823920360218621, 0.53333062858099178]],
	    [-0.26828571512973071, [-0.45876204601650539, -1.1394936913047835, 0.25030308666906775, -0.67993524437161157, 0.44087472182025578, 0.18778224345156846, -0.50116031532611249, 0.24141604854965965, -0.049253155074211359, 0.84714595029071826, -0.78583922078575819, 0.73685584745518584, -0.13747586364891451, 0.61779018298628485, -0.62356142350730481, -0.69153456145333358, -0.83458035683714793, 0.58923824780633616, 0.3017103421554258, 0.27216162285279172, 0.80794720152931443, -0.96366931446490667, -0.66434164315618316, -0.30247422434699034, -0.19025373950163996, -0.36313575261629666, 0.31912266499472502, 0.065080510453468687, -0.72280240939689933, 0.42146015008395477, 0.092761864036710634, -0.41731133517903996, 0.60602608124799195, 0.76264224186329099, -0.1248817022549833, 0.83687294083346919, 0.35872298435659289, -0.29933260902713926, 0.53125238926034979, 0.1850332267958896, -0.30512499339452864, 0.50999786640231182, -0.66011372224173226, 0.96994749929539337, 0.57342759959274314, -0.76442859849484757, -0.5672370442137401, 0.96346383065746821, -0.84961331559216846, 0.37329092417929716, 0.13654684308370077, -0.89535390394822212, 1.0379453419359126, 0.89760057982397812, 0.5405336742089778, -0.44070810122279852, -0.073035590261542896, -0.15722219672061205, 0.78742341958679762, 0.64130430027314156, -0.53082651685177384, 0.008572715481167361, -0.13367277260136484, 0.60734772321824571, 0.75385636732608718, 0.69046197782450369, -0.387366276515204, -0.40315199784492106, -0.25135376335373677, -0.03178703477674677, 0.0085095517330783174, -0.41763590224364017, -0.07496175224677705, 0.50282110683258585, -0.2838232391401958, -0.8283497134811143, 0.46781866613411915, 0.36829443951050489, 0.80204886629463179, -0.62558848314708648, -0.50464622087487088, 1.0727089597609001, -0.82960835796879195, -0.084632632008232025, -1.0427231817176301, -1.0777029923097212, -0.034075906181738023, 0.90213386541831531, 0.36105578183590731, 0.010851912067370018, 0.60505410918404123, -0.58986234780727298, 0.28247909176391717, 0.74860688573044465, 0.12596080795331482, -0.044323911693932141, 0.31360700346616127, -0.5996667150043723, 1.1376419775248963, -0.071587857486806961, 0.52828992950585196, 0.80530944739560972, -0.078297704730782722, -0.74754789226177221, 0.48569486254920269, 0.42374278239834129, -0.23115064500106969, -0.40506149938822489, 0.090340357703569518, 0.48808353933076615, 0.44253106485023941, 0.42264248780438829, -0.51885758616241218, 0.12401903265162288, 0.5629353789464776, -0.25014772567202076, 0.85086701516810559, 0.85893104214362748, -0.17266883128988636, 0.99481992562440447, 0.37839728360297686, -0.56857163060377935, -0.47598108219562291, -0.033437801714590432, -0.88534900557782847, 0.68602461868321207, -0.96537356325008139, 0.82692445895902866, 0.89385748516663854, -0.085714137988287684, 0.79482734741964778, -0.56671469272287167, -0.024572746121361358, -0.20144517040572499, -0.85565640244459695, 0.19396186496534121, 0.55034679601545877, -0.25814360713191253, 0.87741608905978197, 0.25199608998680523, 0.44140316829518528, 0.78553654335073064, 0.27893050727501534, -0.63589678783143855, -0.59181865912300347, 0.95863239632371255, -0.41200666611784542, 0.36675683049231872, -0.27451205814648333, -0.41130656292245815, -0.2080383076267249, -0.94807969581858886, 0.78190596747344188, 1.0065213119893663, -0.75269140462632078, 0.6061936858416439, 0.52008325597198279, 0.13068112124127593, 0.76958271949001589, 0.0084995234703393319, 0.83184135732181685, -0.18343306847635343, 0.49016279302711818, -0.1496811919060741, 0.95896763426209919]],
	    [0.068903806707266174, [-0.86134452083473556, -0.16687579953598897, 0.49384028335368801, -0.16388097423608852, 0.61670552052943051, -0.33571961068883299, 0.55593151915494732, -0.26474560438424083, -0.88374234511955552, 0.47985061965145148, 0.18482286783723645, 0.56467318332887062, 0.88451688540668871, 0.14227015840247503, 0.76817195942400529, 0.1906628347642747, -0.23880853778999273, -0.34661501194293964, -0.034578252864419227, 0.33990623568099299, 0.21764912771361761, 0.16027227010368753, 0.58320677589957637, -1.0249623901019356, -1.0232565121048838, 0.85875842167120953, -0.25383971898868485, 0.10229176957149694, 0.053342437216085767, 0.049898247239910987, -0.44749828257487662, -0.059500358307592961, -0.41617718474794996, 0.59767076791289708, -0.054163937394174182, 0.5667124310247339, 0.18000110574621886, 0.53346179424767082, 0.20228223759407066, 0.95638481294791577, -0.26602976275844431, 0.37359580126772718, 0.40712889932253493, 0.79711266955832216, 0.54075924303396294, -0.12727021454303636, 0.17502835712170917, 0.75149033436330803, -0.21614040701208972, -0.50535192278814733, 0.33550862869581738, 0.084651407129558834, -0.11680995573735392, 0.22066993660156956, -0.130043305492269, 0.49557985600837845, 0.81921059577386146, 0.12516666905486226, -0.49429353357174988, -0.34447466576031216, 0.3232977991074884, 0.27307013368498007, -0.77433253532025703, -0.43030383054164423, -0.17512683626435674, -0.46690347239663371, -0.7072702247923901, -0.92897564499788843, -0.71417524001680466, 0.90534654841049866, 0.91367508407470421, -0.027074199758744744, -0.19331955619245186, 0.71022686850031014, 0.36598500594569749, 0.18732215814454337, 0.64345524017324685, -0.19879023893043965, -0.15517723461874883, -1.1657988029498059, -1.5057104538223607, -0.91661083954041622, 0.92393257050331334, 0.061812303382422558, 0.69607935442580848, 0.69784360612640828, -0.72354677051962035, -0.41452080291940996, -0.12523708722643984, -0.45214341121326918, 0.49197550434437143, -0.094508550470359776, -0.75939894669209407, 0.18288620518859044, 0.57146141477732237, 0.20736729097216824, 0.38874847511272687, 1.01611580930802, -0.21181277835728102, 0.23860215466148238, -0.041386537989610013, 0.65796182875858022, 0.35077291094102059, -0.59595091736115158, 0.16253136825867928, -0.4131422923026945, 0.37534556000223246, 0.18613710050949234, -0.30185589807882746, -0.11073883403444851, 0.47551857161600547, -0.68508054558848352, 0.83778667719152455, -0.19507155847158236, 0.056713540688030285, 0.70443557785427524, -0.9864468532296865, 0.1255224321219251, 0.60035116718639858, 0.60104567025292943, 0.95560389065678097, -0.41819993879855771, -0.72140566668965045, -0.53186110951744281, 0.033975988668429581, -0.59382516396723362, -0.26804060301800176, 0.81375933729518191, -0.87037140023821569, -0.73260090650573284, -0.92066309127176194, 0.55371776013255136, -0.33846300618197694, -0.76772258919964453, 0.90940004355909021, 0.96734105285483551, 0.27772461284734529, 0.98486184259800436, 0.40202997758076492, 0.1751014211570133, -0.80055114505119562, -0.99255118696746736, 0.74899920455207025, 0.044155741651331432, 0.67005694245080361, -0.27142609452753969, -0.3532760161841349, -0.29670197749643906, 0.34770039498172906, 0.514775580686752, 0.61147139604920775, -0.82503703751129431, -0.098749835535937552, -0.79046734000263574, 0.062286326675771241, 0.81338320023776511, -0.32683647918245678, -0.17018398760398584, 0.62611331149922311, 0.21294039167440126, -0.92498333307364522, 0.12911514146281777, -0.21665541636357122, 0.47619228062116181, -0.33148288540246718]],
	    [0.26579302193943083, [0.9020819009356138, 0.58802210664594179, -0.53214440369001337, -0.4493656717107109, -0.19357268916645337, -0.13047272921657113, 0.46688426431844615, -0.3636771574083042, 0.45765947993963413, -0.74101589604044471, 0.22724109396841607, -0.47666678736008017, 0.33045325231900807, -0.35961533214530839, -0.14920346338042201, 0.496169437894175, 0.96600529022140591, 0.87791315649110258, -0.076992418499941664, -0.53229796985953892, 0.087949950912031463, -0.33841767072777779, 0.29553195714888991, 0.2009936638089182, -0.85245801806615851, -0.55517187664137191, 0.010572750983229216, 0.91707096244372022, -0.041026555471340015, -0.77135011671910791, -0.056069786804116215, -0.28797783577315228, -0.17284715401265022, 0.50080556610290017, 0.51643626328337155, -0.20651520112584396, 0.61012439879533764, 1.3730246956948444, -0.0044991988427686017, 0.51536966369857695, 0.36787088771888282, -0.59797979756790232, -0.98132068803144623, -0.88837433487479478, 0.80001684557122044, 0.24509807537252115, -0.32966069863220754, 0.3246946077709793, 0.25719751696026621, 0.98229469506470546, -0.18329304301221572, -0.53912461361265263, 0.61592871118565806, 0.76641434890987692, -0.64069167061927923, 0.2460519707659152, 0.38344482286447229, -1.1131306792902227, -0.61559168253046093, -0.61391819612568521, -0.30716942791573065, 1.0556034866184851, -0.83934735611999456, -0.46302760388068948, -0.15954037318656303, 0.58465580601281686, -0.19247196288283269, 0.94982170663410315, 0.41450415603999557, -1.0392098756298065, -0.97794619545454009, -0.83328077852812865, -0.23241336603885948, -0.37216429316337457, -0.71647338421780904, 0.91297262098980037, 0.46450313561901035, -0.082697767823030441, 0.17641986705406029, 0.087721641478750945, -0.66122001175639089, 0.71934713411311235, -0.60783684926479953, -0.346097311960055, -0.49744661981029109, -0.57134443227080245, -0.84181500222085004, -1.0344967659225011, 0.025509335279914478, 0.051408118865587937, -0.83420553483194715, -0.1901112535181014, -0.29441039373913219, -0.62222232121852916, -1.0098248217449024, -1.0333596184097356, -0.32409685625518336, -0.49710671365981945, -1.0226089618532963, -0.81939115987698907, -0.3933333745506834, -0.84609220533849527, -0.13441012845398939, -0.43433942241521001, -0.57136294474608729, 0.54614623569033505, -0.35686660283454147, -0.014988940314525653, -0.15250798681156369, 0.11291505820977188, 0.72079439876189833, -0.19980669719026811, -0.35013710177054969, -0.95245653835923427, -0.53162140713537265, -1.0490118407718501, 0.47913972343400973, 0.69681241325199328, -0.5016364771252767, 0.80421421625321854, -0.70841163470385338, -0.12502521463689203, 0.1048212698637878, -0.98452655360448549, 0.74418570841628751, 0.98221922862921285, -0.94733207021693788, 0.39184751652426336, -0.30201193516992147, -0.27706869842399007, -0.096033327451364711, 0.64559986845393313, -1.0167901968955302, 0.056985279554420662, 0.71666580241614386, 0.2334447243834174, -0.05822118998477549, -0.90729052396358045, -0.17091395926265057, -0.55538502779347387, 0.31400837686365418, -0.98607985802875198, 0.64447599603125272, 0.42068764819672688, 0.7843000380927021, 0.30947209914145168, 0.72853009435030391, 0.66636481772450984, 0.4998351470293998, -0.94835133513375847, -0.81528740732660554, -0.058978678042693834, 0.79197593865374949, -0.61070486346488861, -0.18443068357158612, -0.70065602632349788, 0.49146117764749431, 0.56393655429115785, 0.69903376628303393, -0.033322464536142737, -0.098124690441653506, 0.96109085607789901, 0.60262939754569222, 0.89374425282923342, -0.50493433539679899]],
	    [0.68276544475802292, [-0.4379040553678144, -0.83905585104925384, -0.96273639428674007, 0.018686710336921042, 0.024467880352073292, -0.99164333276076899, -0.86011417888354591, -0.7747639697688562, -0.31019764556079371, 0.60155245691639614, 0.91516241925280895, -0.78833812508836898, 0.065363456597550509, 0.68410699096577976, 0.091570065205046625, -0.22051740378037729, 0.18775313856780682, -0.37994961013365774, -0.44985564950841744, 0.066563753389224434, 0.26672751718508997, -0.047829745156251754, -0.80514795103771919, -0.072445633558028799, 0.77022541238714681, -0.15321389725748233, -0.21884597154143487, 0.64998330770984813, -0.90323804822633347, 0.88454070170532217, 0.25239626964652589, 0.30737288663888024, 0.1981647508484419, 0.53482278159335772, 0.85891941609554046, -0.93374638242520958, -0.15689465987057541, -1.0005295038144277, -0.32789275514671745, -0.43857146076368753, 0.41002741835458278, -1.0188603932830478, -0.72400053752914428, -0.013455477793991762, -0.90281358674236367, 0.35831504470802278, 0.077782818272393334, -0.53130854797714877, -0.11929531624824115, -0.014663821732251043, -0.26055239200658931, -1.1276923758884723, -0.027970342114337753, 0.72723808993802186, 0.0032649907379702606, 0.92662032678057582, -0.23534413118102351, -0.89582551765728291, -0.95153280797770923, -0.1394749309470249, -0.050574557636589558, -0.99239367030431469, 0.75274226674689526, 0.56419673750759258, 0.18980992031931881, 0.49129131527130504, 0.60601573454063584, 0.20155872068849642, -0.24611844470740366, -0.81995795163646945, 0.060293165614011095, -0.52618227256807837, -0.50886705272322408, -0.0072686127984793918, -0.20902660639194126, -0.55622082949932816, -0.86478009692807889, 0.089380308174515588, 0.25026916896837137, 0.78192758535206563, 0.9042388754395132, -0.19566852203987722, 0.10884867279670667, 0.18549474264388879, 0.40048781514201071, 0.24180128318374219, 0.010932799411684867, 0.075564923399682807, -0.91625704537796726, 0.70412403005539237, -0.98069305175146859, -0.60967215887737491, -0.05772942275445124, -0.65632689658596299, 0.56842732195495849, -0.94944425415865707, -0.063603706610361146, -1.0021856548431531, 0.16101704088924434, -0.3822242283385866, 0.68106716501568298, 0.039395349433375651, -0.19243597383255279, 0.043231512976185826, 0.84723170382091662, -0.67202863565541626, -0.47703398325704632, -0.35211729329052605, -0.95809573677615201, 0.1595375394037844, 0.48379014006232868, -0.48578903324572076, 0.77860410361958909, 0.77990016086374248, -0.24126394114238348, -0.56855177708482696, -0.39081795102874906, 0.82791563123005663, -0.12872782520044385, -0.31655454675823064, 0.35197999318768786, -0.77303361289879358, 0.62707539174728122, -0.73397867794769323, 0.7312555300405571, 0.79425775537521148, 0.11046972735073128, 0.70204495874704842, 0.18952446843788606, 0.69449486940554273, 0.60011342314053251, 0.015585744387987046, 0.4965374996042432, -0.31699198059915684, -0.2160601989758657, -0.8750289991422846, -0.81899486706820801, 0.92295761324894798, -0.58731101724169443, -0.26061087254868881, 0.64740399746289434, 0.92367181174494239, 0.21474440746299386, -0.37511995446221424, 0.85573776109731481, 0.30329497463245375, 1.0332953008168508, 0.54733574049697753, -0.69848692150616098, -0.58082897608061845, -0.41252042273682243, -0.11792016262661861, -0.10496548113544051, -0.24720994701155416, -0.47314626552007405, 0.050848021663573405, 0.26726842960937064, -0.49065180831265848, 0.21107406780069848, -0.68240821209181268, 0.39396926456618431, -0.39530537619549566, 0.10827070017693585, 0.86452462860013979, -0.013423821252221746]],
	    [0.7567865270885511, [-1.0565859436481704, 0.0096434283175383315, -0.10793971319894523, 0.59179029269764249, 0.62712676477817364, 0.20642756567500656, 0.33333916096578053, 0.092210413492572807, -0.81270779236841062, 0.53493233565755249, 0.5573164155528646, 0.54902169354816854, -0.35440708701113582, 0.75916599738830959, -0.58104400564886305, 0.10063354054347888, 0.13617963027342875, 0.94013909273932905, 0.54429124774897053, 0.1159846015665056, -0.31469743981284015, -0.556149088989354, -0.88012445195471445, -0.78525512310090528, -0.029274546358719979, -0.27229839917193249, 0.4519260212556937, 0.72981976492151701, -0.57677027144276938, -0.097097812855523324, 0.98412950261252752, 1.1414950603677714, 0.95481889605448267, -0.37820143538872225, -0.1499992096599512, -1.0790507512755867, -0.16165342335163393, 1.1388819043559195, 0.30560584432717902, 0.52082046734189213, -0.21022422937307225, -1.0305237816183668, -0.55495151503893836, 0.050644263648202202, -0.96503549294877855, 0.39649937361181659, 0.018720042141311226, 0.15971798749404517, -0.95375945829248032, -0.50655464064353795, 0.32553107964520761, -0.24634848028322551, -0.65576867374965631, -0.768869424346589, -0.83533243109175614, -0.91591264661327298, -0.5222896983029226, -1.2527248529191612, -0.77529786412167656, -0.093012123115562506, 0.67862472853979194, 0.75976033090635287, 0.033357900078406583, 0.39107242783364921, 0.67188144288658969, -0.27012481312600001, 0.73662326569527448, 0.061083049483108297, 0.33238177996834745, -0.082045162654578535, -0.62365047151023423, -0.30737700875259932, -1.2663489683536371, -0.12561464577232195, -0.33480137171947044, -1.0335254142810286, 0.7529291039404834, 0.55980720239184234, -0.33529411470953441, 0.52577695939304014, 0.35343751663049167, -0.58244274299355769, 0.23000014369925492, -0.39133659237252444, -0.78970255658164445, 1.1083376524247148, 0.83658637848383355, -0.49471369543137211, -0.084277914301585335, 0.37641471717787245, -0.74265741095603788, 0.55205775846206528, 0.1993898314904847, -0.45771045437478908, 0.58331249123004514, 0.51307315246366614, 0.80466983779491918, 0.21270208738330013, 0.33667010135391401, -0.2811141350779644, -0.78021352727998383, 0.11349704250650522, 0.0063577167224778087, -0.45188692338830078, -0.043659894513297839, 0.078856895734869245, -0.33209565642124117, 0.039922931078193592, 0.70518786849420223, 0.70728658713225279, 0.78658262550314506, 0.45115681007076569, 0.90322869086567348, -0.71266635076410623, -0.71048467936063697, 0.79010114205599591, -0.60751256199761139, 1.0089329929237203, -0.47781785663932408, 0.30935585050307951, 0.033067628846043647, 0.11333330232867712, 0.99416350532957398, -0.80232448810934853, 0.17541603327516941, -0.71181057183535845, 0.92379163000425524, -0.64434709350781727, -0.69758006704517728, 0.64162030596233433, -0.050169936161491992, -0.58538575160956052, -0.74441327267541268, 0.10711892591230174, 0.20757050891820863, -0.77182338164512676, -0.49862774868950788, 0.83660597678089688, 0.68540194211121752, -0.49610536866151056, -0.47720981348442526, 0.59405448387338178, -0.24944700635440603, -0.45435348078601834, -0.076213479994764424, -0.79080433117788929, 0.24388436222814813, 0.21741289630685864, -0.087740606412388414, -0.4965043485871059, -0.78044277191153189, 0.79924675795494049, 0.6500812294777647, -0.10640628914880626, -1.1211452258375563, -0.051599348813056549, -0.56459175856493982, 0.19455173063292375, 0.47220293658268941, 0.30804261513581754, -0.86090914919430994, 0.036303409867136205, -0.33018037304724035, 0.60337813585224009, 0.40388600325102275]],
	    [-0.35266334446732189, [0.97907151116897728, -0.5970312751667497, 0.57216137034231218, -1.1278532464733009, 0.35634221105827085, -0.10261785063362669, -0.38581191767216022, 0.57605280234851441, -0.64870782733026633, -0.19891884588167055, 0.98736691778917318, -0.3215499874145491, -0.57099102773943755, 0.59081314939958252, -0.91577497479259118, 0.17528910907830494, 0.73819005817527494, -0.2573621621398206, 0.5622412204333368, -0.63289030340434627, -0.80631636951693719, -0.67042588983895679, 0.60210065951237146, 0.32498720044772661, 0.5714995215899844, 0.42673811308356041, 0.61386942705291347, -0.030076983647629101, -0.39559714602631452, -0.84431183405159782, 0.34712762160913035, -0.6457795532496573, -0.16675613723726607, 0.5880529210787071, -1.0036779218213434, -1.0660374391598944, 0.21176719225033316, 0.41993926096098999, -0.0993678795808043, 0.22157618685601335, -0.25786245018178422, 0.50925834647964918, 0.39644677251387855, -0.33104565922959822, -0.15720873494774779, 0.18564249440139477, -0.31606175868678343, -0.64103719954208749, -0.29477846916472417, -0.46550193568711601, -0.3258370795830472, 0.33464008398714462, 0.37038512847844274, -1.2100097056231096, -0.79083625472542995, 0.14299435516000417, 0.77413113255513966, -0.67032518840889332, -0.68837706629494921, -0.15399260254493785, -0.31193939727242831, 0.2404647244894999, 1.1611782807127851, 1.0109347777438544, -0.80067699455383767, 0.49274604121166393, -1.0491784025858151, -0.41232006426752338, 0.162014580236331, -0.18147646523257271, 0.32989750392223588, -0.71381706444158222, -0.61698615159163595, 0.87298006252551685, 0.53136851270261132, -0.8370628542317361, 0.71707933808535673, 0.38738722818365795, 0.88044552743048399, 1.0401119853935168, 0.43412950796344257, -0.059098728184539505, -0.52067565316643938, 0.57396447387267824, -0.82611453008740876, 0.58734304177521734, 0.5313103910174497, 0.65748050150745052, -0.20383718870580803, 0.22096643660105197, -0.86869223062852485, -0.09606239444115186, -0.49430115842429589, -0.072720887511425802, -0.042102167922491315, 0.029002774748942042, -0.55657262029726928, 0.53596561630679407, -1.0057762730967283, -0.67437788982681868, 0.13559904280422358, -0.45548390272751405, 0.068509370940359901, -0.60285162610310705, -0.73925972233454984, -0.91344323170788433, -0.37252366950658677, 0.19842164526694456, -0.54979898846972142, -0.38446199284366855, -0.84579373558807103, -0.90653243926673877, 0.32678445130550537, -0.62509284941763898, 0.15833135112685684, 0.05093539447936548, 0.62766239435076709, -0.69134689349236922, -0.49036699733034977, 0.57375512398911654, 0.51290270176395369, -0.77804781112375088, -0.95728778753243471, 0.37501622448523969, 0.87325489534578238, -0.27967314807104054, 0.57085828942852757, -0.33600637162315133, -0.60168081249908645, -0.065411205745988188, -0.91338283323673053, 0.50917798607235643, -0.85828977396322259, 0.59837884275625297, -0.91189713865814526, 0.25829616554575247, 0.44456853145476177, 0.15982818512941005, 0.12506207542990383, -0.59289410744078619, 0.47224863339553846, 0.17365487510017907, -0.13475771970910319, 0.57749685498686887, -0.58287740233369389, 0.89737238317490586, -0.64445900632412267, -0.58701329454566653, 0.072145916053257805, 0.0083745526468006481, 0.26287281727720657, -0.31966300929290997, -0.16067096803229103, 1.0353362125568488, -0.42872071993387972, -0.92198487497166559, -0.010208198711772774, -0.8468683647276688, 0.44267617436696499, -0.47018927611654981, -0.093296163728219694, 0.0097920539053906186, 0.47411279519790472, -0.16384842302504277, -0.95479924023761176]],
	    [0.30781637724202082, [-0.34526287044407611, -0.19674822751759102, -0.36145126605170341, 0.23379183247150637, 0.34818089350231679, -0.57592635075895149, -0.6411015487676327, 0.29148725455551772, -0.13857022208240735, 0.10488503916018924, -0.29592766130897069, -0.75942506884342287, 0.65992058431878142, -0.29369261492901133, -0.51937876589796383, 0.30876321311846816, 0.74721425686123122, 1.2049732137456148, 0.67038365789828658, -0.37524833782669192, -0.50038185893811371, -0.59290230982562764, 0.9325599555985441, 0.40848008662548024, -0.11106368439634469, 0.47125184910179141, -0.53944153189026656, -0.82955739523970606, 0.10536583671036021, 0.066960673765198653, -0.055104359310133057, -0.93017189845844939, 0.87524021262071938, -0.71791642766124697, 0.45193948385968563, -0.073832882122693635, -0.97395291679884433, 0.48285061941368096, -0.54618931391923686, 0.3142072187447017, -0.44062539563471637, 0.53646080377252592, -0.77349452453595924, -0.3522203734590994, -0.091086920767130319, 0.4489302330125936, -0.72751838930052259, 0.63739231699056142, -0.65255467257932864, -0.30414201415433922, 0.2800901543453424, 0.38976159485810713, -0.69515278205367603, 0.91766542140943075, -0.85154975820605372, -0.63879213883454022, 0.49097999036899598, 1.0092824060900043, -0.18214894493234379, -0.033735795315189554, -1.0348841219487481, -1.0331037152530016, -0.85024481633728266, 0.41415565466608106, -0.60542653397083579, 0.87710995698477268, 1.4436349492758997, 1.1525163991557628, -0.660060202686785, -1.0855200285453672, -0.47555311685444251, 0.028007322211825163, 0.36481637666885358, -0.6728311291992406, -0.64397947685209544, 0.0099120669194754946, -0.85981187587864583, 0.79288591535107156, -0.82631430210108803, -0.59350486092466992, 0.44544326430913128, 0.85280108891441619, -0.45050140150715512, 0.71884378519977576, 1.0180981701341296, 0.96458694531698463, -0.28652708321091047, -0.16674511408599527, 0.13772313667471309, 0.97974731677506743, -0.90069739340709654, 0.10482881704943503, -0.50953838620361613, -0.70116604200042199, 0.32801421129207536, 0.65584040484352191, 0.48475391215235414, -0.2573464684134128, -0.55391606114443381, -0.57234876249490885, -0.18193813404559622, 0.73897638047952741, -0.98877212912345069, 0.54700743028569554, -0.34094250903277856, -0.87327739590275277, -0.23070927614647169, 0.81422891183162671, -0.65537419022206778, -0.84578867715829453, -0.79452106017471669, -0.61809988373812697, 0.15132213051213009, -0.94758281141924461, -0.28771985841718034, 0.7307011106935003, 0.65486454051901022, 0.80868294392657436, 0.14842555767554649, 0.85533400597885978, -0.30692062023577754, -0.92382823362295896, 0.80551800048404909, 0.14941106583745389, -0.74302764757935857, -0.23924680077492094, -0.86075782713135196, -0.17848838455257346, -0.13823268330273869, -0.093645521047622332, -0.45931962996896825, -0.22589068751978289, -0.042959793147631958, 0.49871628015672942, -0.94450248821086513, -0.049010670422579408, -0.31949016930978325, 0.36816746809875234, 0.069213080448188566, 0.50948696585809938, 0.39963141932870483, 0.14665331206646137, 0.098162701519324796, -0.44509655159569367, -1.0573374979998573, -0.73775088333824168, 0.62762415732360588, -0.3361140031430499, 0.38532136350089663, 0.33295281014158329, -0.37530060583177788, 0.68030142144332606, 0.82895899375868409, 0.82231925898321978, -0.63653695729307114, 0.2249663190182751, 0.008283101133893361, -0.045894703602297103, -0.25085595844784719, -0.97147064293586483, 0.90195802639435074, 0.84911292392588367, 0.075747874496147949, -0.15392441939494272, -0.029653979791621987]],
	    [0.18152174381065631, [0.71016341855231435, 0.22444293909401541, 0.50778851366331157, -0.47743516902576605, -0.80800664709848546, -0.71363367586747584, -0.67833357832925878, 0.076072792884811585, -0.55444550462665487, 0.14114995221073653, 0.43332292440716302, 0.15401748596612522, -0.30803874317263286, 0.34484920119199747, 0.10922707232625206, 0.90800229510544139, -0.095504194578368423, 0.81789768373294214, -0.82308184298889864, 0.43641443952473813, -0.28886344317186352, -0.30938482693133856, 0.42079674448186294, -0.82759853880126732, -0.98662979611795931, -0.97650995643531058, -0.37931182200468849, -0.7285352587950279, 0.73949877817298892, -0.43024737548989544, 0.37459398204715794, 0.60075968788722678, -0.50244391364493579, 0.17335718924353513, 0.26004061614671936, 1.1225797546194141, 0.12270174602688907, -0.10103083915919109, -0.52094506647409999, -0.22621303271846097, -0.39509513377021999, -0.21916242229745256, -0.76785494819941946, 0.51221715002911206, 0.9828065900857228, -0.12444059444408535, -0.24482741541799949, 0.79224187156970038, 0.86671289287211883, 0.30415463236414758, -0.2770456817603833, 0.78480147332124051, -0.32749488420663531, 0.36746087543092876, 0.70823588386604597, -0.47048631172013022, 0.45996466735573061, -0.18986455359881901, 0.55264183367246333, 0.18023805701712514, 0.425593196447485, 0.11243834114029959, -0.39436749070501448, -0.8108624892313876, 0.43213483564268773, 0.53567121733134626, -0.60611729581683982, 0.1826419561307964, -0.16994733449764171, 1.0734020189263249, 0.41751084333673105, 1.1435351328000549, 0.76337395394710317, -0.85919264358536918, 0.09767913094775893, -0.41875002232422059, -0.80350806347146519, 0.7730003065182135, 0.54807007753309323, -0.0090214492805013365, -1.1347524750695783, -1.0383616835078109, 0.18342693498509702, -0.92892181717888156, -0.19522001332770053, 0.026422459972980678, -0.20981608344477487, -0.23842479463639626, 0.9191393617746636, 0.83575642646669857, -0.82551155589432201, 0.11575058897556711, -0.56769629130849997, -0.36220433423024889, 0.080680100411048658, -0.57342291134336787, -0.20284082674049206, -0.44873238054004788, -0.52924718107300317, -0.23001482456793226, 0.54251077468592268, 0.32626006863282531, -0.36867333255379747, -1.0467296171673068, -0.3151143884171787, -0.18665851494507554, 0.04819229958980556, 0.27080427831190601, -0.22628296762817501, 0.10639510008618035, -0.18507890879393243, 1.0066979191487897, 0.94236805261631296, 0.75703145776984071, 0.47647290808057197, 0.11140079097075455, 1.0149034346699684, -0.3815758328243864, -0.19312540704874201, -0.13041398240541829, -0.42982204249860606, 0.65587434304893699, -0.18496860532990336, -0.32326865918388115, -0.13478255452699944, 0.46659515251210576, 0.60722267534538099, 0.12226190684122093, -0.56795406762661937, 0.39578116884145503, 0.90179112062625544, -0.14789063798286139, 0.60670761582061994, 0.4182264040593176, -0.50821962752383776, -0.56859813971185513, -0.52155324558802885, -0.47065160737013406, 0.31262075478791707, -0.15265574298691409, 0.12660780236393751, 0.56050043010326323, -0.031767583844327568, -0.67670536192460817, 0.41043266742741769, 0.19739320858220233, 0.76777972819168949, 0.35225596533078091, 0.63719027304265341, 0.28180560244412511, -0.20256734117459932, 0.40910442141882131, -0.57147556770326724, 0.0052833339431537299, -0.15513162246983728, 0.66727646069824287, -0.89117225125470501, -0.21257589688315889, -0.44030304739779125, 0.96696652606643774, 0.50868558873918301, -0.46656918577401596, -0.80268099989340236, -0.46177117408276236, -0.67761902262882923]],
	    [-0.62943876127295162, [-0.42903510623118124, -0.44379794967567682, 0.11978184138160844, 0.5494515479944172, 0.15309811464059983, 0.34351547048357911, -0.58000382963135788, -0.47910014054165778, 0.23008749358632716, -0.0046820564727393515, -0.36967969375767434, 0.34157428928482114, -0.17515998748687683, -0.91385807549139586, -0.22850093364395385, -0.62035347303750754, -0.42453580674606062, 0.050820346795559787, 0.71510787085707428, -0.24741882796359629, -0.83672196011870026, 0.074982332159676132, -0.77541087289137223, -1.164415066745988, -0.64917217508759562, -0.41597505014954056, -0.83172193737591027, 0.69094509662781112, -0.17098943193188632, -0.81833629236868166, -0.74236225795731969, -0.018907010231028403, 0.028490799779365885, -0.29721996257565819, 0.24988048268495677, -0.33130177498776592, 0.10243090513801809, 1.231276386894413, 0.60615857769881687, 0.92012628504107608, -0.13151314978302808, 0.5848997918108797, -0.22771729413347219, 0.34442821892485742, -0.46991833137867323, 0.4167947573367633, 0.57242086837056227, 0.0958733513738452, 0.73269905367864507, 0.36150228303136556, 0.28737525393823377, -0.6710541177661894, -0.64062580403409908, 0.94148406125935158, 0.76415015766679917, 0.057740108668948686, 0.25953427074400787, -0.80691212850510041, -0.21811058266077654, 0.34913970589450583, -0.68921605757257964, 0.65804803502334253, 0.52690107325073621, -0.19917788465012978, -1.3749488203449007, 0.45046873899834083, 0.95967692639059055, -0.70806612204990771, 0.94131252674681243, 0.34853013516740222, -0.26413136627451789, -0.93823810207642044, 0.025052554612627936, 0.91916810905325763, -0.97160111855397413, -0.45006963324418403, 0.43151730525701526, -1.1987189237193021, -0.93127830849892679, 0.37964941589625162, 0.41848007320626257, 0.24737109610145902, -0.13382499525949393, 0.52559115804507539, 0.66150669978401533, 1.0221832558108519, 0.36163237634106937, -0.58497184471353003, 0.6535561642045018, 0.5550529489203968, -0.2052664527545717, 0.27965843159611625, 0.97197395543545906, -0.030795982227381221, 0.79205112160233493, -0.65350764639034509, -0.70572368281227971, 0.31321913675520946, -0.076282558048851479, -0.45618675606363612, -0.52739904640931934, -0.50426123128134392, -0.079972163060944082, 0.81839018675589237, 0.99677483871047912, 0.31737253948133265, -0.68435322775715324, 0.24903425127495413, 0.93719675017987614, 0.66889818890353714, -0.60500212573274059, -0.9296892722225617, -0.69846053048313617, 0.086792357448018304, -0.15981132943421147, -0.96717482900621321, -1.0570049876126035, -0.068740337029257706, -0.23916124472441663, -0.058763242658939577, -0.79524765698138311, 0.83049239725371937, -0.88429497760975118, 0.30553949619267612, -0.99137969658131442, 1.0100641141803943, 0.1362791952525072, 0.045027350505590383, 0.64762938659429492, 0.26998913043955453, -1.0398697258660694, -1.0097921308954318, 0.36328769906292729, -0.51407963347460306, 0.77309147871772299, -0.77746315103813357, 0.17777113310147541, 0.65097879476364995, -0.7249747424868378, 0.72061302015741258, 0.63576966952273195, 0.33119940719604468, -0.58585605504629124, 0.30912896749446533, 0.10413912644369165, 0.090791930298803822, 0.17589653914476575, 1.0849329965881296, 0.43786606417609991, -0.3255042077441479, 0.51975192916020763, -1.109994519344413, 0.54221301005562572, 0.3450639801752271, 0.70955569456850809, 0.023507945828399164, 0.044765920746920138, -0.05572870982403734, 0.59859727306895605, 0.99988914033658749, -0.5094072055221035, 0.39903468183226676, -0.94586688081083037, 0.87218733198241005, 0.82897182013856163]],
	    [0.14139952939036107, [0.85493249838160879, 0.90334866764635813, 0.27461194235579922, 0.040517253796659741, -0.12226201639219933, 0.26557428552657769, 0.54204145418951399, -0.59065926847587258, 0.054391122082168369, -0.82956580911934119, -0.33949369614585162, 1.0812474838982777, -0.88913525258045079, 0.83148046708097989, -0.87040494131720969, -0.52524620148125789, 0.86567425072609328, 0.35365828385500103, 0.27898702497902905, 0.84879961739932919, 0.23777717797752376, 0.78049310817371453, 0.2219715626410543, 1.1163065520016056, -0.45046111682158502, -0.11991454333586174, -0.30786651395809078, 0.23761377578636106, 0.92006834996590503, -0.24364132584902931, 0.68137039675541478, 0.83740695114808295, -0.10192192172411096, -0.26867369957058901, 0.44148120480481839, -0.99670286462358004, 0.4668627450680371, -0.40136652685383489, -0.12978518047002888, -0.95901315546974264, -0.45711993517241117, 0.44592438504637671, 0.67737147737974768, 0.74955800451201593, -0.31943258978216593, -0.36590379035785203, 0.83675146465758243, -0.52758810519013555, -0.69799399526070793, 0.6623518912228864, -0.37670998099666853, -0.86631385561329211, -0.8872544437881581, -0.26494269360773576, 0.55779151657519133, 0.34747352249643437, 0.30306660467476793, 0.55716668187253382, -0.14228990850949408, -0.52941298059351172, 0.40681505290096659, 0.54138107087509912, 0.30195557748927088, -0.50356935616543119, -0.012442081373674531, -0.36143295809210074, 0.3084003372970584, -0.83443246478686839, 0.087856903025013353, 0.13372799468062924, -0.72377155805479043, -0.73797488728849336, -0.81692402355963223, -0.88537212984749569, 0.65884883074359224, 0.11942929910170959, 0.62309054837588529, 0.10042236759291936, -0.29481861848802637, 0.80091492968469846, 0.81257628002372595, -0.11412740125794661, 0.39585992583620883, 0.16801846847909746, 0.61987152517305766, 0.66601496857621689, 0.11255969757932212, -0.41958460961848887, 0.81091526928079116, 0.28268815460111152, 0.57314267246752471, 0.4157110373390116, -0.64717624945230223, 0.1497027824257712, 0.20097373324862364, 0.39532949237525472, -0.76452673958676376, 0.033316243998030022, 0.19763716415225341, -0.010183982018390639, 0.92244873997261279, -0.62569416962273239, -0.21311663105467671, 0.55213772295260366, 0.298076006661116, -0.90015436669238458, 0.07520342598907373, 0.45393236213895127, -0.01544018461138975, 0.23593530706944477, -0.86896490005699467, 0.6953485365829527, -0.79882679940221735, -0.57579050769240747, 0.81491294028940631, 0.5868556018369212, 0.092182725424584958, -0.80955474199394784, 0.54703308642338599, 0.63528234113421089, -0.062955931075599325, -0.20292793495143394, -0.69841621435989543, -0.84203337260823241, -0.39441921806397345, -0.9140126269001192, -0.77512910756726094, 0.9236174816524203, -0.1823470382223239, -0.013956574549862372, 0.93740701627838507, 0.59204731998987103, -0.95875370679548755, -0.57371972354909262, 0.60308280091525768, 0.90524876374001628, -0.40500446016854164, 0.29811712357040382, 0.67493097343142017, 0.25322994713482844, 1.0048899501184927, 0.69982405498647715, 0.42579041138089013, 0.31787948752096518, -0.81110131279304998, 0.45613555453684901, 0.83008843240544772, 0.55039818892367698, 0.69425244283154786, -0.61745536015305369, 0.77996167083571877, -0.39844306379603717, -0.29646054846705416, 1.0001721701091948, -0.69243228302651827, -0.20877312659664773, -0.81956978930552593, -0.16755869568402701, 0.67684925039539101, -0.65766266916922067, -0.43216234478216431, 0.95545169513875949, -0.99479583487499013, 0.39226374482729187, 0.82475926769351826]],
	    [-0.74810399775220959, [-0.6088490642614558, 0.48033868647242745, 0.31409883075274347, 0.75196291961362605, 0.8403793046043716, 1.0565232434653093, 0.12520058965935482, 0.68126420513834918, 0.47274718006634164, -0.50759542032922822, -0.49116285935465231, -0.95512549166140448, -0.14305547692545881, 0.01599450097050692, -0.88416838534520426, 0.3143242357834819, 0.36283058183969796, 0.19543700216473706, 0.361272556112953, 0.70093208177865474, -0.24311146154774796, 0.65144760524945855, -0.00089511745395569353, 0.94801837133214095, 0.8728637889685108, -0.87001542783937269, -0.27374250346254342, 0.29074598287984849, 0.108170668462749, -0.095809196903448468, 0.38487677384864072, -0.48897285606888757, 0.26544407743132675, 0.0058622288029661889, 0.14199764499517256, -1.3551947101032713, 0.25430597658018195, 0.79464737716612166, -0.9265470567956785, 0.0076143012302556344, -0.71629202310555451, 1.0957264221313874, -0.79458627238454926, 0.39164629978080473, -0.36888709039570444, -0.26567009237682171, 0.32238890195855585, -0.29663172736816679, 0.78718378517573262, 0.61942846537397278, 1.0455150991621847, -0.39893779788873035, -0.57985980409876692, -0.51432714554008785, 0.18732884102901423, 0.66480977324662183, -0.26024434504805333, -0.69470142391664169, 0.33951344649780907, -0.334752478464726, 0.068238469236856655, -0.34266972606015517, 0.41405877657936146, -0.30593204546822828, -0.40607767390540062, 0.20435072648179428, 0.17440683562747494, -0.14882347256225989, 0.19130252553040791, 0.2435915948654985, 0.93527233733616888, -1.2938550008151011, 0.42049106828296495, 0.49656308003867422, 0.47144871308171576, 0.35425908712531645, -0.6142360706685831, 0.51832365332037444, 0.64695875628368238, -0.14804461351858383, -1.0044414217873028, -0.28451399228420043, 0.5355534613594527, -0.31372484629519676, 0.13169077267718238, 0.82136630077604245, 0.45803352632763733, 0.43296537408308106, 0.74250261833385789, 0.087237011760056493, -0.34264904586335992, 0.49942628726224175, -0.1199827366265671, 0.32787190591935461, 0.1600428629554842, -0.91880849981084722, 0.54336848212915134, -0.18429291966723446, -0.88836483719105819, -0.003355358649304481, 0.52414604290572686, 0.47551131147088266, -0.023431002403872636, -0.33343285996182037, -0.77341433805529936, 0.34849000298335259, 0.91099270106251462, -0.86549781190405417, -0.17748998259770893, 0.54201186583194805, -0.89214823081361572, 0.13965980008604889, -0.79495199637063041, 0.63225300853111843, -0.86681063135917147, 0.70981396455729895, -0.9267228891665712, 0.42769469849588293, 0.12294414173784271, -0.40286092787886651, 0.97237383459466387, -0.7573466805835285, 0.19142311094278597, -0.17496194787183036, -0.93938015950049369, 0.36796030839666272, -0.11592426235271343, 0.27809299478366667, 0.39592452749374213, -0.60034185220021397, 0.9288005516935578, -0.170479150123232, 0.73140886822844886, 0.85133406086853081, 0.35707700938899234, -0.70720204454494606, 0.90650118051802153, 0.31080018830949824, -0.16167800611415395, 0.55392486160165111, -0.12283673420829101, -0.22721369467578359, -0.19722900562731999, -0.56341147274061987, 0.75056233337789691, -0.87083894824457475, 0.27310516329958534, -0.37177210063116217, -0.99434414886786882, 0.29768529325682724, -0.8682897513426584, -0.7044976636566801, 0.096724566212059937, 0.90702104815954065, 0.69039725482216352, 0.91211400442010748, 0.44470263719347364, 0.71730190533946592, 0.45358609658900373, 0.83805569303359295, -0.17739653493155427, -0.12478679132283554, -0.55611823897484713, -0.010179921399741998, 0.45807804386949602]],
	    [-0.47155084545996578, [-0.15553128506020056, 0.46149058343989485, 0.39687752685052891, -0.03964686240318132, -0.11740588199259253, -0.0098132290711046306, -0.35210389933421926, -0.74452092135902093, -0.28195988281931011, 0.96559252980626653, 0.38367151717319625, -0.0036291750026417233, 0.0031443028786075009, -0.29505774747934366, -0.73895474123062654, 0.81517180581970394, -0.87035859972916985, -0.56036442015962573, -0.17794898485524152, 0.72590651983828702, 0.60337896880004138, 0.73133120092884685, 0.16070133444687493, 0.4275790998976664, -0.50841452717171443, -0.36638086936022513, 0.95935617366957548, 0.29037292319379149, 0.89200657308571463, -0.57402089239783582, -0.40006522747932327, 0.20297169117100478, 0.012789941910488892, 0.72463478373312307, -0.62773266364799651, 0.24998254132732617, -0.94652363659718797, 0.59601011062641773, 0.90348462040096333, 0.19220215843220811, 0.031564713433494124, 0.65457686259474779, 0.79499650325670013, -0.024499058212065949, -0.47171660129332937, 0.75285307771189369, 0.87613968882007276, 0.14262788493770187, 0.80489656539486409, 0.9625069167724406, 0.94793348808972977, 0.85121223160395687, -0.48755552611577363, -0.77883223415601954, -0.80188082152882345, 0.92384107474332133, -0.24243373243522803, -0.16078833192878395, -0.72070054056187127, -0.15410668401000716, 0.46465656378209907, -0.13785592909650862, 0.73209956462441073, 0.055679095872499862, -0.590133477837259, -0.66348650184096991, 0.79053880726574566, -0.097771677230408652, 0.22641061606505003, 0.69843294155067648, 0.060675476421994251, 0.89121662779844657, -0.0091645199635357402, -0.82496565890160722, -0.69882681880474529, -0.049122976901628569, -0.01388393772514135, -0.044475063579663243, 0.66753252605976099, 0.8371479567249015, 0.58205899803193673, -0.4940037500636042, -0.61182722509801502, 0.24159004226622371, -0.20598217871754401, 0.12748749922704941, 0.53099573374352504, 0.96344076512053578, -0.53234973077220593, 0.44358443867198649, -0.36871621399124549, -0.60303535260575969, 0.83590185812193951, 0.97499531352809499, -0.38917873714465367, 0.96855622254940088, -0.73315540425278036, 0.30589816754674032, -0.14299324511649725, 0.63256744661436592, -0.26367863748229509, 0.47200629845056941, 0.098826640448552994, 0.34983778838397278, 0.97458031791666089, -0.33720652084314484, 0.24774187243210821, 0.6944838420061008, -0.80475131845805381, 0.66684287943897536, -0.62506847051885217, 0.52869127202560551, 0.14027721400537738, 0.054157077382848973, -0.23488609866424259, -0.66752979912308719, -0.86665718687501681, -0.33205901901277829, 0.76623044501110305, 0.36032454494248439, 0.48623354422026782, 0.035064616189290146, -0.9002979576495298, 0.75745276958234975, 0.66059314388811385, 0.14378834258095102, 0.29581035856926968, -0.37233202239529933, 0.16691671320009729, 0.46296641534188582, 0.53042424795974219, 0.020909109393292456, 0.71370404827635958, -0.84233006887835027, -0.58980218587017441, -0.62585788850552737, -0.82054134028371295, -0.88942384611372016, 0.19166053307854508, 0.12795718644294127, -0.63554895257668254, 0.87812736283011039, 0.29235238714282891, -0.78475501748643428, -0.49571942540916836, -0.89768504782891334, 0.304064930447354, -0.10907082805477315, 0.30371377203187555, -0.66797884132034246, 0.36515102972134056, 0.29137440936934411, -0.4696438746361809, -0.19023544668616327, 0.31280998870327847, 0.32316437522445018, 0.12868348048229117, 0.97830504999122236, 0.97067553967697917, 0.084928057174546323, 0.78374016149339032, 0.45478891450321046, 0.26441952477817887, 0.48402085117529836, 0.06408421770603967]],
	    [0.18358451364577261, [-0.09154895577092946, -0.21826914338389311, 0.43039121479288672, 0.33180079224386061, 0.85586591282396629, -0.22484649273151358, 0.37075574210302692, -0.51834160944418783, 0.79706526411401879, 0.84614351888594785, 0.86489244445881652, -0.69670613557138716, -0.59263146409991652, -0.21423721444111954, 0.88919578520348064, -1.0044679419373868, -0.060073428528523806, -0.69853029048799042, -0.44486325436470242, 0.33093527492292019, -0.51974179726726766, 0.37718239637346201, 0.41530191052094617, 0.17159999331956863, 0.82930957027341246, 0.89047749322533853, 0.36755918247473091, 1.2901620148807789, 0.72737706239129785, -0.63713861238096747, 0.59481403972776858, 0.13103911194136825, -0.84264818966006128, -0.89816027223004691, 0.75312220544232722, -0.2873165990375382, -0.95719573949451786, 0.9016493301837667, 1.1421529358088272, -0.36244377917270465, 0.61984517773249737, 0.061250723149282191, 0.87871974604154079, 0.70547923073667718, 0.11009253499361882, -0.061271279799504801, -0.98734041070502099, -0.81478537568461673, -0.13775383101992916, -0.6425267507052812, 0.039667710845007392, 0.61797148693205095, -0.24338275276286891, 0.7140194023650851, 0.7398291523806978, -0.075458544235416827, -0.11934666587165865, 0.99053975270066608, 0.26121093497573977, 0.63021838622937731, -0.26045013099048153, -1.1095094606773725, 1.0392810994310349, 0.089989968362258782, -0.39019671836189918, -0.6379302502924058, 0.85560975953710783, -0.47548155642081674, -0.031355293147606808, 0.47087855786945665, 0.72165199709415506, -0.32546673403905491, 0.92127006645524212, -0.49170632736333209, -0.34760375419895606, -0.24371041086333473, -0.9774965524090603, -0.2706020513750037, 0.0014907237874990868, 0.36172984854145379, -0.5531291182968906, -0.35866042787897739, 0.4713919221306565, 0.58734627872949285, 1.0089006846043704, 0.78743696879083136, 0.39630773843130018, -0.71543055799070188, 0.80604424237106942, 0.79042268463042675, 0.330135225348205, 0.45606382293807379, -0.57916200421657782, -0.30698750971078653, 0.64467968813535226, -0.60664168332531665, 1.2405571312615185, -0.37204496269047449, 0.85024989542564855, -0.48595133134493534, 1.0744198115320145, 0.95929174731366251, 0.41726741616945728, 0.25383908338646832, 0.93124334753662585, -0.41615792552922898, -0.69590613611688112, -0.53925344666930819, -0.7937395971187019, 0.75572788564387094, 0.65607653481335293, -0.4686053028072858, 0.63234629314623048, 0.84568778729832883, 0.60993227378940329, 0.15953329039173955, 0.40018268711115584, -0.32186518808320236, 0.2976246320490053, 0.31728959530831247, -0.52553680148091431, 0.80283154373100296, 0.38993163796875185, 0.9753850559940751, 0.47963056451361274, 0.38365460791304817, -0.14392934603863639, 0.98629146373108079, 0.98113399777894827, -0.94032297013682209, 0.18815949287736405, 0.25664268463374962, 0.058396874803830198, 0.49553837001237006, -0.89428758039919654, -0.33135656689605153, 0.20858706086055506, -0.88834767461893749, 0.59357778673417794, 0.98005330065889584, -0.72590359286395045, -0.83206356457520136, 0.50032297096149325, -0.46789950429416838, -0.51621354299634059, 0.33282190391278482, -0.4293616692125366, 0.24661737373291193, 0.019213514246643408, 0.55353512649249637, -0.04472445293263607, 0.71000780608406644, 0.84980273336340972, 0.010513672897295599, -0.018926528704294621, 0.40161048147750184, 0.66173712402521345, 0.82650757118338758, 0.55136603769061932, -0.095917971018163017, 0.39159257114518509, 0.50805029610483743, -0.42480698055773636, -0.49526794383211903, 0.3803679582542463]],
	    [0.54436127876938034, [0.2246427023205062, -0.53460145213242094, -0.29158976461967245, -0.35540947670656292, 0.62036865556897502, -0.54986877610406271, 0.70929560848665474, 0.61457364283716498, 0.38426485361015827, -0.53834074418207634, 0.12361876767957092, 0.47200568645906393, 0.85903754427072354, -0.97084873662621973, 0.70769030137298383, 0.13235572903658299, 0.27994298167905302, -0.77238540075678563, 0.80315090633786668, 0.69733235077316413, -0.38849628347557597, 0.22136881693483346, 0.89854423525827232, 0.88867173597007609, 0.80138999241495723, 0.90871157884444165, -0.21094873059901317, 0.06819136422602548, -0.12589622199725117, 0.45585819494201196, -0.82628862281130788, -0.51803826769838546, 0.26031538393618875, -0.41110689193519628, -0.36208088337238004, 0.18041252751146267, 0.038619974398970892, -0.91825754763058587, 0.42500301641041388, 0.37094166626398445, -0.34893640139939336, 0.33554459699653449, 0.080404175391783531, 0.74500557104452902, 0.63148929779580443, 0.17508597829941541, -0.64205726232597471, 0.27257007747151513, 0.81630395863949801, 0.40037774064948312, 0.42625006535592902, -0.37142291201710209, -0.87553703710515574, 0.47926704970392664, 0.30835649596306308, -0.42714194368822012, -0.37525969133042208, 0.0070180756243057394, 0.88077477525292247, -0.91612318237891532, 0.31300714406959307, -0.71999934018135137, 0.036981027883906725, -0.27874204538733249, -1.2018866104879435, 0.2797340157422476, 0.34323496960696248, 0.11931755913882953, -0.158425623615496, -0.8771124519971597, -1.1502997757327451, -0.47310070290907608, -0.12340883892062778, 0.21673479775685422, -0.69607627754407631, 0.11496398986772188, -0.21493912538127713, 0.18071115566920481, -0.10764653402307439, 0.70251786102804326, -1.0617913432715982, 0.50011610134029383, 0.48674688578599273, -0.83491467694891452, 0.1430115568840454, -0.34990225315027035, 0.77961899694378856, -0.58136150869427972, 0.039591866070566827, -0.44349583323219943, 0.3997064385489123, -0.81315813928440728, -0.25160962560554523, 0.37954528181686475, -0.64613235288697668, -0.047960736578562861, -0.15444108563778902, 0.26570365736175644, 0.69615734855161526, -0.22144810260937797, -0.094567391191269667, -0.35724965838510842, -0.022792321848472071, -0.40666829870721205, -0.34323121202253482, 0.26963205308554, 0.0042078900330439267, 0.067930165081600755, -0.4310947376035672, -0.030044276321062224, -0.46648916949174724, -0.90306224175809446, -0.38855193591858683, -0.021771118970136557, -0.36488543117105793, -0.2738002979901521, 0.64245340658724859, -0.62816128299844276, -0.82541820280515554, -1.0205954764147811, -0.11776303729511313, 0.90262362000630103, 0.53444825716449973, -0.25791820770788665, -0.22562239851968802, 0.94345665488084951, -0.54830904735041641, 0.37417354110520556, 0.073856516159258812, 0.026117849287268791, 0.22252383646930132, 0.85624350626425849, -0.41055828367848762, -0.0034704659784683526, -0.26732067783123636, 0.75577134824281988, -0.018202608524795747, 0.44781355574018311, -0.090543701391918349, -0.24450639119737019, -0.75753014968085552, -0.16410866941069119, -0.12646349800133197, 0.8125090577014531, -0.081148807958652841, -0.25786198238071872, -0.82706635957772157, 0.73518816605570192, 0.0099511700169868569, 0.11187570683923953, 0.59101026069307028, 0.87153371744453145, 0.57510480970057343, -0.014809541385502572, 0.97543652936530922, -0.69843609422790331, -0.21170928070199416, -0.84074850725880168, 0.11020378724817231, -0.58379571646147155, -0.71417485032605033, 0.55178795431246908, -0.70070941359018213, 0.85534738919625819, 0.86121218120299492]],
	    [0.88710868206780469, [-0.24091943001013727, 1.2489730695961982, -0.34133003073535789, 0.47762547882036477, -1.0305665836313675, -0.83340055569039839, 0.98617021145502015, -0.73383063033290941, -0.59832994515729621, -0.43562690140847826, -0.30786169798486929, 0.82439773751490386, 0.74879544127138065, 0.82051840956402011, -0.064342917325598492, 0.15369635972075157, -0.22318414205728798, -0.56577617149712989, -0.88322803896216318, -1.1336707465846483, 0.94252383151116459, 0.054629683942881063, 1.0264785117470494, -0.54926780647943885, 0.50311504584243139, -0.15451010301397772, -0.34885500898806171, 0.53072111328190907, 0.35330327570569758, -0.14998754698901817, 0.46691985363440019, 0.23661604302783643, 0.050622224545437446, -0.97213769735803868, -0.26425362466485713, 0.2177492532269226, -0.081675059218591847, -0.41242731325204135, 0.49742749137105113, 0.39939221677096981, -0.68722307691530138, -0.60984033157578355, -0.25276670614362712, 0.37382026814852348, -0.31647276553883508, 0.068841775349862896, 0.14732372533174717, -0.16481714762638408, -0.2371688381937051, -0.061398852232081316, 0.44322511366084799, -0.36333311711077532, -0.1717719697151944, -0.91151481892953379, 0.021682721153638732, -0.5920599389810921, 1.4529647391659508, 0.60085016461325469, -0.35064468382594255, 0.63215836395537028, 0.15689229601100474, -1.1181084331176474, 0.15464651541317884, 0.57442628787139161, 0.2740356081199396, -0.6159035978400087, 0.91349539312202743, 0.10572895995013087, -0.87941744322216353, -0.76122267684259071, 0.6818619789329442, 0.64308089229080345, 0.047856127440188176, -0.44404358636051783, -0.23805497177478285, 0.70497776747502994, -0.77766967211963445, -1.0028070084562697, 0.91189639673994283, 0.068422574743102968, 0.14133907965720238, -0.72056652144078015, 0.12021182145885008, 0.75284830579981188, 0.41761444222606331, 0.20333757766230298, 0.5671770682181877, 0.76745524677033983, 0.061109807716075361, 0.24874074584123518, 0.8257636206476171, -0.56519674612695459, 0.85147335515446299, 0.7194747032757155, -0.32750218026237388, 0.4258776491533221, -0.40264700021230437, 0.24904836915894518, 1.1247611785723484, 1.1654668093935172, -0.34216233656678136, 0.28013288463772273, -0.47288313987078312, -0.34665100440297197, -0.25758880872831569, -0.1943405128156272, -0.55799430858773746, -0.85793706384591173, -0.92134839974444693, -0.47527278143481361, 0.75259218433690045, -0.27923884163573032, -0.39662182684789726, 0.23911396896898285, -0.82810295644271714, 0.77830351279041865, -0.3923502779796465, 0.70981428626687126, 0.53558584036607459, -0.069863027709025957, -0.41366006499045166, 0.32260497387356879, 0.5253539022518724, 0.54804170079484482, -0.24902056028505479, -0.70153291886888403, 0.33565925135089852, 0.89787088908077528, -0.18913034023369502, -0.88753272864299304, -0.39119773533162272, -0.04557187026654512, 0.61912665367526665, -0.40209099472490095, 0.32182919775538021, -0.047169226437636609, -0.57066527093638353, -0.13935026606702106, -0.96095865872637742, 0.46456240176832697, 0.56221201172158464, -0.97409985434655089, -0.66961338892217748, 0.58757609931337462, 0.068391826887266763, -0.012781279934692901, 0.86469533789741981, 0.057593354423083075, 0.41236059582916834, 0.12979430954055093, 0.39810355465399655, 0.54706236556852805, 0.11544893985591083, 0.14183863244901285, 0.047359687481071229, 0.19348091506510076, -0.063573277334558073, -0.22668044292145292, 0.12681532799889, 0.41638991999173891, 0.091040443666046134, -0.19318175792852976, 0.86029367264342071, 0.98753752173642817, -0.83663168510018204]],
	    [-0.61050912789804856, [0.940289491885971, 0.80637885472022752, 0.45773238136779132, 0.22930951965651539, -0.93578855254631044, 0.86514626303091358, 0.97148162088301826, -0.6352347674394907, 0.72225980846727145, 0.74254281515416531, -0.58786308960069766, 0.1978668785971115, 0.4336806867895161, 0.45880549831176465, -0.24197842853258811, 0.24436516200538322, 0.74748813497752475, 0.043783837164533504, 0.52801597535916445, 0.91929870918673728, 0.35117094751076389, -0.07190844100159445, 0.51692580255667941, 0.2109871261348347, 0.48709083921947971, -0.70592890533178887, 0.25978116569065735, 0.72863833825288526, -0.80114123105602586, -0.29539269248463151, -0.12075001460619041, 0.79811063673714411, 0.43840328675509577, -0.73449847982165006, -0.2837205643329056, -0.85331219879309017, -0.26605833945921437, 0.70566439965374617, 0.39181195863997348, 0.0080660823926178866, -1.0144775357525964, -0.23526070161509174, 0.30125781242878208, -0.68902495545675968, 0.54402204917885144, -0.93471153585065492, -0.91046523421321957, 0.64862280302059128, -0.95899516782743854, -0.58130048069430729, -0.48491725028045463, -0.57614422992806713, 0.18236699395385136, -0.41679036767672484, 0.36108571534634981, -0.18254891083795935, 0.3134794319617617, 0.41849641131618737, 0.39855443872703927, -0.23894687359648437, 0.11936031519085914, -0.019439665715651134, 0.51438374300644107, 0.7731358222990079, 0.43059757489155459, -0.13321955806014529, 0.51793502148607629, 0.39272420466332397, 0.774382485165649, -0.22198781228301373, 0.55646235924038967, -0.52161918093778625, -0.63530436313408911, -0.61125599086599514, -0.21546505467762755, -0.42988247660849194, 0.81827697462532034, 0.41707428831436288, -0.59049304767753807, 0.3017412988701656, 0.68865044567203759, 0.18518222045108179, 0.48342464109515992, 0.047435562221562914, -0.53279909548920334, 0.41800963503912097, -0.35862691507104572, -0.4016944806735071, 0.83692926260396705, 0.27120249963253262, -0.80177365717007631, -0.35747931062270721, 0.16306647383459205, 0.094724291665274005, -0.11140370678349591, -0.52388169106583427, 0.30672771256638959, 0.61467539559056505, 0.040596438048596757, -0.30573557466295848, -0.050872364299654013, 0.72067874544089283, 0.096695361509640684, -0.57314164062945916, -0.012922862110675384, 0.81583015606719356, 0.26127621063180212, -0.23136451233963484, 0.52631081096807419, -0.99089578699524472, -0.726645719952703, 0.091008534574442773, 0.1110310127154981, -0.57682081113368799, 0.39849577534510322, 0.60069493655057959, 0.64738442065845359, 0.21604816128153409, 0.67352562994778875, -0.8912528482948977, 0.05273946268755153, -0.57122452273347091, 0.85492817835783974, 0.90139781076000025, -0.51206125725124019, -0.2606247021067204, -0.67192261548512233, -0.1879703206499681, -0.40720795145371835, -0.74138239139307538, 0.92144469927126871, 0.039451507527342319, -0.76310785023310923, 0.9047323147905858, -0.5674744601333942, 0.051456756603375987, -0.043406487395121179, -0.39956122391852394, 0.0046175052541279063, 0.066567604993793744, 0.932246156395244, 0.49105245620757326, 0.083332382853230288, 0.74147970207881864, -0.48227571702332267, -0.71725467639278129, 0.36029735678844438, 0.18165915384963521, 0.081853874220843462, 0.99962577968531319, -0.77452410402574901, -0.65421250013780285, -0.98553120498979663, -0.30870522828500518, -0.63352482856105619, -0.47145756915376053, 0.13284922910396721, 0.77438294427792476, -0.12432493393650994, -0.36155296530930237, -0.43010175626844771, 0.17175056440452696, -0.5124423496196866, 0.8421087098629112, -0.55585915752961945]],
	    [0.70499476618505297, [1.0729349601974223, -0.55589222619592837, -0.52420486410216238, 0.76529755199095428, -0.38474164186313797, -0.85678513306010595, -0.94172213536360694, 0.44522195901956391, 0.88147773005334906, 0.32012677837305209, -0.26348404451828084, -0.88865962322796888, -0.0068293429395584757, -0.5702082108905937, -0.84310529329173534, 0.74309879556144121, -0.30607912146999394, -0.62726985310593664, 0.54568358567324937, 0.041605000453203908, 0.85414188062757379, -0.30750032470233174, 0.74442436738659346, -0.84359908618794988, -0.16886449690632624, 0.70773560850345418, -0.34090088039230793, 0.9888378595661601, -0.35842490257407622, 0.021433395921294673, -0.3501362083713242, -1.0352933640729354, -0.2225945229943759, -0.08485166917180692, -0.96312162096579024, 0.058387284419631799, 0.42856747073904872, -0.43354973975695454, 0.42764047543981443, -0.13545668402442748, -0.74935445067714235, 0.096206060419418607, -0.7001413189926935, 0.10338573305846108, 0.78176963878577865, 0.051871146557393992, -0.62128453006691275, 0.33627745133198056, 0.69163349791958784, 0.27958612571085789, 0.25263096670710883, 0.93227475520938197, -1.1184642407392023, 0.56376795738317109, 1.016875473384077, 0.38551631881094534, -0.61765192174538464, 1.273881989613201, 0.33716807966376794, 0.90226766774968148, 0.38775150300201677, -0.40809454307839715, 0.66046041462657024, 0.66900621303825036, -0.16761824050974355, 0.21582766416952445, 0.78189279879885798, -0.82443141431651401, 0.17200333588180053, 1.105366504089857, -0.17502450956224638, 0.69641943878329693, 0.15312848523831768, 0.30617142036239026, -0.18097901068658806, -0.032129165211699326, 0.68067006090115623, 0.65245300234898662, 1.0681722454349569, 0.53067125560660888, 0.42022041251396336, 0.61286289997635746, 0.013033570382110752, -0.54910041050696001, 0.978016515246103, 1.0565213866958405, 0.047957844945620269, 0.9964260427425391, 0.68694190038997882, -0.31299828900919224, 1.0063579154634954, 0.84773469200583151, 0.47423992841160711, 0.4705314625256718, -0.77327579688532577, 0.89091030424897755, -0.83779134848906656, -0.3111485480542161, 0.40202088884211834, -0.74504704206224814, -0.098781453698287974, 0.11935348715344965, -0.38590004412673135, 0.37317762502242041, 0.56624671655380054, 0.052891035524384851, 0.78935117489144213, 0.029475937841860398, 0.84942727832285114, 1.0886472094154218, 0.072144039252005063, 0.81413366018980926, 0.44467268026420448, 0.75948865774767615, 0.26375778629799229, -0.58015021310546755, -0.17178498870578368, -0.87456422751635032, 0.45676057286379423, -0.83763620562466434, 0.096156509276590141, -0.43313846378768611, 0.075073984555849196, 0.81294170079898176, 0.37137727249166341, 0.9005217822032624, -0.75081743566740689, 0.19083641339318758, 0.73437080891694062, -0.47533325871904036, 0.96851248499984166, -0.92094174759624003, -0.53055575470387961, 0.78551182579170287, -0.67745506463659033, -0.016378010555651329, -0.85893250250583841, -0.64024716223920786, 0.92475346987631624, 0.8649373111958043, -0.62660125761701035, 0.98041501960522537, -0.32522187585502377, 0.18657055338327733, 0.77656440047970787, 0.29389710284570569, -0.18981342773060486, 0.74608696456174339, -0.40202695268188177, 0.090475704395726497, -0.6752974364335691, 0.85740794621666339, -0.73654177124523668, 0.47864525127503654, -0.33141983191828911, 0.65226097822369067, 0.093989268112580723, -0.57897720476400694, 0.23294416460720349, -0.88917375535046905, 0.98501438441988398, -0.69204514079957313, 0.53230143895992121, -0.19011426571651713, -0.97413178846474402]],
	    [-0.19277594087582517, [-0.080846992693817551, 0.12810192141800927, -0.77535608685545798, 0.67665747620718331, -0.034251445629525638, 0.053471505421036569, -0.89669514318827648, 0.89330116115904035, -0.13025864722490835, 0.10881542098671253, 0.046837865227546099, -0.73035328740317496, -0.0035104139065169114, -0.72133368782917473, 0.748836084345881, -0.088692348430303936, -0.85634158755402223, 0.27066102944651477, 0.77386768119969929, 0.66186291959315857, 1.0659500570061065, -0.20927178165457974, 0.21291805496494753, 0.79362070437476351, -1.0990645898249987, -0.85667097282849336, 0.23684094093782734, -0.51190244205470037, -0.049569001904638942, 0.59131156352701542, 0.39078850944243554, -0.90033458192791571, -1.2334954220024872, 0.09568927903014135, -0.74072953149074028, -0.34307210106380037, -0.3827428062014584, 0.63134547475483527, -0.50846646373393167, 0.51826159222504831, -0.92617670060417701, -1.3123643478543239, -0.42401204762914568, 0.81589754004359805, -0.16991964807071636, -0.77468323399997829, 0.69406670865512532, 0.58190299100057774, -0.13826161411604249, -0.48879622589664751, -0.51309995532430697, -0.80641362850412301, -0.1016836840964746, 1.2120834907278633, 0.95685901170759535, 0.17062229762610703, -0.74135866352985691, -0.30460695192709419, 0.47953137521486827, 0.91566367349349398, -0.17826176046911407, -0.26636064640768842, 0.71815568994660961, 0.13469338359156252, 0.73247068222409506, 0.48015216750477863, 0.34580589516951205, -0.45215795419698057, 0.12533177726950867, 0.22855417719488724, 0.14325790308220715, 0.27532170057748345, 0.24099803953181773, -0.97789133149321927, -0.1942023108737112, -0.23301350767127912, 0.29548044766240006, 0.89964089576989814, 0.47016377332691933, 0.19430247145151663, 0.52661217957710782, 0.00028113139470562626, -0.31584576216947463, -0.23817368835474884, 0.8795907027599521, 0.72948472122428432, 0.43016275546303895, 0.55611982727803733, 0.17088311592582356, 0.42996092395863927, 0.44657913286077183, -0.8896910299105143, -0.13768146636563808, -0.85178855240103468, -0.39438138965389313, 0.50399150318065733, -0.24134030198709705, -0.37996087251794353, 0.7397373276940673, -0.30466717532737958, -0.92761615520738794, -0.64971862074267928, 0.020252582018916956, -0.48080975926105507, -0.083784021120824143, 0.45634173159219515, -0.38097698264831364, 0.12525507370632835, 0.67098952615146723, -0.98618051439246257, 0.34564924174774703, 0.25406771903300307, -0.7189172809345924, 0.047951172813018923, 0.81799387864551143, -0.67913410596943247, 0.58147754236381677, 0.89503150257283481, -0.34339383580206445, -0.088557268481853274, -0.32731698298184753, -0.75143069901421589, -0.30770211897241845, -1.0162050388664861, 0.77246248687390251, -0.18284281467744065, 0.028310055956107492, -0.81368597285825661, 0.22698131833204821, 0.82806289763971608, -1.1337992798809264, 0.60597797151290467, -0.87358354410285677, 0.61050497606091469, 0.52801450732392419, -0.28707174122433438, -0.94287616697513765, 0.84272455404969804, -0.098584757173357254, 0.41913900746680516, -0.20319873636004698, -0.84938968258636771, 0.012034658042665396, -0.030227312510408753, -0.5154945314430246, -0.53057308575623496, -0.089730906874934027, -0.86876062154913636, -0.1829113297775935, -0.35981675628650311, -0.27195590764034827, 0.72919078831627104, -0.92517598937552936, -0.32843902364120453, 0.035572839610993917, -0.9570767250935911, -0.73493461351707223, -0.97906899083425092, -0.92802965693099249, 0.30819614196605061, -0.097432912223562873, 0.84956825891695953, 0.041310215125488714, -0.22456086437404643, 0.94257463089576587]]];

	var o_weights = [[0.92960326972251772, [-0.44434444087111297, 0.19430194779528376, 1.0052316695998358, 0.43761682104717126, 0.92139839199549411, 0.3575146530985811, 0.017979980173649216, -0.051616042206246528, 0.038994066620980344, 0.038887064590979029, 0.73829893920791168, 0.47913649021227089, -0.70691523047138849, 0.42453287859782463, -0.78059462451550765, 0.3000740790650161, 0.077437657906326521, 0.76420481481290015, -0.68385502780002505, -0.66221022585356593, -0.66491980894702496, -1.4857485427456916, 0.6878318018248516, 0.6782430555356147, 1.0092878182005589, 0.38256136489590159, -1.1163316569946202, -0.72623383988512691, -0.24581894366164, 1.28048296679132, 0.183058919302728, -0.60875119961638691, -1.0762549378388928, -0.39102935251844684, -1.152249964138675, 0.082473317314849345, -0.90288936306269651, -1.0764477733542088, -1.261720017122544, -0.24329380096373043, -0.83464887769310925, -0.28656820855036541, -0.63581970513961505, 0.17258800910709551, -0.6352592472653652, 0.3210192840725275, -0.039773665803516302, 0.24849914180712052, -1.3200210606202025, -0.047319793089979453, -0.35883821787250186, 0.11839929851261873, -1.0103273044599996, 0.89377835244141168, 0.42177913222862118, -0.034844985594275048, -0.03208397631404139, -0.19812721671054914, 0.85461756625500307, 0.84350657546469621, 0.88188329471757199, -0.10842698014121717, 1.185531125495735, -0.83493944474668202, 0.26320798810684359, -0.10355512592975838, -0.1474264393793624, -1.6354008815923788, 0.36495001802580468, 0.67172615996531992, 0.95853545993088241, -0.97674130884978849, -0.96906790540147059, 0.21172265330954143, -0.39472247113281, -0.70296765037500841, -0.65649031481821285, -1.185833692530283, -0.68075743229681596, -0.82641398093389218]],
	    [-0.39674401576235918, [-0.42122064495269695, -0.2376348947035363, -0.51214637832701704, 1.062782596638105, -0.4368373212711657, -1.0325292542208804, 0.63051548003623503, -0.62540070115713065, 0.7659827855782031, 0.026349632690614532, 0.33903902988516327, -1.6761343207655546, -0.79646386289932125, -0.89281284827931684, -0.057084319729522576, -0.49803561155778703, -1.3677614935539206, -0.33920505377529575, 0.043049460540428422, 0.89058413731693697, -0.71393391790079141, -0.95811626663949578, -0.29665993479593955, 0.3671878282354244, 0.62535621686773235, -0.32032025571769862, -0.015086722805668168, -0.25612354625368211, 0.033268991614365674, 0.13100142544492277, 1.5226082445198563, 0.19701381943185528, 0.031530364028703239, -1.1246853471293403, -0.2773985098790096, 0.31603348088063354, -1.1071256695414728, -0.21210039704789835, -0.12338421302968122, -0.51274285319433022, -0.053521245653153159, 0.2436430522639797, 0.88375009697554097, 0.1672522239271341, -0.37250887484892414, -0.45513203366676969, 1.0002998646737047, 0.30456232409076139, -0.54413337461861355, -1.0617536661785238, 0.80369261130695469, 0.0017225575982904554, -0.10700597355027774, 0.73351326569110686, 0.089295244862549125, -1.3652088638492048, 0.80950598055483214, -0.17178282059151254, 0.041384142829240626, 1.0463284118038909, -0.69075917696839284, -1.1082090592462666, 0.25165314992124693, -0.63720209060430821, -0.39935704925312043, -0.96306879715835125, -0.25900677506161596, -0.52458801437650437, 1.6974296232052783, 0.6457599395022271, 0.44507367263364522, -0.40674618714280236, -1.6581064924596689, -0.32092188553033557, 0.13230462423395464, 0.44131370840364809, -0.28515445936424139, -0.64229845813416531, -0.17826936984604894, -0.5152334541816137]],
	    [0.81992679756387254, [-1.0746203064155628, -0.39158036387641604, -0.54348514656393687, 1.5021911134410444, 0.28131521749687821, -0.59226945651401197, -0.10509948129768179, -1.0064922628460933, 0.38532767785546329, -0.76875371023833605, 0.68592149663710067, 0.49575565194373189, -0.7808662886229899, -0.063223731641413844, -0.96487831547795744, -0.79237313886310234, 0.8605904590084329, -0.55700199235721926, -0.23766896992263051, -0.50958743550490471, -0.28213792929616871, -0.095290979101135112, -0.0076517355225422055, 0.55208717282924191, -0.62306790074401774, -0.96324052901126223, 1.0459351021924845, -0.87947271271319694, 0.17619841172545508, -1.1917680229356864, 1.1117364163074566, -0.28387731561883234, -0.76878666623395331, 0.69396821749675963, -1.1545507047441892, 0.50438674646841741, 0.25416300670864367, -0.28629271964729003, 0.63570629134931722, -1.2066515456422742, 0.17170364321900844, -0.537099024338765, -0.87714372199799773, 0.12196230697903754, 0.18447097979337038, -0.4727172463242571, -0.16281927463792586, 0.73235313329704543, -0.93893277955679644, -0.50176164437214421, -0.73752494256858792, -0.46108462399567524, 0.45945863881134436, 0.33498590278772183, 0.082102448502844733, -1.0207539118172213, 0.49200548742039585, 0.95755094772080285, 0.31111108896300615, 0.023415206904802161, -1.317425961060402, 0.075653715549443723, -0.63435532390743676, 0.1637678132295845, -0.36882383087538123, -0.22061372057719816, -1.1874860302125434, 1.0432411885173356, -1.4014387657368468, 0.019085026128383524, -0.035278401487891298, 0.47129706216793144, -0.37645083444242589, -0.083722429237916493, -0.81541737152702198, 0.25769393681695635, 0.80748303742463046, 0.034742317742850026, 0.24154946758151258, -0.89974280590701128]],
	    [0.10435342333434872, [0.62806704241067068, -0.063741219906838342, -0.45692513613291125, 1.0404193159124617, -0.43939825244860503, -0.47529435177605545, -0.9744684086428681, -0.48578875189956, -0.48471997524178367, 0.080224402808155279, 0.71849595715137382, 0.15110073892083994, -0.62532898394147207, -0.44429912638297558, -1.2600017260772773, -0.74545236394085079, -1.5905288598823126, -0.6985443138317472, 0.080908174453118056, 0.74147807069952287, -0.56040251938988905, -0.5164249098447069, 0.096001887779622125, 0.73284039253219913, 1.0314611982698414, 1.3062196840400624, -0.39912919717933526, 0.66782084024304433, 0.6008617495059323, 0.18826700696306434, -0.37226445302328454, 0.56356185713365603, -1.1868079600522043, -0.18347689588576391, -0.17936258782591596, 0.73656380368207675, 0.59844249353406842, 1.1869522473564513, 0.001735382059447167, 0.086157553321634175, -0.26592159491030731, -1.0137203626793352, 0.55143532404324391, 0.54132177464679465, 0.49438920166360106, -0.53961316615128618, -0.70191552425396309, -0.12294311609868799, -0.78510524726237119, -0.87279868130671545, 0.0085769987397121914, -0.13798821395348174, -0.16880540061147523, 0.042413338873515366, 0.67343809659128095, 0.82516169465002076, 0.2458651210739432, -0.98032645063451218, -1.1764672869271771, 0.063263085304891609, -0.38789252317440337, -0.13555074487630933, -0.17745680237603162, -0.098276583627342304, -0.067009752855028512, 0.98502463238909022, -0.93458405827799429, 0.021408206282680545, 0.66515544990806819, 0.08625719037412867, 0.029813007674042706, -0.72444219911164509, -1.1252450573260042, -0.40188869911975178, -0.43631739044169021, -0.80716450549913843, 0.280528195783112, -0.42400958330203986, 0.83332534924899848, 1.0720766900355523]],
	    [0.63889790458221307, [-0.37536076081629954, 0.64788109811863515, 0.95330673514214492, -0.61783074527030912, 0.38698377369135167, -0.82893695216455598, 1.4199619898993856, -1.3433383309216733, 0.093527158091955137, -0.44435010894248106, 0.14720138214093534, -0.1997798656777223, 0.11021384679979836, -0.85896567878420937, 0.0007711284016849346, -1.3618606777696562, 0.900552398185687, 0.43954970733935483, 0.7005875672357148, 0.70704917703397629, 0.078658081543865221, 0.58551795695851627, -0.41938979789521147, -0.5851743623188389, -1.3956902617685585, -0.16600779449859429, -1.2435118648101489, -1.0003206155846083, 0.32872661395199632, 0.14266476490390514, 0.46755710264088912, -0.96581345065920621, -1.7547117609793994, 0.41186304768351084, -1.0574166669712755, 0.28661015564238174, 0.4425183535447002, -0.22287749546784932, 0.38905937725514955, 0.81263234544184237, -0.43634254168298692, -0.31198252476708127, 0.580596065887236, -0.11303708710359502, 1.4580803514726286, 0.1750365436889309, -0.5415123535347327, 0.79072389302304447, -0.29559215194859634, -0.032010274650453072, -1.1979366681307657, -0.87959780913003616, 0.66403562811559602, -0.94823242856104795, -0.62325908065248237, -0.79811073218180462, -0.77440375732989397, -1.321219632122703, 0.045338739877842017, -0.5763658357470266, -0.58104277444485664, 0.24016557938898947, -0.79596312793468305, 0.38039009284029701, -0.09055861740148323, -0.41001420753862455, 0.45572384837543106, -1.4300444528741527, -0.510832394138648, 0.57580893748948425, 0.082391992156828395, -0.051831326092851494, 0.80727828927578349, -0.81980511414478408, -0.61720356587653102, -1.0238810564343261, 1.0316829120637101, -0.67655775672911667, -0.19941014479001923, -0.69723558492154869]],
	    [-0.46552919382534969, [0.493134194227491, -0.45954093237824362, 0.015455393704132788, -0.100663483025138, 0.74697392464650481, -0.8365327467181507, 0.054836899347373735, 0.51237426022373278, 0.90483070347657057, 0.86969438402073751, -0.13207699681852189, 0.99158573754756552, 0.43915388559372459, 0.40064689322889346, -1.200008142375536, -0.95935918885048466, -0.46722995420183439, -0.15831393949294911, 0.24720265570973826, 0.78279952286721488, -0.57901356018242756, 0.91975356328696078, -0.8305180255813327, -0.43414897200070807, 0.19122011693675026, -0.84334368063877085, 0.18296871070534987, -1.0287878117296914, -0.57631811371450936, -0.34524294908588027, -0.25359517913080309, -0.92956549514997355, -0.13203943628229439, 0.2654282295545744, 0.39131021202511956, -0.010013261816400471, -1.6707290533874013, -0.09394376356732044, -0.75440433782434213, -0.062993870061908652, -0.70490000163951783, -0.28431453027822068, 0.45989667276919505, -0.81059754471896828, -0.84105088925826232, 0.39452964586196132, -0.41802759365523612, 0.016741640210651262, 0.2261620449655026, -0.60888486710155787, -0.7144670402949671, 0.16253136046742553, 0.15792116122346911, -0.53403774374433255, -0.4432027493077072, 0.63935867011218517, 0.010342033458259615, -0.12263680893933, -1.0313025892030887, -0.29988065878570608, -0.047705441169837437, -0.088077384548917143, -0.75480453964263428, -0.4190177944855803, -0.3769969196937924, -0.12300333921284201, 0.11234928645831016, -0.86228357231512642, 0.54805200355664774, 0.029469417644840862, 0.13133565628125798, 0.14829607832134148, -0.78037622560532838, 0.02916505616235358, -0.89604726071325613, 1.0916382429390017, -0.22438491305891395, -0.82420357733642935, 0.73811144176792487, -0.41458066748064454]],
	    [-0.34376055975497583, [-0.10273854271406374, -0.89919142869057589, 0.65301470466016431, 1.5280167347403266, -0.91732184516939796, -1.3147866725445922, 1.2569214075633175, 0.59772167771738127, 0.70327270042608514, 0.47023535816492162, -0.81491638043022996, 0.088110157758261129, -0.83607565070455381, -0.4471399342108977, 0.35653303639758072, -0.84971971224882437, 0.70953370613915145, -1.1095077580395405, -0.71192153595636654, 0.90380039179743032, -1.0703675132857582, -0.63711814249194409, 1.1317799887176396, -0.40033381523641126, 0.024891358388362921, -0.74807413480906826, 1.3586199089552384, -0.12116269019774031, -0.90334133680163509, 0.117036764530298, -0.79620256394945588, 1.051197246181139, -1.1329278062290515, 1.1735116441259263, 0.61674828918970426, 0.54084777907923887, 0.69789993195776889, 0.85682152337396822, -0.93245651055679846, 1.4094879056796998, 0.56364943219736297, 0.59107807647553601, 0.8755132343355394, -0.40104902424184247, -1.0523008419163489, 1.2503840977207397, -0.89305763590533893, -0.73325997942727839, -0.95978468216442936, -0.18975262791060216, -0.82569126478456711, -1.7897990534703787, 0.12423255732517728, -0.29949319995464102, 1.3210030133611452, -1.1194780469138779, -0.39805594874641276, -0.014718653117369749, -0.24437997371084538, 0.21974553754501649, -0.045671405540478958, -1.1848670791808862, -0.71319621147312251, -0.98513125772918753, 0.6354975514726422, -0.54797638498593459, 1.053996430859391, -0.63403358172012358, 0.044323538128974133, 0.58158984592135143, 0.60255204592743017, 0.12662147983817962, 0.68652348292223475, -0.21493077370035193, -1.0167892804658742, 0.2365165499316593, -0.029917748231092344, -0.74286519676227269, -1.5331509173210223, 0.45392109156071991]],
	    [0.46461402015727143, [-1.5116853131478074, 0.75811293553521397, -0.97465802526987744, 0.35103609155601734, -0.7011530573437651, 0.41054403689875385, 0.69463139743731661, 0.84612388524837856, -0.79909490055210031, 0.39870635770837209, 0.28359859647355407, 0.56705655954432055, 0.65832721463522614, -0.86896587793776037, 0.93485862478272053, 0.39029074721340301, 0.95842856962232259, -0.66971278277244617, 0.81244038473279878, -1.0639768893707175, -0.31081089560921704, -0.66055729888387615, 0.42469918541011675, -0.16220947253272089, 0.25895430244552409, -0.90580444701550922, 0.44218971664866386, -0.96409818290319982, -0.73948228751874456, 0.18879095466343546, 0.91536144436154732, 0.10110123043015809, -1.0794766760261891, 0.62732612627590489, 0.94083341794373343, -0.28623772305646722, 0.66439873596932786, -0.63722619792959867, -0.075728416114499694, -0.1560023534902753, 0.84765730905818637, -0.16256403848852555, 0.41210944303720276, 0.18628213096714569, -0.70850120719798637, -0.88244051051954808, -0.58708089316049328, -0.25754157701690528, 0.50875757557509671, -1.1358722585953751, -0.53848223101008985, -0.07398902304170589, -0.20564809792528452, -0.27105807402457288, -0.41053157801143175, -0.78209308794602883, -0.47541675951299206, -0.81881385633493375, 0.3506942013413718, -0.73244836451105122, 0.81708857274198543, 0.50319581429038585, -0.32211814149384405, -1.0757512894229588, -0.99019539142587831, -0.64301640482087885, 0.95700016695651557, -0.25952171994826972, 0.56035178765008131, -0.25455196718122236, -1.1218209588214165, 0.54586742358696838, 0.36057602105021008, -1.0033197705699126, -0.4846775973761111, -0.57652865190113034, -0.46063509522588403, -0.39363823148804444, -0.35504145058614639, 0.64337902502893352]],
	    [0.27358128305496954, [-0.98769036900648099, 0.88823429949535748, -1.0096554552650707, 0.33210903297104843, -0.79361417247289878, 0.41638617333912786, 0.3268937952629053, -0.46628156561905487, 0.4589678714816553, -0.89236325559455654, -1.5081675889567414, 1.0396720642140449, -0.16985389678966695, 0.51826532106720502, -0.96296342323026818, -1.1463845513000641, 0.85543054430289078, -0.72951572043725854, -0.43029656715972453, 0.043067035276049832, 0.30888677977250989, 0.10090479251067008, -1.3655884360986998, -1.5186897547035376, -1.1925164137958688, -0.24208428624956624, -0.49304801851676061, -0.039107973639003112, -0.40060659885855771, -1.2618438065648943, -0.4782212973112227, -0.12033975835141086, 0.24576076402999797, -0.0037457548616851625, 1.6402496649042315, -0.73493922078111185, -0.33640424759586285, -0.46437694673575897, -0.90494215264414801, 0.08882266901942526, 1.2111595801896491, -0.95715775799862712, -0.64328209272804959, -0.53359745651562462, 0.016571886662243903, -0.48972663879586842, 1.1488629931137082, 0.59903528240547266, -0.0040912636701340224, -0.08693191860517116, 0.18877935562645959, 0.75109839479240481, 0.57723551588826183, -0.00057961204151905682, -0.73898443749663745, 0.54454418276851602, -0.17387932496008748, 0.0059064037049748816, -0.91128097652331919, -0.15099542305846764, -1.0512632220366032, -0.67896884067919272, -0.085235191301328589, -0.67613521029566737, 0.43287005032116016, -0.26641900916628758, 0.42345159132176213, 0.8952603466196638, 0.83284567060851411, -0.64120190944912703, -0.36623295094638764, -0.77312959505184309, 0.40657282053617932, -1.1008573779492257, 0.52691490423729415, -1.3409275766863651, 0.99880293485199945, 0.49704347387852738, 0.21679041866638563, 0.81428882128599689]],
	    [0.030827517511195026, [0.91489312436576831, 0.05963825170398869, 0.89312385431657237, -1.1771143833469455, 1.0178454184030337, -0.2153126464462852, 0.23645980478411793, 0.077343484700628962, -0.26864032145239969, -0.18559630784237732, 0.809109412504459, 0.88820952748321991, -1.1031642106540307, -0.43054414338243568, -0.35950080431989689, 0.44313048880173894, -0.11958922334470339, -0.39624208669414396, -0.85111685125092096, 0.59766827584183113, -0.22770006825513908, -1.4023131744868047, -0.083386862861128244, -0.96068290701965331, 0.84941708962503637, -0.2204450876299531, 0.74125254810721442, -0.78511794906165611, -0.6488772639289071, -0.8864096303261626, -0.036489470591885141, -0.91355005601505912, 0.18497941459670245, 1.297707230249362, 1.0302756026582733, -0.40787167669433383, -1.194005291868935, -0.84190043379029866, -0.15414291672653407, 0.44276453222831291, 0.12544706768090108, -0.70713262290679224, -0.51065379194238592, -0.52203189499283031, 0.48890381109776709, 0.79164057620481854, -0.39804974430000611, -0.2559631016266708, 0.78066549057930357, 0.53540838175815963, -1.6639785059198589, 0.57363630439635571, -0.89352336519695019, -1.1343728611838131, -0.25861894417057102, -0.7559409585276442, 0.67274756196487739, -0.67768802051396615, 0.065931685776377785, 0.70926658374224505, -0.084903021943222301, 0.37412161167816965, 0.52554426520345077, -0.29296464059896143, -0.75912466883148699, -0.10282399246388207, -0.37251218964864002, -0.68314390428613192, -1.0163050804004699, -1.0243543190276392, 0.65277997337198779, -0.17710130363428503, -1.2632467771067439, -0.7342212533290875, 0.20852992167492451, 0.25504187973625597, 0.14923375742910155, 0.037211573944140666, 0.46322655874806601, 0.33191903671640699]],
	    [1.1879369763827965, [-0.41057759662508569, -1.2424874364337402, -1.0981460406539498, 0.61982853501455681, -0.11746838282107271, 0.54872357999128574, 0.54983009582256115, -0.049348597154563287, 0.93805689458562536, -0.54384837900127248, -0.66532145822799793, -0.1585280629665729, -1.3239244589021291, 0.18346092310697165, -0.54401161676418663, -0.37738441691492547, -0.17794279900481155, -0.075215953973083755, -0.13439092687573118, 0.54793924468405031, -0.28580156548971125, 1.2704413981946798, -0.79786086205289475, 0.41448394064991861, 1.1984405752685447, 1.1993879684200743, 0.36377899125524504, -0.62543076355885141, -0.35760242317368535, 0.86974610807216324, 0.85979737747146201, -1.5599393625922218, 0.89901807147470025, -0.43428319053451836, 0.38522341363960877, 0.89416347010350694, -0.75391322197657096, -0.32146432568880678, -1.1500761947421201, 0.032518211133555866, 0.76661579139829095, -0.54538787507595854, -0.42668295706810166, -0.65824178194210581, -0.38869032646912782, -0.72440596395304646, -1.1899930954460953, -1.0014316866574153, -0.73215413936892326, -1.2048861379169375, -0.95328209008838061, -0.13506595641136201, -0.35565974804781836, -0.79385323125087681, -0.0018918451337262634, -0.32871284035424908, 0.31096784603159217, 0.9588361770520164, -0.44543269362134996, 0.90238211496345344, 0.029313799575404552, 0.603749746602113, -0.21500161640554549, -1.5392863225535112, -0.06952653630276516, 0.35722160079144566, 0.074618874880806763, -0.25128900981583341, 0.61832395458556355, -1.1293489784574391, -1.7967735200015633, 0.3121744246548368, -0.076671741328484061, -0.055069310749290432, 0.75201597436637035, 0.46623210117348679, 1.9489113877330901, -0.4098842232525291, 0.58256129487092134, 0.041065176573059969]],
	    [0.24811968966570841, [-0.8105134622701361, -0.86440542181788449, -0.3208325923183169, -0.6268946165397119, 0.014207037021324148, 0.30958377972785217, 0.30533561049886854, 1.0271878678766109, -1.1864997093125838, 0.82299391032705393, -0.95551362144302432, -1.3500143733591208, -0.33226740074056638, -0.33754741464528348, 0.55208467602618816, -0.72131152223367301, -1.2237718156119051, 0.19174556372598989, -0.59291045055199776, 0.15081661609451349, -0.65340353820628783, 0.49013950788566601, -0.69300011657507332, -0.4711159958327033, 1.2394778338540429, 0.97040162312704115, -1.1673958413827514, -0.023875224885228565, -0.36241284707788296, 1.1084875652195898, 0.33544006074360933, 0.046190243718751779, 0.66773407906580673, -0.47275007136933511, 0.27885999422540997, -0.41728221692892875, -0.49540733039657714, 0.61793945962093555, -0.27764675666930638, -1.1936179667467768, -0.98140004575539386, 0.016664671312444826, -1.449730537391257, -0.98761217881926666, -0.28489953914824329, 0.40384019822625544, 0.053025950386219607, -0.4291759155471031, 0.4326305364565754, 0.036058158479824798, 0.35386790831631876, 0.57200180503033915, 1.0732711159303356, -0.74736856633293147, -0.24722287127299081, 0.92578862108073856, -0.63536748991493208, -0.84881959366782778, 0.3769642637678034, 0.63754645254293629, 0.96642385735683201, 0.81450438543817583, -0.34667243323003777, -0.28606944327175809, -0.42907787877836473, 0.18571587432973552, -0.00451173805938222, -0.045437509130122442, -0.29740207973992344, 0.54587405960296631, -0.85702152458862579, -0.71400232261328522, -0.25054231479258687, -0.16416494620651814, -0.97606689554925963, 0.58201637652273286, -0.95221345555007142, -0.42831361858535255, -0.53595009528202953, -0.6584243673115211]],
	    [0.90530429626227371, [1.1487037299778071, 0.38528241868498075, 0.63014638421383096, -1.1726680708112767, 0.84525900936876841, 0.043048782675416154, -0.27201785240109433, -0.87701832864854801, -0.13121932239826925, 0.55235604816929995, 0.45227036563084783, -0.3873858375164887, -0.62966309309351765, 0.25357383052327703, -0.057335936105144925, 0.95844277236821518, -0.016354018849176002, 0.16646051275635459, 0.032420967718204852, 0.035697744393271572, -0.72578621923246345, 0.37795592083624585, -0.34003278745474014, 0.98871817306320875, -0.80826413015596643, -0.86933835436690832, -0.40029577190356269, -0.35604451896702233, 0.39392950541715244, -0.61494309605740927, -0.71656051049869407, -1.039129121447093, -0.73885733129944631, -0.97350214130046708, -1.0177257653305416, 0.22219086689568407, -0.63520901270421437, 0.5827456804942508, -0.47786969764911491, 0.21114941163829673, -0.29956490275801717, 1.0268262361964979, 0.30736948541617182, -1.0405500020248917, 0.035936748656753448, -0.35791674798767553, -0.51702143916197296, -0.49540713253115704, -0.50621750218010098, 0.59629223193887293, -0.8169840982595018, 0.4572773120989439, -0.17217912388238582, -0.55971194975794192, -0.82854169014131207, -0.90303724152186948, 0.6355203045924398, -0.32218886127338892, 0.35924105895206987, 0.013620401993468438, -0.026536263037395137, -0.79144628508950998, 0.8272920430353603, 0.72995282070915823, -0.88893316054908966, -0.35124021240393338, 0.22640869328342336, 1.0850471843464797, -1.2848794494216889, 0.49328202042307845, 0.39279715733508186, -0.60924717052115296, 0.34080500966948474, -0.11589529357037875, -0.97805546215045236, 0.75536249082469886, 0.39108643605287557, -0.74363119528283006, 0.48493510368883364, 0.4359043912320445]],
	    [1.0167114022337163, [0.091679624490166534, 0.10576572134228961, 0.07935942836835326, 0.1921623290168156, -0.69139462227340931, -0.26246524490932083, -1.1900867207512698, 0.60444844819136412, -0.15760559534875673, -1.3480909522993583, -1.7737958259666984, 0.44102741684333568, -1.6920800850113489, -0.51434006819297851, -1.6811482332724981, 0.79621229309369634, 0.54719036444293523, 0.14068316708729911, 0.91368100656674889, 0.74799188125512206, -1.654750407549056, 1.3477484257560659, -0.92694008789334836, -0.8022104455856498, 0.01089179480722428, -0.57571922637415174, 0.020112961097266575, -0.075761277891815873, 1.3744854732337284, 1.3811124450865524, 0.14788537737829197, 0.39380246359998927, -1.5555828222616284, 0.011339524287133288, -0.99969588381045049, 0.11872241491289585, -0.32180837328199635, -0.45013601455746222, 0.17895927995838254, 0.033336730687131243, -0.1817236853080246, 1.2502326161945021, 0.23343065933785118, 0.43579921619265932, -0.42869561117735905, -0.61623786835200101, -0.67403074543889407, -0.34701840046081184, 0.55762700570964729, 0.03076079440355748, -0.82242333564265913, 0.58321466720541937, -1.5524786114296478, -0.3703641141552973, 0.58030786033057136, 0.020441123455663561, -0.92163658038419871, 0.90079396505551668, -0.06297611671241897, 0.61999322085042241, 1.0534041430294456, 0.44215090696466047, -1.0041926870882465, -0.05441011552534878, -0.68337801039738799, -0.21280672773044212, -1.3052962976550795, 0.41863466554222117, 0.71224729781021567, 0.13805297251910598, -0.64525568699589819, -0.81127318945517468, 0.57849063805777123, -0.37844625310088548, -0.0043511565114564893, 0.84700327039568923, 0.17530808776934539, -0.92142844630505649, -0.63028380665287331, -1.3312617367495525]],
	    [0.2582211260032205, [0.510613608095417, 0.5954287008104322, -0.76841946826165708, -0.72333121963234992, -0.4733223523575274, 0.29887786605486832, -0.38530777310669639, 1.3515488943941152, -0.10244088617381891, 0.16263718684659165, 1.0640339685180435, -0.72466758485667404, -1.2171484938780592, 0.47461327644253509, -0.15204289762192827, 1.1261709653608367, 0.76889260163746653, -0.06848768870396664, -1.9222131824142492, -0.24367029984961541, 0.45376344720428913, -0.047297428172629254, -0.30141018513875062, -1.3510709998191439, -0.2155583162780732, 0.063832198189227876, -0.9150960266167979, -0.72346675922848713, -0.57848786110852013, 0.5213877922614002, 1.3737220694293593, -0.030743756858884044, -0.60782966133661509, -0.61195986628819521, -0.71995193104904509, -0.088702358332980347, 0.53775312148316023, -0.18116692106385526, 0.76217978447925494, -0.29678794589048274, -0.54051603831503547, 0.81572748180226629, -0.71029957496220952, -0.0049202114766117699, 0.89583336694626969, 1.5727231476168897, -1.3105988838715108, 0.45091734338737577, 0.12717681180037099, -0.40745704115786979, 0.29203023920193943, -0.7407077955088236, -0.92500796427299836, -0.75381390723355068, 0.0072295747410155119, 0.33346346656618048, 0.47336457595599196, 0.6732139515984602, -1.0705906392759299, -0.37175258750465495, -0.71804271209538606, -1.1868403331669588, -0.62090998165570266, -0.11252593214867879, 2.0677060439990784, -0.59620630804047825, 0.38202526398180853, 0.76298212307854973, -0.18517559608307607, -0.85032354190258508, -0.72654137491803672, -0.75270689700858695, -0.40291329399865017, -0.37877023745349248, -0.75760510619595256, 0.027726937228926548, -0.2416231909397494, -0.057633452433862191, -0.54092872031461958, -0.51540899162969545]],
	    [-0.41361229015327633, [1.1740502138639928, 0.80793600185931291, 0.58496460586634202, -0.21362009474259919, 0.18858653632704192, 0.65419113123619066, 0.69959222638292207, -0.23389045801020075, -1.0277856163669596, 0.63746557252522906, -1.1943753411967954, 0.56370249461211874, 0.61543208981879383, 0.31117427383123858, -0.77545196249098558, -0.45210092035587818, -0.79188598669711374, -0.93770304146185679, 0.47696145746473184, 0.49874358101004945, 0.44685949273010572, -0.93831440718969839, -1.0880053868083592, -0.48060192859174689, -0.74645590722661281, 0.7253566870574909, -1.1771528732083862, 1.1287343383816846, -0.10798260753303621, -0.8770803500701152, 0.96182561436519709, 0.065660439730514344, 0.90427184476181433, 0.37861439080745418, 0.62108394114505905, 0.30544535253685656, -1.0717095063297499, -1.1490573252053562, -0.62517759743183554, 0.026431903612928419, 0.15019658863576582, 0.21789704002176108, 0.76863068954248814, -0.20769681058694095, 0.42747066678158085, -1.1283025536427922, 0.53303444504261432, -0.33813390067880739, -1.4422030904144358, -0.2023942951137746, -0.50240060084435156, -0.87511526509477966, -0.90929397700621306, 0.78002335109447218, -0.1044802039264187, -0.14306906907526851, -1.0235843788475447, -0.93607541206510958, -0.12162983620407047, 0.55606024326086867, -0.48244448369159582, -1.1565336627440002, -0.2080281001518049, 0.79566594457534023, -0.27517658102958087, 0.10744388195069066, -1.0719094814539392, -1.122989537030457, -0.22808900533795326, 0.10395203153465554, -0.3288360490338198, 0.23588879541798755, -0.17513554291123062, -0.3324622548651151, 0.68152658472886374, -0.13635253607426118, -0.35247964580257812, 0.4046414748485524, -1.1965052816930899, -0.2855944397370534]],
	    [-0.44038648230835648, [0.86867933105231732, 1.5472693547849372, -0.70326628193076568, -0.74179640782183254, 0.27371099864907861, -1.13615816541571, -0.53014662348274022, -0.94870977423258462, 0.35263742582397095, -1.2297245162359505, -1.1871872909942898, 0.65515058685986871, -0.46318231576358998, -1.0436947421439124, -0.6067673672290006, 0.98545386337630014, 0.87968086403385248, -0.23363634197474975, -1.1648450104270056, -0.93639600791207689, -1.1066528366906505, -0.61124072415164465, 0.48412157505089348, 0.40391887636217116, 0.15463132754183115, -1.1715542315329439, -0.74260912092683451, 0.25937546658875399, -0.617306953943772, -0.37943565251357386, -0.6163208264870178, 0.15597922546584558, 0.63293207917111149, 0.52000560125491579, 0.94003012884929005, 0.97636606786982183, -0.8558702024310203, -0.57532813429071805, 0.066026242468502555, 0.34355142839270597, 0.83107995922558908, -0.076682249787797516, -0.07706555204698548, -0.95541520806284952, 0.8676774590118731, 0.69947271658174381, -0.074647009420257801, -1.1653218408626556, -0.66467925056029498, 0.38655853293705728, -0.66274151065295572, -0.36845616632192318, -0.89096602844208195, -0.026096388763948722, 0.42532723457831467, 1.0298951336090414, 1.1451330630854852, 0.34442113607967684, -0.68520260653902187, -0.68063019670960001, -1.1872043812384139, -0.84911398733800625, 0.20601055280848632, -0.78216387260428921, -0.73219490769639994, -0.28441912704123168, 0.13241251713580918, -0.22008054596500709, -0.27809321471979587, -0.84008539987505648, -0.79935433703732828, 0.3727733467179859, 0.41897360347548929, 0.26993025224990153, 0.16178119748230416, 0.481910515523022, 0.78994894050084929, -0.0324137265509363, -0.46498454835894582, -0.30324135741309072]],
	    [0.69888411997524957, [-0.30744051942246819, 0.40871827257801002, 0.58287634418294154, 0.17417828464575771, -1.0992051388410147, -0.015015923272573754, -0.51329189902220285, 0.65365672142795284, -1.2503278106774347, -1.1776647058592149, -0.20220536005380374, -0.45920552154142102, 0.051277825943369895, 0.20352911063283588, -0.89099377888225417, 0.71567659132669725, -0.22431012328819402, 0.47700306456100355, -0.39138698568488134, -0.99336790142164866, -0.23643867415571052, -0.40787271583728402, -0.046811648596570436, -0.34806983113618328, -0.40248685235801018, -0.35831617267783367, 0.76241403885971337, -0.6599020463633416, -0.52015701423854677, 1.0280971644964749, -0.73100600975209673, -1.0038114056990495, 0.75647454102617706, 0.35864726689914422, -1.0145680482755857, -1.1484101634760577, 0.48421337040658896, -0.12285075206919799, 0.47266412387080026, -0.79741164711793322, -0.56107747106238348, -0.48788386794845473, 1.2820348746748151, 0.67835838313719188, -0.81294384914206852, 0.27950934092996083, -0.47414658711905883, 0.067335041258042849, 0.14667228380658417, -0.24105495245190309, 0.90040321249008803, 0.83085931042495698, 0.42745385161006799, -0.55144889723870028, -0.85379510681438131, 0.53535908196875703, 1.2820353819178525, 0.24626605209300328, 0.57877393308942571, -0.92764421551712095, -0.70873346125005277, -0.90474237808018831, -0.62737773765853977, 0.19712276908084483, -0.36786845024203918, -0.13519540924948531, -0.65533856412492264, -0.18750058942801701, -0.87734486538161849, 0.32721643494076369, -1.0688378322831615, -0.2034007889544597, 0.49833196437297694, -0.89246598724445392, -0.64415232376958365, 0.91521908994366974, -0.80190820584463274, -1.2862897333876382, 0.43935950384676448, 1.2511008660375642]],
	    [1.3423963810982689, [0.11881596581013441, 0.053433258205792387, 0.46085900795904322, -0.67649575411143403, -1.0318796751339827, 1.6078188667934308, 0.45269636421460507, 0.98810756522601784, -1.2351684462559585, 0.73312771204860816, -0.62023687575393283, 0.41041807926486873, 0.53909157968967869, 0.23966612611500437, 0.50697435102096045, 0.23404568886150218, 0.43132362165325494, -1.2365173262768157, -0.75338945181667005, -0.88269050005233118, 0.068433679665747663, -0.37385349584231314, 0.066239705077666938, -1.7381472773135873, 0.18008395358084522, -0.49202112992281238, 0.51502302143968859, 0.21709599770498489, -0.24710672186101121, 1.0139691055134457, 0.40521175620082273, 0.85680687010731482, -0.73190054538739913, 0.35551678371281037, -0.19231565033536904, -0.81556538022636571, -0.61719675113396666, -0.89863956499857001, 0.10341950929748771, 0.0086820326487421617, -1.0786174779889988, -0.047710599418789405, 0.26600062755400111, 0.49866196588818512, -0.11185418532525486, -0.91656483789203969, -0.050963052267535128, 0.28971354642768959, -1.1777759040672746, -0.2548670553421914, -0.16422270646848133, 0.13473433467884821, 0.38760095125763788, -1.524799098741255, 0.39608575900553056, -0.25274174045599523, -0.99986714800564791, -0.22740228301113327, -0.95385045861844286, -0.35860665957158477, 0.085911087564996519, 0.51975382454515151, 0.12413691385551494, -0.87529873406379854, -1.0388222508488152, -0.16657728170832997, 0.24210513971190112, -0.95680122586784389, -0.65863446273200177, 0.71046717834094364, 0.80409200124853997, 0.63050870321175512, 0.42052551808758337, -0.1203038559095141, 0.66947660821277533, -0.40634407477470574, -0.84219047314081108, -0.19270143456902755, 0.057409303175967361, -0.20169573359798987]],
	    [0.23155135137629521, [0.23511055066418862, -0.46420463046986715, -0.18931493711907113, -0.68821658759415438, 0.58426716108572807, 0.31925295216147431, -0.087432136226632026, -0.48312252222896879, 0.88673471536387083, -0.30278839421763132, -1.0120355112688639, 0.88281034243991297, 0.53543360735272449, -1.1887165324549527, -0.2837171897483311, 0.55705903721282679, 0.2938552564914288, 0.12942696882173044, -1.174803398634493, -0.68910691448781591, 0.57024328169434024, -1.1213356258950022, 0.87709106319717955, -1.0366208125626946, 0.22387786501032872, -0.29877654430263728, 0.10203067314124534, -0.10277547829767539, 0.08511346559106818, 0.31780693762180651, -0.21283348478944669, 0.87261695400170403, -0.074795661865045798, 0.44172790130163814, -1.1281719678965401, -0.57911128195864736, -0.73925078510927533, 1.4897407460715899, -1.00900206167636, -0.41731194217147433, -0.10042092255914641, -0.18991987681053452, 1.4370918752501485, 1.415849573285054, -1.394204395306557, -0.7338545243152389, -0.14943511352585012, -1.1355758182868738, 0.85378030987807629, -0.46444927261543256, 0.27921530947767587, -0.48155402703181449, -1.3860960604387682, 0.8788722298090702, 0.34916423355620513, 1.3049028185457607, -0.83059952894542, -0.18640665444884508, -0.75039029830770443, -1.1002405231738481, 0.22851409276498555, -0.47090685796936821, -1.2861129547955326, -0.033033665816412157, -0.37299075545637184, -0.58166662601661212, 0.66089015420390063, -0.97810299046129801, -0.015179894911024642, -0.48291874059711876, -0.49594127295391016, 0.51410545466195456, -0.84612189624068812, -0.47635636271506449, 0.43845070915343815, 0.48973027504112232, 0.19753090432517945, -0.33543892416927701, -0.50979010719164575, 0.42045711228512256]],
	    [0.13057111050530132, [0.59649038634359297, -0.7765459860124746, -0.71901846178949869, -0.65717036218724656, 0.0029317984439121546, 0.30537650811438793, 0.30700686774991742, -0.089127531179913136, -0.93073419903631394, -0.35645486692855854, 0.95329491381501408, -0.89265848236033085, -0.40870424484456613, -0.90316891769137531, -0.67613068115082953, 0.82998235184436364, -0.63065548711654795, -1.2646039253701677, -0.39806674573920209, 0.34722901887743507, 0.27633735577469165, -0.37934161390634624, -1.5523606659602323, -0.12706227700543071, -0.99853746712014058, -0.5626546839234593, -0.39049368952287483, 0.3738295447334114, 0.80777300460200996, -0.24311490330473079, -0.015171407786193799, -0.65563158168685065, 0.77447105130032645, 0.4670987195708971, 1.3713105360236033, 0.67778405304278244, -0.28820700634289992, -0.033327538151749631, 0.37133696089350127, -1.2783152522165868, 1.0287545017377631, -0.097584525839021968, -0.58488423640498888, -0.96956576392175242, -0.3702317856911847, 0.28631531129508331, 1.1107375091091476, -1.0187798122655667, 0.22788227633521468, -0.26041325017647948, -0.47706336976949798, 0.22774183669238629, 0.63420179010449595, 0.52902441366182784, 0.54367099402055985, -1.1511041979855878, -1.2011779376499883, 0.36106701563176924, -1.1609180805686012, -0.15489068252607605, 0.57669829865893651, -1.0724779917753624, 0.19719929926669802, -1.4939198701337049, 1.4779345464101796, 0.42840127375795795, 0.95954162937620247, 0.23606778856366747, -0.55658803570553639, 0.091054268955962081, -0.18284439443219977, 0.10609969379044791, -0.47475252553655045, 0.34474919284394723, 0.32594400825542452, 0.75547821959033468, -0.95508556925392674, 0.16001290428471068, -0.27654182852751585, 0.73353239834144268]],
	    [0.071221794729594015, [0.69381600193291959, -0.96464105549864032, -0.25043610973078595, 0.64318727703766998, 1.1936147218540527, -1.0874233619407456, -0.39856785912762327, 1.0919546925450605, -0.11374452812334278, 0.26122037757033334, 0.11259199446503292, -1.2446381122651895, -0.3302823885625974, -0.85363359516563009, 0.81372649920053253, -0.22296664106590952, 0.59054767734833302, -1.0721801651824459, -1.2396973616542946, 0.66011519289602982, 0.25997802397276998, -0.13398127542278529, -0.21897484500179859, -0.31169658575303544, -1.1398050744442061, 0.43598089112738936, -0.016495573008825294, 0.099863313112607391, 0.19934283703713618, 0.49129477845354302, 0.72124691987178247, 1.003294643488289, -0.23218577275608923, -0.13175739689067728, -0.025840318514687911, 0.99696404049837895, -1.058346555422861, -0.77583652845686035, 0.65552294939207456, 1.2485337930324096, -0.79155645289889487, 0.40675105057872607, -0.59990576767068071, 0.54732013098796384, 0.79402048223954613, -0.59140910207013531, 0.32696085107527695, -0.11422137117209782, -0.90127971261980899, -0.29886869392503301, -0.76649362571602464, -0.15802629323394607, -0.083099691860178099, 0.72417408216943635, -1.1690376192566223, 0.68046328928226962, -0.4686001220622078, -0.043853734332511447, -0.10959326613873609, 0.68042687054620099, -1.2068104753825792, 0.46695365503293157, -0.16705571687760498, 0.67405791627507916, 0.70915489842106683, -0.18786469410482917, 0.2003321670906382, -0.26067109537295091, -0.8175827019000399, -0.71575117004307287, -0.036537802413673381, -0.73726931222821646, 0.13016873131091364, -0.84467825442742783, -0.80316419081238577, -1.7156656270025412, -1.1868315990485963, -0.29665586632616225, 0.7710758933596451, -0.61655489712264766]],
	    [1.5500068702761014, [-0.021116676534217848, 0.51437983467756343, -1.3263438477303171, 1.0899413854362516, -0.84615870149004735, -0.90692495756198155, 0.63314951230018723, 0.70506753754580753, 0.4542473302962875, 0.16192664465848008, 0.33716944412586886, -0.044239929087700511, 1.1365710732850312, 0.19142152329453574, -0.58128202197714018, 0.39274688820972981, 1.0349220736234646, -1.2413062144016247, -0.75630059488542178, -1.0913196270460015, 0.27338807609282922, 0.83883337868065344, -1.1204898847216298, 0.30314491573299313, -0.34722523699649249, -0.54439059632191356, -1.0577561297274423, 1.0720872421377499, -0.14284527573591402, -1.2280059895549083, 0.15434822402170836, -0.97092450450901169, -0.27177895569602178, -0.28714622973295711, -1.1619665817061002, -0.028781624172339898, -1.5265906901174975, -0.90768686094463646, -0.71618619358643165, -0.74263016917063696, -0.6480810556917953, -0.5380228864906792, -0.2697466002940056, 0.44642015984151684, -0.59735014255230268, -0.98506980692337143, -0.82174546781102675, 0.14073189888649826, 0.99416349170580576, -0.069548234796075803, -1.2022867125581114, 0.34141412164997492, 0.52608514616492397, -0.94080156184064068, 0.37997146553893774, 0.4054970054480716, 0.21927832728932828, -0.57087830546143825, 0.43264716459349628, 0.43156468753349958, 0.5886594698862192, -0.41874841481462832, -0.82617261881871884, -1.4234051729506851, 0.12131989988899941, -0.82408907943797316, 0.60306318386912905, -0.72502303577181537, -0.18043662198618013, -0.66132858346893586, 0.50674810831282557, 0.2525186981147331, -0.054393027435415339, -0.86252366325237495, 0.172413533285981, -0.80686008676213761, 0.17800378666377528, 0.35611048405549423, -0.19315112312807531, 0.78273717882256311]],
	    [-0.1886232235916579, [-1.0874962591320811, -0.70083598310154838, -0.35643575149408413, -0.47090184022408532, -1.0876936710693981, 0.18630832892046964, -0.63612802937205959, 0.4301067385522912, 0.70634534346999911, 0.19424330405310603, 0.42147588484715637, -0.033276537325574312, 0.78058261988491762, 0.2534580179055016, -1.3946107339587952, -0.40020749890320334, 0.13259236046479628, -0.41900031998890225, 0.00079124328034331102, 0.57141974908010562, 0.88867685820582554, -1.1318646185147954, -0.024402319530299917, -0.2731189097663993, -1.2236070336549911, -0.5126398980605964, -0.46640889670189806, 0.37813985896585162, 0.56808888903843446, 0.029758989725826284, -0.52415281953574533, 0.83752074388392095, 0.50553077425338655, -0.20758956275115625, 0.025634778886595176, -0.22736554532934383, -0.46847857475977883, -0.68646912406222205, 0.41819443806657036, 0.23086145193881802, -0.73226517247654366, -1.3710512176968608, -0.11722902156237471, 0.48469003648441117, 0.4086632129520385, 0.19588128552600031, -0.95904375121564955, 0.32561363017468353, 0.58850620145723298, 0.22828725052144383, 1.0379249171637148, -0.10007918474338211, -1.5593890610354424, 0.080419945486826391, 0.44029242999808721, 0.79533486796700925, -0.4619825051206895, -0.46256884749835953, 0.87336616177524129, -1.2377623602778012, -1.0090617280384513, -0.78381018654529044, -0.37079400781137356, 0.4263861120221456, 0.42239804954680032, -0.11397705753107563, -0.38948258680866565, -0.22364598962583687, -1.1654865919859634, 1.3530443728933115, 0.29797060809419701, -0.32964928261078741, -1.0910063261880996, -0.22477148889832038, -0.76812092450907443, -0.13537278612179621, -1.4558280637843746, -0.67259679093696978, -1.2759111238081344, 0.87024603060910444]],
	    [-0.23990719264581167, [-0.54955692830851122, -0.61530284689134729, -0.50700227882690863, -1.5533185762005948, 1.3856527881875917, 0.5297221878552073, -0.34105334985609337, -0.14110317547713389, -0.15071191801535819, -0.13325587050760124, 0.78422772189865142, -0.081224516662928625, 0.54325267616870665, -0.21839350509354843, 0.60442884987942402, 0.39613831653474735, -1.3915832714043204, -0.38769372861266649, -0.73630314211060544, -0.8029050590168948, 0.37955053082572482, -0.71246478414220571, -0.7138279914103336, -0.37314065305731359, 0.43510449994603556, 0.39386202120900482, 0.29431315121692742, -0.73549816849029093, 1.2798312059182542, -1.0263787163091853, -0.62515780930972087, -0.93378190508526537, 0.22228232903360748, 0.68414869055991345, 0.81667694127014434, 0.645076666142962, 0.46081236530882325, -0.61649063524678382, -0.16514425138380434, -0.21193141571479254, -1.7270978660048979, 1.6407357103464679, -0.31041187325340447, -0.85833164833982645, 0.66920029479357179, -0.91754522881954093, 0.17828061466280867, 0.11399284336868783, -0.32722272442539441, 0.61600685351168838, 0.56529918640506049, -0.28774223767889812, 1.4033903866019588, -0.17542359125279483, -0.44711520556614959, 0.16953820590209567, 0.029197910963812274, 0.26059103416366025, 0.42546872845643358, -1.5275420391820616, -0.68357914488274263, -0.77059942497761391, -0.99343711444512828, -0.72844562433487203, 0.20807294076240229, -0.20160843338108442, -0.39998059526145519, -0.29337072893696969, -0.47553882316485724, 0.65453150676753369, 0.28165969483711351, 1.0635541580307799, 0.17337905371621104, -0.62637642251912706, -1.7559002252400941, -0.95752393898959332, -1.1259885951733275, -0.15509317719376683, -0.34384989289176415, -0.084535208366597739]],
	    [0.18749946246838783, [-0.084149866651897026, 0.043881526985246923, -0.0037012026848146666, -0.83747543093260368, -0.03136444234633641, 0.62868707588312445, -0.92764349866809104, 0.09636608998685435, 0.14182499878383131, -0.69574407149323825, -1.1222365026621037, -0.073588192133047264, 0.75724474917836948, -0.62665144154419783, 0.7818594576330844, -0.70147870638635068, -0.92901923727898439, -1.1820138686387387, -0.63077447466321523, -0.93996265071884744, -1.1219595560074311, -0.46631693391728668, 0.23014430981500072, 0.95220971994632164, -0.81430733622003959, 1.1461381889622542, -1.0723077769412726, -1.3425649340092034, 0.81001481919648932, 0.34511767087618084, -0.46447515369849424, 0.073057562151613756, 0.34269402796189785, 1.3401415057828943, -0.17343564688531021, -0.43379093412524322, 0.46859766840951944, 1.3290125223149285, -0.022754838867425051, 0.18890442893679724, 0.61524490487814854, 0.17623261449504662, 1.3129724574925616, 0.23163893392016008, 0.087981136685256964, -1.0546132540796744, -0.58174600233494167, 0.023893874753457108, -0.37933717812177808, 0.22239113268318314, 0.91261432407774412, 0.23089215714453853, -1.2334005436469218, -0.45228246074183254, -0.99342178243973656, -1.2546113860330304, 0.33752885625481305, 0.74898895768810381, -0.33006931842820719, -0.024564264923828183, -0.40806487267588915, 0.40240960293098743, -0.29029252201872713, 0.66252175659516954, 0.58663882067499062, -0.37469386766149959, -1.7740410306523231, -0.31367267609845051, -0.53522829776183511, -1.175973526758245, -1.0567314857658607, -0.47704503770023465, -0.29351203824217775, -0.72438488633785314, -1.0353873562847049, 0.42670962387638262, 0.37069143748849198, -0.58873978837104757, 0.54965683328214432, -0.8647716038307024]],
	    [-0.12578288676961361, [0.13104266124094457, -0.059402823919533519, 0.044146198352240859, -0.91812765360415494, 0.87067015238896472, -0.93392908542098552, 0.7546344979508357, 0.23723874804859985, -0.81490756970692146, 0.049961406106277612, -0.090813731990508406, -0.62708830237894342, 0.4810723751010248, -0.34121515123763341, 0.24036683698987768, 0.77745349414850162, -0.78719776653668005, 0.51470380207775468, 0.32169055198053176, -1.3405262828237854, 0.87301091286349319, 0.58612963610118451, -0.18181131897716885, -0.11356797858208079, 0.37627723966239607, -0.41102376935749624, -0.69770224280666615, -1.2560247177280766, 0.22866836550131461, -0.94182005816697756, -0.88876618444056887, 0.18678250410911185, -0.50462768203648589, 0.2932252921120086, -0.6202305438997695, 0.90205470843665969, -0.83451312877228279, -0.37660941136813803, 0.88250675698588765, 0.96060465276869922, 0.23308676142626034, -0.77844346312676183, -0.88254021592117704, -0.78962122968021931, 0.67856316031150787, -0.80544223678395555, -0.11462014944532227, -0.96458623540759836, -0.64132421789966931, -0.89071441671740925, 0.28058784624935307, -0.24603493551346001, -0.61425497429336939, -0.0045348871372856278, 0.088794586138897319, -0.67519044405957651, -0.6726314000205349, -0.037983567118755404, 0.24170795646524809, -0.58553674764608299, -1.1858007428963044, 0.64255398568470512, -1.23411635755198, 0.1157186907548088, -1.0414123710733447, -0.16099189984795842, -0.83067776588631081, 0.70840936330360527, 0.33012243194554031, -0.52391520254074209, 1.0092585578479563, -0.47606205610313307, 0.011658535661721569, -0.71879930928025682, -0.48944183434305044, -0.75704111815729092, 0.54639857226127286, -0.83360053063302819, 0.66027100450460308, 0.21021071473158298]],
	    [0.26532633780887582, [-0.81364067713813981, 0.82314384324871204, 0.10939373631693419, -0.59418745011449525, -0.3599020045218162, 0.55160220779343749, -1.0223376606688126, -1.0372471389238029, -1.062213448102419, 0.32967579582715628, 0.18788981722639445, -0.94737218422495539, 0.74579476373346154, -0.85942758627224136, -0.0046101392904878734, -0.68090333042121942, 0.62728445865381033, 0.092383058653508987, 0.54066171532458396, 0.95922271482515942, -0.72445027740109247, -0.23377293288087672, -0.86722107360489242, -0.52583938068458724, 1.1246657117727905, -0.40249144542915538, 1.3978607587655885, -0.088610029770772383, 0.87169050353316302, -1.0350340849911546, 0.18459596553935914, -0.49291922541699379, -0.37393604626270038, -0.36149209155476342, 0.24599357613406778, -0.64159258942900488, -0.32203297182495916, 1.4868880435764733, 0.51889644764342568, 0.29523724016679381, 0.045817513497830406, -0.92181832505779704, 0.81143183145271869, 0.35640677714643682, 0.10588333844170138, 0.73722396739958529, -0.028500472146120118, 0.45132470534168828, -0.36375703781307628, 0.44658480489677954, 0.033865960442238059, -0.52869358587179782, 0.46333651785097846, -1.409953308646152, 0.82618022224934839, 0.015030844987798938, -0.05866304594369616, 0.70694409236527234, -1.2361816024557264, -0.65693136745109004, -0.58220106970328234, -0.4551376006116058, 0.81542575005391404, -1.4519551783785807, -0.62617004992260161, -0.38780488644740496, -1.5406284843067766, 0.37268125661879731, -0.20995822503603295, -0.5602488889297772, -1.344383182490404, 0.50233142990628754, 0.16850259998815847, 0.015268923861436958, -0.22269723128622876, -0.49354173004297569, 0.73135601828543606, -0.37528403457058662, 0.91399571242663813, -1.3097131924301295]],
	    [0.0058422756735189828, [-0.66736730611552963, -0.31795520009961664, 0.47534190106016705, -0.88961723317227093, -0.35582738328465924, -0.19250129741515579, 0.77824429952426144, -0.37952969961021848, -0.202358709838135, 0.91439828507600351, 0.68673291016434546, -0.077125505541394454, 0.46007830497644492, -1.0137473022656753, -0.28532098139219508, -0.69530177184459041, 0.8340305061239669, -0.8411083944196458, -1.5263951512752254, -1.5076075392673332, -0.98266010612194865, 0.25577210645071624, 0.57439997973824319, -0.54689856998910069, 0.73164086912316351, 0.033606509994329195, 1.2895093932206745, -0.37244623641311086, -0.44292938313752722, -1.0097250677566196, -0.023956952838113815, -0.64302440027957009, -0.53788338471001074, 0.1257413346726928, -0.047662850096037698, 0.069748245899629024, -0.62276442869739146, -0.28904221280055148, -0.69720685962387796, 1.0742687829484681, -0.0076582810080102221, -0.49280347127142271, -1.0977005022573656, 1.8151810315778671, 0.1674759452819386, -0.68256201578137443, -0.1666913583788325, -0.70965488139627908, 0.31236999322132736, 0.67367181195456505, 0.17183303760020593, -0.47573251302384628, 0.2236787731165373, -0.32189284663260104, -0.48146022466205368, -0.16468832575940651, 0.71729953969228244, -0.034532362470728536, -0.30012426473053494, 0.17140288838441278, 0.40120269187637136, -0.55057573013684047, 0.18229075148156743, -0.84884448260035816, -0.096795362903381185, 0.080579797717476476, 0.56881657571435729, 0.64784552533139539, 1.2873620054656312, -0.23642053021918097, 0.11450581986176174, -1.7889696677273252, 0.57777401513017823, 0.14564960766335899, -0.46012719044123762, -0.23957892679754283, -0.84242192890515732, -0.18922623628718035, 0.69434280114525748, -0.33732554312200191]],
	    [0.51881653782685944, [-0.95039148169487775, 0.85718636354739375, 0.0045313778406372279, -0.17090075270842361, -0.37197597832332929, -0.35415515351391164, -1.0971374228287327, 0.36059380502670257, -0.1152109193909461, -0.62522073861449778, -0.27175168180472581, 0.064662052057498073, -0.96014232253204701, -0.20339873011449283, 0.26265052425526048, -0.56838965497241523, 0.89661947030163858, -1.2261951905433097, 0.62703655967116478, -1.3007412210675484, 0.077074441027721319, 1.3048097930910418, 0.5718505162218146, 0.35812193131026732, 1.2421406427772081, -0.60867962367745465, -0.99509668183219679, -0.22720624462084932, -0.26312758845412554, 0.88062244281061652, 0.079215933517453416, -1.1283528075439149, 0.35881851541830212, -0.84326652563913551, 1.4033974239275706, -0.57957883291376122, 0.057138221773819164, -0.045507002592245743, 0.52727545972344436, 0.03744987762828305, 0.65336781441228964, -0.04796302034647066, -0.0063840063979909833, 0.53724067063067327, -0.22433775231640887, 0.92914972330317669, 0.005155729314135854, -1.0141146918870656, -1.0791494157594237, -0.57628028263979048, 0.24274431568376184, -1.2184125494811129, -0.010053449620699966, 0.16487513373791771, 0.29059537022676452, -0.29776188679483268, -0.60905762757265303, -0.55901683195417473, 0.49924832735223162, -0.76344559809365709, 0.28028667792364076, -0.18986113920891781, 1.0106005642750424, 0.26028678558175095, 1.1968226909279036, 0.59616329916713529, -0.94367903797783448, -0.72303770074332863, -0.43720359752209281, -0.31837599204791384, -0.12887877862192185, -0.96530046448450268, -0.02544036343383892, -1.0516299310035455, -0.84862163431376714, -0.25436062065365284, -0.43669637910941367, 0.78717629166849723, 0.9057189973623081, 0.76339110131888011]],
	    [-0.18369386290626274, [-0.20545389669249836, -0.60538665195703645, 0.039012394738835901, 0.7293566015474614, 0.070222404095261287, -1.0746575290867812, -0.89306825006173718, -0.79576281019863548, 0.30378268287044446, 0.11736535330727046, -0.077941926190457894, -1.023665658422884, 0.44384460818445132, 0.5973426759257684, 0.98949285132116538, 0.5948314145509922, 0.095711168827851356, 0.61308153671113508, 0.76633873413609943, 0.035516032284165694, 0.27018845838142064, -1.1196631112714457, 0.4160220436145603, -1.1515471292646231, -0.23807663474996066, 0.11457867784884504, 1.0742102199840973, -0.11940921838448114, 0.50789034802401201, -0.51013320112919991, -1.6121454594519, -1.2409694106597431, 0.47294057699590081, -1.3372845006688474, 0.82463137255590335, 0.50720483588934862, 0.35030950926318721, -1.0456650406850478, -1.6312804391442715, -1.303624552098132, -0.14660354524288832, -0.29124641625893016, -1.2319052920719564, -1.0493793384541312, 0.22944522019779492, -0.1709005768385031, -0.62620349106806794, -1.0680545644208255, -0.38991659553321228, -0.83356092502210977, 0.56129242578020422, -0.25737580277966204, 0.46748868516301578, 0.0069404179419280849, 0.6347495336844805, -1.2221605095995705, 0.66188314213896227, 0.85522909546106107, -0.78867532183702971, 0.78432110959767676, 0.0752708060432416, -0.088983209554373097, -0.84738969328872105, -0.34324564553176629, 0.16392779839129334, -0.1415717974240423, 0.62934719926775451, -0.59586110963613592, -1.1582446408325613, -1.2166606302303344, -0.79525311936821763, -0.13064279120816713, -0.95635100152922925, -0.92548793823484254, 0.73447104688127751, -0.17673545227994944, 0.30553976474886246, 0.39235582726658735, 0.55818315179270472, -1.4259044894489767]]];

	var net = new NeuralNet;
	net.h_layer = net.create_layer(h_weights);
	net.o_layer = net.create_layer(o_weights);

	return net;
}; // end megaupload. createNet

